//const indexSearch = require('./plugins/search-index');
//const feed = require('./plugins/feed');
//const sitemap = require('./plugins/sitemap');
// const socialImages = require('./plugins/socialImages'); TODO: failing to run on Netlify
const path = require('path')

/** @type {import('next').NextConfig} */
const nextConfig = {
  //reactStrictMode: true,
  swcMinify: true,
  experimental: {
    appDir: true,
  },
  flags: {
    DEV_SSR: false,
  },
  images: {
    remotePatterns: [
      {
        protocol: "https",
        hostname: "wwareact.cda-development3.co.uk",
      },
      {
        protocol: "https",
        hostname: "admin.wwmain.cda-development3.co.uk",
      },
      {
        protocol: "http",
        hostname: "admin.wwmain.cda-development3.co.uk",
      },
      {
        protocol: "http",
        hostname: "localhost",
      },
    ],
    minimumCacheTTL: 1500000,
  },

  // By default, Next.js removes the trailing slash. One reason this would be good
  // to include is by default, the `path` property of the router for the homepage
  // is `/` and by using that, would instantly create a redirect

  trailingSlash: true,
  // By enabling verbose logging, it will provide additional output details for
  // diagnostic purposes. By default is set to false.
  // verbose: true,
  eslint: {
    ignoreDuringBuilds: true,
  },
  env: {
    // The image directory for open graph images will be saved at the location above
    // with `public` prepended. By default, images will be saved at /public/images/og
    // and available at /images/og. If changing, make sure to update the .gitignore

    OG_IMAGE_DIRECTORY: "/images/og",

    // By default, only render this number of post pages ahead of time, otherwise
    // the rest will be rendered on-demand
    POSTS_PRERENDER_COUNT: 5,

    WORDPRESS_GRAPHQL_ENDPOINT: process.env.WORDPRESS_GRAPHQL_ENDPOINT,
    WORDPRESS_MENU_LOCATION_NAVIGATION: process.env.WORDPRESS_MENU_LOCATION_NAVIGATION || "PRIMARY",
    WORDPRESS_PLUGIN_SEO: parseEnvValue(process.env.WORDPRESS_PLUGIN_SEO, false),
    API_URL: process.env.API_URL,
    ADMIN_URL: process.env.ADMIN_URL,
    SITE_URL: process.env.SITE_URL,
    STORE_URL: process.env.STORE_URL,
    USER_API_URL: process.env.USER_API_URL,
    COOKIE_DOMAIN: process.env.COOKIE_DOMAIN,
  },
};
const removeImports = require('next-remove-imports')({
  test: /node_modules([\s\S]*?)\.(tsx|ts|js|mjs|jsx)$/,
  matchImports: "\\.(less|css|scss|sass|styl)$"
});
module.exports = {
  compress: false,
}

module.exports = removeImports({
  webpack(config, options) {
    const eslintRule = {
      test: /\.(tsx|ts|js|mjs|jsx)$/,
      enforce: 'pre',
      loader: 'eslint-loader'
    };

    const rules = [].concat(eslintRule, config.module.rules);
    config.module.rules = rules;
    return config
  },
});
module.exports = {
  "plugins": [
    "postcss-flexbugs-fixes",
    [
      "postcss-preset-env",
      {
        "autoprefixer": {
          "flexbox": "no-2009"
        },
        "stage": 3,
        "features": {
          "custom-properties": false
        }
      }
    ],
    [
      '@fullhuman/postcss-purgecss',
      {
        content: [
          './pages/**/*.{js,jsx,ts,tsx}',
          './components/**/*.{js,jsx,ts,tsx}'
        ],
        defaultExtractor: content => content.match(/[\w-/:]+(?<!:)/g) || [],
        safelist: ["html", "body"]
      }
    ],
  ]
}
// const withSass = require('@zeit/next-sass')
// module.exports = withSass({
//   cssModules: true
// })
const nextConfigcss = {
  webpack(config) {
    config.resolve.alias = {
      ...config.resolve.alias,
      '@styles': path.resolve(__dirname, 'src/styles'),
    };

    return config;
  },
};
module.exports = nextConfigcss;
module.exports = () => {
  //const plugins = [indexSearch, feed, sitemap];
  const plugins = [];
  return plugins.reduce((acc, plugin) => plugin(acc), nextConfig);
};

/* module.exports = {
  async redirects() {
    return [
      {
        source: '/shop',
        destination: '/shop',
        permanent: true,
      },
    ]
  },
} */
/* module.exports = {
  async redirects() {
    return [
      {
        source: '/shop/:slug*',
        destination: '/shop/:slug*', // Matched parameters can be used in the destination
        permanent: true,
      },
    ]
  },
} */
/* module.exports = {
  images: {
    domains: ['admin.wwareact.cda-development3.co.uk'],
  },
}; */

/* module.exports = {
  images: {
    domains: ['https://admin.wwareact.cda-development3.co.uk/'],
  },
} */

/**
 * parseEnv
 * @description Helper function to check if a variable is defined and parse booelans
 */

function parseEnvValue(value, defaultValue) {
  if (typeof value === 'undefined') return defaultValue;
  if (value === true || value === 'true') return true;
  if (value === false || value === 'false') return false;
  return value;
}
