import React, { useState, useEffect } from "react";
import Link from "next/link";
import Image from "next/image";
import UrlReplace from "./UrlReplace";
import styles from "../../styles/components/Storemaker.module.scss";
import { fetchOptionByParams } from "../../services"

const StoreMakerExpert = ({ expertAboutList }) => {
  const [optionData, setOptionData] = useState(null);
  const handleOptionApi = async () => {
    const optionResponse = await fetchOptionByParams("acf.expert_about_list");
    if (optionResponse) {
      setOptionData(optionResponse)
    }
  }
  useEffect(() => {
    handleOptionApi();
  }, [])
  return (
    <div className={styles.ourStorySection + " " + styles.storeMaker}>
      <div className={styles.wrapper}>
        <div className={styles.bgColorSection}>
          <div className={styles.threeBlockSection}>
            {optionData &&
              optionData.acf &&
              optionData.acf.expertAboutList.map((aboutListItem, index) => {
                return (
                  <div key={index} className={styles.mainBlock}>
                    <div className={styles.block}>
                      <div className={styles.imagePart}>
                        {aboutListItem.pageLink.buttonLinkType == "internal" ? (
                          <Link href={UrlReplace(aboutListItem.pageLink.internalLink)} className="image-hover-link">
                            <Image width={258} height={333}
                              className="img" sizes="100vw"
                              src={aboutListItem.sectionImage.sizes.homeAboutBlogsImage}
                              alt={"General-Image-" + Number(index + 1)}
                            />
                          </Link>
                        ) : (
                          <a href={aboutListItem.pageLink.externalLink} target="_blank" className="image-hover-link">
                            <Image width={258} height={333}
                              className="img" sizes="100vw"
                              src={aboutListItem.sectionImage.sizes.homeAboutBlogsImage}
                              alt={"General-Image-" + Number(index + 1)}
                            />
                          </a>
                        )}
                      </div>
                      <div className={styles.textPart}>
                        {aboutListItem.pageLink.buttonLinkType == "internal" ? (
                          <Link href={UrlReplace(aboutListItem.pageLink.internalLink)}>
                            <h2>{aboutListItem.pageLink.buttonText}</h2>
                          </Link>
                        ) : (
                          <a href={aboutListItem.pageLink.externalLink} target="_blank">
                            <h2>{aboutListItem.pageLink.buttonText}</h2>
                          </a>
                        )}

                        <p>{aboutListItem.content}</p>
                      </div>
                    </div>
                  </div>
                );
              })}
          </div>
        </div>
      </div>
    </div>
  );
};

export default StoreMakerExpert;
