import React, { useState, useEffect } from "react";
import Image from "next/image";
import axios from "axios";
import FooterMenu from "./FooterMenu";
import FooterNewsletter from "./FooterNewsletter";
import { fetchMenuBySlug, fetchOptionByParams } from "../../services"
import VisaIcon from "../../../public/images/visa.svg";
import MasterIcon from "../../../public/images/Mastercard.svg";
import AmericanIcon from "../../../public/images/BlueBox.svg";
import styles from "./Footer.module.scss";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import { faTwitter, faInstagram, faFacebookF, faYoutube } from "@fortawesome/free-brands-svg-icons";

const Footer = () => {
  const [isActive, setActive] = useState(0);
  const [footerFirstMenuData, setFooterFirstMenuData] = useState();
  const [footerSecondMenuData, setFooterSecondMenuData] = useState();
  const [headerFooterOptionData, setHeaderFooterOptionRes] = useState();
  const ToggleClass = (value) => {
    if (isActive == value) {
      setActive(0);
    } else {
      setActive(value);
    }
  };
  useEffect(() => {
    if (!footerFirstMenuData) {
      axios.get(process.env.API_URL + 'menus/v1/menus/footer-menu-1')
        .then(function (response) {
          setFooterFirstMenuData(response.data)
        })
    }
  }, [footerFirstMenuData])
  useEffect(() => {
    if (!footerSecondMenuData) {
      axios.get(process.env.API_URL + 'menus/v1/menus/footer-menu-2')
        .then(function (response) {
          setFooterSecondMenuData(response.data)
        })
    }
  }, [footerSecondMenuData])
  useEffect(() => {
    if (!headerFooterOptionData) {
      axios
        .get(process.env.API_URL + 'acf/v3/options/options?_fields=acf.address_title,acf.wwa_address,acf.wwa_phone_number,acf.wwa_email,acf.opening_hour_text,acf.opening_hours_schedule,acf.twitter_link,acf.instagram_link,acf.facebook_link,acf.youtube_link,acf.header_logos')
        .then(function (response) {
          setHeaderFooterOptionRes(response.data)
        })
    }
  }, [headerFooterOptionData])
  return (
    <footer className={styles.footer}>
      <div className={styles.wrapper}>
        <div className={styles.footerTop}>
          <div className={styles.footerLinks}>
            <div className={isActive == 1 ? styles.footerBlock + " " + styles.activeMenu : styles.footerBlock}>
              <h3 className={styles.tabTittle} onClick={() => ToggleClass(1)}>
                Legal
              </h3>
              <div className={styles.content}>
                <FooterMenu footerFirstMenuData={footerFirstMenuData} footerSecondMenuData={footerSecondMenuData} />
              </div>
            </div>
            {headerFooterOptionData ?
              <>
                <div className={((isActive == 2) ? styles.footerBlock + " " + styles.activeMenu : styles.footerBlock)}>
                  <h3 className={styles.tabTittle} onClick={() => ToggleClass(2)}>{headerFooterOptionData.acf.address_title}</h3>
                  <div className={styles.content}>
                    <address dangerouslySetInnerHTML={{ __html: headerFooterOptionData.acf.wwa_address }}></address>
                    <ul>
                      <li><a href={'tel:' + headerFooterOptionData.acf.wwa_phone_number}><strong>{headerFooterOptionData.acf.wwa_phone_number}</strong></a></li>
                      <li><a href={'mailto:' + headerFooterOptionData.acf.wwa_email}><strong>{headerFooterOptionData.acf.wwa_email}</strong></a></li>
                    </ul>
                  </div>
                </div>
                <div className={isActive == 3 ? styles.footerBlock + " " + styles.activeMenu : styles.footerBlock}>
                  <h3 className={styles.tabTittle} onClick={() => ToggleClass(3)}>
                    {headerFooterOptionData.acf.opening_hour_text}
                  </h3>
                  <div className={styles.content}>
                    <ul>
                      {headerFooterOptionData.acf &&
                        headerFooterOptionData.acf.opening_hours_schedule.map((openingHoursItem, index) => {
                          return (
                            <li key={index}>
                              {openingHoursItem.day_name}: {openingHoursItem.day_time}
                            </li>
                          );
                        })}
                    </ul>
                  </div>
                  <div className={styles.social}>
                    <ul>
                      <li>
                        <a href={headerFooterOptionData.acf.twitter_link} title="twitter" target="_blank">
                          {/* <i className="fa fa-twitter" aria-hidden="true" /> */}
                          <FontAwesomeIcon icon={faTwitter} />
                        </a>
                      </li>
                      <li>
                        <a href={headerFooterOptionData.acf.instagram_link} title="instagram" target="_blank">
                          {/* <i className="fa fa-instagram" aria-hidden="true" /> */}
                          <FontAwesomeIcon icon={faInstagram} />
                        </a>
                      </li>
                      <li>
                        <a href={headerFooterOptionData.acf.facebook_link} title="facebook" target="_blank">
                          {/* <i className="fa fa-facebook" aria-hidden="true" /> */}
                          <FontAwesomeIcon icon={faFacebookF} />
                        </a>
                      </li>
                      <li>
                        <a href={headerFooterOptionData.acf.youtube_link} title="youtube-play" target="_blank">
                          {/* <i className="fa fa-youtube-play" aria-hidden="true" /> */}
                          <FontAwesomeIcon icon={faYoutube} />
                        </a>
                      </li>
                    </ul>
                  </div>
                </div>
              </>
              : ""
            }
            <FooterNewsletter isActive={isActive} ToggleClass={ToggleClass} />
          </div>
        </div>
        <div className={styles.copyright}>
          <div className={styles.leftPart}> © William Walter Antiques LTD 2023</div>
          <div className={styles.midPart}>
            <div className={styles.paymentCardContainer}>
              <div className={styles.paymentCardWrap}>
                <Image width={42} height={24} src={VisaIcon} className={styles.imgVisa} alt="visaicon" />
                <Image width={30} height={23} src={MasterIcon} className={styles.imgMs} alt="mastericon" />
                <Image width={30} height={30} src={AmericanIcon} className={styles.imgBb} alt="americanicon" />
              </div>
            </div>
          </div>
          <div className={styles.rightPart}>
            Site Designed &amp; Developed by{" "}
            <a href="https://cda.group/" target="_blank">
              CDA
            </a>
          </div>
        </div>
      </div>
    </footer>
  )
};

export default Footer;