import dynamic from 'next/dynamic'
import Image from 'next/image'
import React, { useState, useRef } from 'react';
import { Formik, Form, Field, ErrorMessage, useFormikContext } from 'formik';
import * as Yup from 'yup';
const ReCAPTCHA = dynamic(() => import("react-google-recaptcha"));
import { joinOurNewsletter } from '../../services';
import styles from "./Footer.module.scss";
import TrustPilot from '../../assets/trustpilot.png';
const FooterNewsletter = ({ isActive, ToggleClass }) => {

    const ref = useRef();
    const [g_recaptcha_response, set_g_recaptcha_response] = useState('');
    const [ReCaptch, SetReCaptch] = useState(null);
    const [buttonText, setButtonText] = useState('SUBSCRIBE');
    const [joinOurNewsletterSuccess, setJoinOurNewsletterSuccess] = useState(null);
    const [recaptchaNeeded, setRecaptchaNeeded] = useState(false);

    const resetCaptcha = () => {
        ref.current.reset();
        SetReCaptch(null);
        set_g_recaptcha_response('')
    }

    const onChangeCaptchavalue = (value) => {
        SetReCaptch(true);
        set_g_recaptcha_response(value)
        setJoinOurNewsletterSuccess(null)
    }

    const onExpiredCaptchavalue = (value) => {
        SetReCaptch(false);
        set_g_recaptcha_response('')
        setJoinOurNewsletterSuccess(null)
    }


    const NewsletterSchema = Yup.object().shape({
        yourEmail: Yup.string().email('The e-mail address entered is invalid.').required("This field is required.")
    });

    const AutoSubmitToken = () => {
        const { values } = useFormikContext();
        React.useEffect(() => {
            if (values.yourEmail)
                setRecaptchaNeeded(true)
        }, [values]);
        return null;
    };

    return (
        <div className={((isActive == 4) ? styles.footerBlock + " " + styles.activeMenu : styles.footerBlock)}>
            <h3 className={styles.tabTittle} onClick={() => ToggleClass(4)}>Join our Newsletter </h3>
            <div className={styles.wpcf7 + " " + "js"} id="wpcf7-f131-o2" lang="en-US" dir="ltr">
                <div className="screen-reader-response"><p role="status" aria-live="polite" aria-atomic="true" /> <ul /></div>
                <Formik
                    initialValues={{
                        yourEmail: '',
                        firstName: '',
                        lastName: '',
                    }}
                    validationSchema={NewsletterSchema}
                    onSubmit={async (values, { resetForm }) => {

                        setButtonText('Submitting...')
                        if (ReCaptch == true) {
                            const form = new FormData();
                            form.append('first-name', values.firstName);
                            form.append('last-name', values.lastName);
                            form.append('your-email', values.yourEmail);
                            form.append('g-recaptcha-response', g_recaptcha_response);

                            const joinOurNewsletterResponse = await joinOurNewsletter(form);
                            setJoinOurNewsletterSuccess(joinOurNewsletterResponse)
                            setButtonText('SUBSCRIBE')
                            resetCaptcha();
                            resetForm()
                        } else {
                            SetReCaptch(false)
                            setButtonText('SUBSCRIBE')
                            setJoinOurNewsletterSuccess(null)
                        }

                    }} >
                    {({ errors, touched }) => (

                        <Form method="post">
                            <AutoSubmitToken />
                            <div className={styles.mainFooterForm}>
                                <div className={styles.inputPart + " " + "half"}>
                                    <Field className={styles.input + " " + "input"} name='firstName' placeholder="First Name" />
                                    <ErrorMessage component='div' className={styles.formError} name="firstName" />
                                </div>
                                <div className={styles.inputPart + " " + "half"}>
                                    <Field className={styles.input + " " + "input"} name='lastName' placeholder="Last Name" />
                                    <ErrorMessage component='div' className={styles.formError} name="lastName" />
                                </div>
                                <div className={styles.subscribe}>
                                    <Field className={styles.input + " " + "input"} name='yourEmail' placeholder="Your Email Address*" />
                                    <ErrorMessage component='div' className={styles.formError} name="yourEmail" />
                                    <button type="submit" id="submit" className={styles.btn + " " + styles.btnSmall + " " + styles.btnSuccess + " " + styles.buttonSubmitForm} disabled="">{buttonText}</button>
                                </div>
                            </div>


                            {recaptchaNeeded &&
                                <ReCAPTCHA
                                    sitekey='6LcMGWkUAAAAAM5vA9rkbH1rbYyu19H1Nwg8rXet'
                                    onChange={onChangeCaptchavalue}
                                    onExpired={onExpiredCaptchavalue}
                                    ref={ref}
                                />
                            }
                            <div className={styles.formError}>{(ReCaptch == false) ? 'Please verify that you are not a robot.' : ''}</div>

                        </Form>
                    )}
                </Formik>

                {((joinOurNewsletterSuccess) ? <div className='success-msg'>{joinOurNewsletterSuccess.message}</div> : '')}
            </div>
            <div className={styles.trustpilot}><Image height={103} width={197} className="img" src={TrustPilot} alt="trustpilot" /></div>
        </div>
    );
};

export default FooterNewsletter;
