import dynamic from "next/dynamic";
import Image from "next/image";
import Link from "next/link";
import axios from "axios";
import React, { useEffect, useState } from "react";
import { useDispatch, useSelector } from "react-redux";
import { useRouter } from "next/router";
import { userPending } from "../../reducer/userSlice";
import UsersApis from "../../helper/UsersApi";
import useSite from 'hooks/use-site';
import Mainlogo from "../../../public/images/logo.svg";

import UserIcon from "../../../public/images/user-icon.svg";

import HeaderNav from "./HeaderNav";
import HeaderLogos from "../HeaderLogos";

import UrlReplace from "../Common/UrlReplace";
import styles from "./Header.module.scss";
const MiniCart = dynamic(() => import("components/MinCart"));
const LanguageDropdown = dynamic(() => import("components/LanguageDropdown"));

const Header = () => {
  // const searchQuery = new URLSearchParams(window.location.search);
  // const searchParam = searchQuery.get('s');
  const { headerMenuData, topMenuData } = useSite();
  const router = useRouter();
  const searchParam = "";
  const dispatch = useDispatch();
  const [scroll, setScroll] = useState("");
  const [isActive, setActive] = useState("false");
  const [isToggleDropdown, setIsToggleDropdown] = useState(false);
  // const [topMenuData, setTopMenuData] = useState();
  // const [headerMenuData, setHeaderMenuData] = useState();
  const [headerFooterOptionData, setHeaderFooterOptionRes] = useState();
  const ToggleClass = () => {
    setActive(!isActive);
    document.body.classList.toggle("body-fix");
  };

  const ToggleClassRemove = () => {
    setActive("false");
    document.body.classList.remove("body-fix");
  };
  const langToggleDropdown = (val) => {
    setIsToggleDropdown(val);
  };
  //const { topIsLoading, topMenuData, topError } = useSelector(state => state.topMenu);
  // const { generalSettingsIsLoading, headerFooterOptionRes, generalSettingsError } = useSelector(state => state.generalSettings);
  const { cart } = useSelector((state) => state.woocommerce);
  const { userIsLogin, userIsLoading, userData } = useSelector((state) => state.user);




  useEffect(() => {
    window.addEventListener("scroll", () => {
      setScroll(window.scrollY > 100);
    });

  }, [router.pathname]);

  const clearCookieToken = async () => {
    const logoutResponse = await UsersApis({
      endpoint: "users/logout",
      method: "GET",
      params: {
        insecure: "cool",
      },
    });
    if (logoutResponse.status == "ok") {
      var Cookies = document.cookie.split(";");
      for (var i = 0; i < Cookies.length; i++) document.cookie = Cookies[i] + "=;expires=" + new Date(0).toUTCString();
      localStorage.setItem("cookieAuth", "");
      dispatch(userPending());
      // window.location.href = "/";
    }
  };
  // useEffect(() => {
  //   if (!headerMenuData) {
  //     axios
  //       .get(process.env.API_URL + 'menus/v1/menus/header-menu')
  //       .then(function (menu) {
  //         setHeaderMenuData(menu.data)
  //       })
  //     //const headerMenuResponse = await fetchMenuBySlug("header-menu");
  //     //setHeaderMenuData(headerMenuResponse)
  //   }
  // }, [])
  // useEffect(() => {
  //   if (!topMenuData) {
  //     axios
  //       .get(process.env.API_URL + 'menus/v1/menus/top-menu')
  //       .then(function (menu) {
  //         setTopMenuData(menu.data)
  //       })

  //     //const topMenuResponse = await fetchMenuBySlug("top-menu");
  //     //setTopMenuData(topMenuResponse)
  //   }
  // }, [])
  useEffect(() => {
    if (!headerFooterOptionData) {
      axios
        .get(process.env.API_URL + 'acf/v3/options/options?_fields=acf.address_title,acf.wwa_address,acf.wwa_phone_number,acf.wwa_email,acf.opening_hour_text,acf.opening_hours_schedule,acf.twitter_link,acf.instagram_link,acf.facebook_link,acf.youtube_link,acf.header_logos')
        .then(function (response) {
          setHeaderFooterOptionRes(response.data)
        })
    }
  }, [])
  return (
    <header
      className={scroll ? styles.siteHeader + " " + styles.fixedHeader + " " + " fixedHeader" : styles.siteHeader}
    >
      <div className={styles.headerMain}>
        <div className={styles.wrapper}>
          <div className={styles.headerInnerContainer}>
            <div className={styles.logo}>
              <Link onClick={ToggleClassRemove} href="/">
                <Image width={175} height={45} src={Mainlogo} alt="Main Logo" priority />
              </Link>
            </div>
            <HeaderNav ToggleClass={ToggleClass} isActive={isActive} headerMenuData={headerMenuData} topMenuData={topMenuData} />

            {headerFooterOptionData && headerFooterOptionData.acf && headerFooterOptionData.acf.header_logos ? (
              <HeaderLogos headerLogosData={headerFooterOptionData.acf.header_logos} />
            ) : (
              ""
            )}
          </div>
        </div>
      </div>
      <div className={styles.headerTop}>
        <div className={styles.wrapper}>
          <LanguageDropdown />
          <div className={styles.topMenu}>
            <div className={styles.menuTopMenuContainer}>
              <ul id="primary-menu" className={styles.menu}>
                {topMenuData &&
                  topMenuData.items &&
                  topMenuData.items.map((topMenuItem, index) => {
                    return (
                      <li
                        key={index}
                        className={
                          router.pathname.replace(/\/+$/, "") == UrlReplace(topMenuItem.url.replace(/\/+$/, ""))
                            ? styles.menuItem + " " + styles.currentMenuItem
                            : styles.menuItem
                        }
                      >
                        <Link href={UrlReplace(topMenuItem.url)}>{topMenuItem.title}</Link>
                      </li>
                    );
                  })}
              </ul>
            </div>
          </div>
          <div className={styles.topUsersLinks}>
            <MiniCart />
            <div className={styles.userIcon}>
              <Link href="/my-account" title={userIsLogin ? "My Account" : "Login / Register"}>
                <Image width={20} height={19} src={UserIcon} alt="user-icon" />
              </Link>
              {userIsLogin ? (
                <ul>
                  <li>
                    <Link href="/my-account" title="My Account">
                      My Account
                    </Link>
                  </li>
                  <li>
                    <a onClick={clearCookieToken}>Logout</a>
                  </li>
                </ul>
              ) : (
                ""
              )}
            </div>
            <div className={styles.topSearch}>
              <button className={styles.searchToggle} />
              <form role="search" method="get" className={styles.searchForm} action="/search/">
                <label>
                  {/* <span className="screen-reader-text">Search for:</span> */}
                  <input
                    type="search"
                    className={styles.searchField}
                    placeholder="Search …"
                    defaultValue={searchParam ? searchParam : ""}
                    autoComplete="false"
                    name="s"
                  />
                </label>
                <input type="submit" className={styles.searchSubmit} defaultValue="Search" />
              </form>
            </div>
          </div>
        </div>
      </div>
    </header>
  );
};

export default Header;
