import React, { useState, useRef, useEffect } from 'react';
import Image from 'next/image'
import Slider from "react-slick";
import "slick-carousel/slick/slick.css";
import "slick-carousel/slick/slick-theme.css";
import VideoBanner from '../../../public/images/Homepage-Banner-1.jpg'
import styles from 'styles/components/Bannerslider.module.scss';

const BannerSlider = ({ topBanner }) => {
    const homeData = topBanner && topBanner[0]
    const [displayThumbImage, setDisplayThumbImage] = useState(true);
    const [sliderReady, setSliderReady] = useState(false);
    const refs = useRef()

    var settings = {
        dots: false,
        arrows: false,
        infinite: true,
        autoplay: true,
        autoplayspeed: (homeData) ? 3000 : homeData.acf.sliderDuration,
        speed: 3000,
        slidesToShow: 1,
        slidesToScroll: 1
    };

    const playVideo = () => {
        refs.current.play()
        setDisplayThumbImage(false)
    }

    const pauseVideo = () => {
        setDisplayThumbImage(true)
    }
    useEffect(() => {
        setTimeout(() => {
            setSliderReady(true)
        }, 7000)
    }, [])
    return (
        <div className={styles.mainBannerSection}>
            <div className={styles.wrapper}>
                <div className={styles.bannerSlider}>
                    {sliderReady ?
                        <>
                            {((homeData.acf.videoOrSlider == 'image_slider') ?
                                <Slider {...settings}>
                                    {homeData.acf.imageSlider.map((imageSliderItem, index) => {
                                        return <div key={index} className={styles.imageBox}>
                                            <Image width={1440} height={822} sizes='100vw' src={imageSliderItem.sliderImage.url} alt={imageSliderItem.sliderImage.filename} priority />
                                        </div>
                                    })}
                                </Slider>
                                :

                                <div className={styles.videoBanner + " " + styles.mp4video}>
                                    <div className={(displayThumbImage) ? styles.bannerImg + " " + styles.bgCover : styles.bannerImg + " " + styles.bgCover + " " + styles.posterHide} style={{ background: 'url("' + homeData.acf.videoThumbnail.url + '")' }} >
                                        <Image className={styles.img} src={VideoBanner} width={1440} height={822} sizes='100vw' alt='videobanner' priority />
                                    </div>


                                    <div className={styles.bannerVideoWrap}>
                                        {((homeData.acf.videoType == "select_video") ?
                                            <video ref={refs} width="100%" controls onClick={pauseVideo}>
                                                <source src={homeData.acf.selectVideoFromLibrary} type="video/mp4" />
                                                Your browser does not support HTML5 video.
                                            </video>
                                            :
                                            <iframe title="vimeo-player" src={homeData.acf.embadeExternalVideo + '?h=32b17ba081&autoplay=1&amp;'} frameborder="0" allowfullscreen></iframe>

                                        )}
                                    </div>
                                    <span onClick={playVideo} className={(displayThumbImage) ? styles.playBtn : styles.playBtn + ' ' + styles.posterHide} style={{ background: "url('../../assets/play-icon.svg')no-repeat center" }}></span>

                                </div>
                            )}
                        </>
                        :
                        <Image sizes='100vw' src={VideoBanner} alt="Banner" width={1440} height={822} priority />
                    }
                    <div className={styles.homeWelcome}>
                        <div className={styles.wrapper}>
                            <div className={styles.homeWelcomeBox}>
                                <h3>Welcome to</h3>
                                <h1>{homeData.acf.welcomeSectionTitle}</h1>
                                <p>{homeData.acf.welcomeSectionContent}</p>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>

    );
};

export default BannerSlider;
