import React, { useState, useEffect } from 'react';
import { fetchPageAcf } from '../../services';
import moment from 'moment'
import Link from 'next/link';
import Image from 'next/image'
import { fetchLatestNews } from '../../services';
import UrlReplace from 'components/Common/UrlReplace';
import styles from 'styles/components/Latestnews.module.scss';

const LatestNews = ({ homeData }) => {

  //const { homeIsLoading, homeData, homeError } = useSelector(state => state.homePage);
  const [latestNews, setLatestNews] = useState();
  const [dataAcf, setDataAcf] = useState();
  const handleLatestNewsApi = async () => {
    const latestNewsResponse = await fetchLatestNews();
    if (latestNewsResponse) {
      setLatestNews(latestNewsResponse)
    }
  }
  const handleAcfAPI = async () => {
    const acfResponse = await fetchPageAcf("?_fields=acf.view_all_news,acf.section_title&slug=home");
    if (acfResponse) {
      setDataAcf(acfResponse[0].acf)
    }
  }
  useEffect(() => {
    !latestNews && handleLatestNewsApi()
    !dataAcf && handleAcfAPI()
  }, [])
  return (
    <div className={styles.latestBlogSection}>
      <div className={styles.wrapper}>
        <div className={styles.latestBlogInner}>
          <div className={styles.tittlePart}>
            {dataAcf && dataAcf.sectionTitle && <h2>{dataAcf.sectionTitle}</h2>}
            {dataAcf && dataAcf.viewAllNews &&
              <p>
                {
                  (dataAcf && dataAcf.viewAllNews.buttonLinkType == "internal") ?
                    <Link href={UrlReplace(dataAcf.viewAllNews.internalLink)}>{dataAcf.viewAllNews.buttonText}</Link> :
                    <a href={dataAcf.viewAllNews.externalLink} target="_blank">{dataAcf.viewAllNews.buttonText}</a>

                }
              </p>}

          </div>
          <div className={styles.newBlog}>

            {
              latestNews && latestNews.map((selectPostItem, index) => {
                return <div key={index} className={styles.blog}>
                  <div className={styles.contentBlock}>
                    <Link href={'/' + selectPostItem.postName} className={styles.img}>
                      <Image width={367} height={400} sizes='100vw' className={styles.img} src={selectPostItem.newsPostImage.sizes.homeNewsImage} alt="authentic-silver-inspection" />
                    </Link>
                    <Link href={'/' + selectPostItem.postName} className={styles.text}>
                      {selectPostItem.postTitle}
                    </Link>
                    <p>{moment(selectPostItem.postDate).format('D MMMM YYYY')}</p>
                  </div>
                </div>
              })}
          </div>
        </div>
      </div>
    </div>
  );
};

export default LatestNews;
