import React, { useState, useEffect } from 'react';
import Link from 'next/link';
import Image from 'next/image'
import Slider from "react-slick";
import { fetchProductsByCondition } from '../../services';
import AddToBasket from '../popup/AddToBasket';
import UrlReplace from 'components/Common/UrlReplace';
import AddToCart from 'components/Common/AddToCart';
import "slick-carousel/slick/slick.css";
import "slick-carousel/slick/slick-theme.css";
import styles from "styles/components/Newarrival.module.scss"

const NewArrival = ({ topBanner }) => {
    const homeData = topBanner && topBanner[0];
    // const { homeIsLoading, homeData, homeError } = useSelector(state => state.homePage);
    const [productsByCondition, setProductsByCondition] = useState([]);
    const [productData, setProductData] = useState({});
    const [modalIsOpen, setIsOpen] = useState(false);

    function openModal(productItemObj) {
        setProductData(productItemObj)
        setIsOpen(true);
    }

    function closeModal() {
        setIsOpen(false);
    }

    var settings = {
        dots: false,
        arrows: true,
        infinite: true,
        loop: true,
        autoplay: true,
        autoplayspeed: 3000,
        slidesToShow: 4,
        slidesToScroll: 1,
        responsive: [
            {
                breakpoint: 1024,
                settings: {
                    slidesToShow: 3
                }
            },
            {
                breakpoint: 767,
                settings: {
                    slidesToShow: 1
                }
            },
        ]
    };

    const handleProductsByCondition = async () => {
        try {
            const productsByConditionResponse = await fetchProductsByCondition();
            setProductsByCondition(productsByConditionResponse);
        } catch (e) {

        }
    }

    useEffect(() => {
        handleProductsByCondition();
    }, []);

    return (
        <div className={styles.wrapper}>
            <div className={styles.newArrivalsPart}>
                <div className={styles.homeArrivalsSection}>

                    {(homeData.acf.newArrivalsLink.buttonLinkType == 'internal') ? <Link href={UrlReplace(homeData.acf.newArrivalsLink.internalLink)}><h2>{homeData.acf.newArrivalsTitle}</h2></Link> : <a href={homeData.acf.newArrivalsLink.externalLink}><h2>{homeData.acf.newArrivalsTitle}</h2></a>}
                    <p>{homeData.acf.newArrivalsContent}</p>
                    {(homeData.acf.newArrivalsLink.buttonLinkType == 'internal') ? <Link className={styles.viewAll} href={UrlReplace(homeData.acf.newArrivalsLink.internalLink)}>{homeData.acf.newArrivalsLink.buttonText}</Link> : <a href={homeData.acf.newArrivalsLink.externalLink} className={styles.viewAll}>{homeData.acf.newArrivalsLink.buttonText}</a>}

                </div>
            </div>
            <div className={styles.newArrivalProducts + " newArrivalProducts"}>
                <Slider {...settings}>

                    {productsByCondition && productsByCondition.map((productsByConditionItem, index) => {
                        return <div key={index} className={styles.imageBox}>
                            <div className={styles.productBlock}>
                                <Link href={UrlReplace(productsByConditionItem['link'])}>
                                    <Image height={345} width={330} sizes="100vw" src={productsByConditionItem['image']} alt={productsByConditionItem['name']} />
                                </Link>
                                <Link href={UrlReplace(productsByConditionItem['link'])}>
                                    <p>{productsByConditionItem['name']}</p>
                                </Link>
                                <span className={styles.price}>£{productsByConditionItem['price']}</span>
                            </div>
                            <AddToCart product={productsByConditionItem} openModal={openModal} page="home" />
                            {/* <button onClick={() => openModal(productsByConditionItem)} className='common-btn'>{productsByConditionItem['btnText']}</button> */}
                        </div>
                    })}
                </Slider>
            </div>
            <AddToBasket productData={productData} modalIsOpen={modalIsOpen} closeModal={closeModal} />
        </div>
    );
};

export default NewArrival;
