import dynamic from 'next/dynamic'
import React, { useState, useRef, useEffect } from 'react';
import Image from 'next/image'
import { Formik, Form, Field, ErrorMessage, useFormikContext } from 'formik';
import * as Yup from 'yup';
const ReCAPTCHA = dynamic(() => import("react-google-recaptcha"));
import { joinOurNewsletter, fetchPageAcf } from '../../services';
import styles from "styles/components/Staytouch.module.scss";

const StayTouch = ({ page }) => {

  const ref = useRef();

  const [g_recaptcha_response, set_g_recaptcha_response] = useState('');
  const [ReCaptch, SetReCaptch] = useState(null);
  const [buttonText, setButtonText] = useState('SUBSCRIBE');
  const [joinOurNewsletterSuccess, setJoinOurNewsletterSuccess] = useState(null);
  const [recaptchaNeeded, setRecaptchaNeeded] = useState(false);
  const [data, setData] = useState();

  const resetCaptcha = () => {
    ref.current.reset();
    SetReCaptch(null);
    set_g_recaptcha_response('')
  }

  const onChangeCaptchavalue = (value) => {
    SetReCaptch(true);
    set_g_recaptcha_response(value)
    setJoinOurNewsletterSuccess(null)
  }

  const onExpiredCaptchavalue = (value) => {
    SetReCaptch(false);
    set_g_recaptcha_response('')
    setJoinOurNewsletterSuccess(null)
  }

  const NewsletterSchema = Yup.object().shape({
    yourEmail: Yup.string().email('The e-mail address entered is invalid.').required("This field is required.")
  });
  const AutoSubmitToken = () => {
    const { values } = useFormikContext();
    useEffect(() => {
      if (values.yourEmail)
        setRecaptchaNeeded(true)
    }, [values]);
    return null;
  };
  const handleStayTouchApi = async () => {
    const staytouchResponse = await fetchPageAcf("?_fields=acf.stay_in_touch_image,acf.stay_in_touch_title,acf.stay_in_touch_content&slug=" + page);
    if (staytouchResponse) {
      setData(staytouchResponse[0].acf)
    }
  }
  useEffect(() => {
    handleStayTouchApi()
  }, [])
  return (
    <div className={(page == "about" ? styles.contactSection + " " + styles.about : styles.contactSection)} >
      <div className={styles.wrapper}>
        <div className={styles.contactInnerSection}>
          {data && data.stayInTouchImage &&
            <div className={styles.contactLeft}>
              <div className={styles.imagesFixHeight}>
                <Image width={533} height={420} sizes='100vw' className={styles.img + " " + styles.webpexpressProcessed} src={data.stayInTouchImage.url} alt={data.stayInTouchImage.alt} />
              </div>
            </div>
          }
          <div className={styles.contactRight}>
            <div className={styles.formPart}>
              <div className={styles.formOuter}>
                {data && data.stayInTouchTitle && <h2>{data.stayInTouchTitle}</h2>}
                {data && data.stayInTouchContent && <p>{data.stayInTouchContent}</p>}

                <Formik
                  initialValues={{
                    yourEmail: '',
                    firstName: '',
                    lastName: '',
                  }}
                  validationSchema={NewsletterSchema}
                  onSubmit={async (values, { resetForm }) => {

                    setButtonText('Submitting...')
                    if (ReCaptch == true) {
                      const form = new FormData();
                      form.append('first-name', values.firstName);
                      form.append('last-name', values.lastName);
                      form.append('your-email', values.yourEmail);
                      form.append('g-recaptcha-response', g_recaptcha_response);

                      const joinOurNewsletterResponse = await joinOurNewsletter(form);
                      setJoinOurNewsletterSuccess(joinOurNewsletterResponse)
                      setButtonText('SUBSCRIBE')
                      resetCaptcha()
                      resetForm()
                    } else {
                      SetReCaptch(false)
                      setButtonText('SUBSCRIBE')
                      setJoinOurNewsletterSuccess(null)
                    }

                  }} >
                  {({ errors, touched }) => (

                    <Form method="post" className={styles.wpcf7 + " " + styles.js}>
                      <AutoSubmitToken />
                      <div>
                        <div className={styles.inputPart + " " + "half"}>
                          <Field className={styles.input + " " + "input"} name='firstName' placeholder="First Name" />
                          <ErrorMessage component='div' className={styles.formError} name="firstName" />
                        </div>
                        <div className={styles.inputPart + " " + "half"}>
                          <Field className={styles.input + " " + "input"} name='lastName' placeholder="Last Name" />
                          <ErrorMessage component='div' className={styles.formError} name="lastName" />
                        </div>
                        <div className={styles.subscribe}>
                          <Field className={styles.input + " " + "input"} name='yourEmail' placeholder="Your Email Address*" />
                          <ErrorMessage component='div' className={styles.formError} name="yourEmail" />
                          <button type="submit" id="staysubmit" className={styles.buttonSubmitForm + " btn btn-small btn-success"} disabled="">{buttonText}</button>
                        </div>
                      </div>

                      {recaptchaNeeded && <ReCAPTCHA className={styles.capDiv}
                        sitekey='6LcMGWkUAAAAAM5vA9rkbH1rbYyu19H1Nwg8rXet'
                        onChange={onChangeCaptchavalue}
                        onExpired={onExpiredCaptchavalue}
                        ref={ref}
                      />}
                      <div className={styles.formError}>{(ReCaptch == false) ? 'Please verify that you are not a robot.' : ''}</div>

                    </Form>
                  )}
                </Formik>

                {((joinOurNewsletterSuccess) ? <div className={styles.successMsg}>{joinOurNewsletterSuccess.message}</div> : '')}
              </div>
            </div>
          </div>
        </div>
      </div>
    </div>
  );
};

export default StayTouch;
