import React, { useState, useEffect } from 'react';
import Link from 'next/link';
import Image from 'next/image'
import { fetchPageAcf } from '../../services';
import UrlReplace from 'components/Common/UrlReplace';
import styles from 'styles/components/Storemaker.module.scss';

const StoreMaker = ({ page }) => {
  const [data, setData] = useState();
  const handleStoreMakerhApi = async () => {
    const storeResponse = await fetchPageAcf("?_fields=acf.about_block&slug=" + page);
    if (storeResponse) {
      setData(storeResponse[0].acf)
    }
  }
  useEffect(() => {
    handleStoreMakerhApi()
  }, [])
  return (
    <div className={(page == "about" ? styles.ourStorySection + " " + styles.about : styles.ourStorySection)}>
      <div className={styles.wrapper}>
        <div className={styles.bgColorSection}>
          <div className={styles.threeBlockSection}>

            {data && data.aboutBlock && data.aboutBlock.map((aboutBlockItem, index) => {

              return <div key={index} className={styles.mainBlock}>
                <div className={styles.block}>


                  {
                    (page == "about") ?

                      <>
                        <div className={styles.imagePart}>
                          {(aboutBlockItem.pageLink.buttonLinkType == 'internal') ?
                            <Link href={UrlReplace(aboutBlockItem.pageLink.internalLink)} className={styles.imageHoverLink}>
                              <Image width={258} height={335} sizes="100vw" className={styles.img} src={aboutBlockItem.sectionImage.sizes.homeAboutBlogsImage} alt={"General-Image-" + (Number(index + 1))} />
                            </Link> :
                            <a href={aboutBlockItem.pageLink.externalLink} target="_blank" className={styles.imageHoverLink}>
                              <Image width={258} height={335} sizes="100vw" className={styles.img} src={aboutBlockItem.sectionImage.sizes.homeAboutBlogsImage} alt={"General-Image-" + (Number(index + 1))} />
                            </a>
                          }
                        </div>
                        <div className={styles.textPart}>
                          {(aboutBlockItem.pageLink.buttonLinkType == 'internal') ?
                            <Link href={UrlReplace(aboutBlockItem.pageLink.internalLink)}>
                              <h2>{aboutBlockItem.pageLink.buttonText}</h2>
                            </Link> :
                            <a href={aboutBlockItem.pageLink.externalLink} target="_blank">
                              <h2>{aboutBlockItem.pageLink.buttonText}</h2>
                            </a>
                          }
                          <p>{aboutBlockItem.content}</p>
                        </div>
                      </>
                      : <>
                        <div className={styles.imagePart}>
                          {(aboutBlockItem.blockLink.buttonLinkType == 'internal') ?
                            <Link href={UrlReplace(aboutBlockItem.blockLink.internalLink)} className={styles.imageHoverLink}>
                              <Image width={258} height={335} sizes="100vw" className={styles.img} src={aboutBlockItem.blockImage.sizes.homeAboutBlogsImage} alt={"General-Image-" + (Number(index + 1))} />
                            </Link> :
                            <a href={aboutBlockItem.blockLink.externalLink} target="_blank" className={styles.imageHoverLink}>
                              <Image width={258} height={335} sizes="100vw" className={styles.img} src={aboutBlockItem.blockImage.sizes.homeAboutBlogsImage} alt={"General-Image-" + (Number(index + 1))} />
                            </a>
                          }
                        </div>
                        <div className={styles.textPart}>
                          {(aboutBlockItem.blockLink.buttonLinkType == 'internal') ?
                            <Link href={UrlReplace(aboutBlockItem.blockLink.internalLink)}>
                              <h2>{aboutBlockItem.blockLink.buttonText}</h2>
                            </Link> :
                            <a href={aboutBlockItem.blockLink.externalLink} target="_blank">
                              <h2>{aboutBlockItem.blockLink.buttonText}</h2>
                            </a>
                          }
                          <p>{aboutBlockItem.blockContent}</p>
                        </div>
                      </>}
                </div>
              </div>

            })}

          </div>
        </div>
      </div>
    </div>
  );
};

export default StoreMaker;
