import React, { useEffect, useState } from "react";
import Image from "next/image";
import Cookies from "js-cookie";
import styles from "../Header/Header.module.scss";
import EngSvg from "../../../public/images/en.svg";
import ChinaSvg from "../../../public/images/zh-CN.svg";
import FranceSvg from "../../../public/images/fr.svg";
import GermanSvg from "../../../public/images/de.svg";
import JapanSvg from "../../../public/images/ja.svg";
import PortSvg from "../../../public/images/pt.svg";
import SpainSvg from "../../../public/images/es.svg";
const LanguageDropdown = () => {
  const [isToggleDropdown, setIsToggleDropdown] = useState(false);


  const googleTranslateElementInit = () => {
    // setCookie('googtrans', '/en', 1);
    new window.google.translate.TranslateElement(
      {
        pageLanguage: "en",
        includedLanguages: 'en,zh-CN,fr,de,ja,pt,es',
        layout: window.google.translate.TranslateElement.InlineLayout.SIMPLE,
        autoDisplay: true,
        multilanguagePage: true
      }, 'google_translate_element')
  }
  const handleTranslateChange = (lang) => {
    Cookies.remove('googtrans')
    setCookie('googtrans', '/en/' + lang, 1);

    //triggerHtmlEvent(lang, 'change')
    window.location.reload()
  }
  function setCookie(key, value, expiry) {
    var expires = new Date();
    expires.setTime(expires.getTime() + expiry * 24 * 60 * 60 * 1000);
    document.cookie = key + "=" + value + ";expires=" + expires.toUTCString();
  }
  const langToggleDropdown = (val) => {
    setIsToggleDropdown(val);
  };
  useEffect(() => {
    setTimeout(() => {
      var addScript = document.createElement("script");
      addScript.setAttribute("src", "//translate.google.com/translate_a/element.js?cb=googleTranslateElementInit");
      document.body.appendChild(addScript);
      window.googleTranslateElementInit = googleTranslateElementInit;
    }, 7000)
  }, []);

  return (
    <div
      className={isToggleDropdown ? styles.language + " " + styles.dropOpen : styles.language}
      onClick={() => langToggleDropdown(!isToggleDropdown)}
    >
      {Cookies.get("googtrans") == "/en/zh-CN" ? (
        <a className={styles.selectedLang}><Image height={24} width={24} src={ChinaSvg} alt="Chinese Flag" />Chinese (Simplified)</a>
      ) : Cookies.get("googtrans") == "/en/fr" ? (
        <a className={styles.selectedLang}><Image height={24} width={24} src={FranceSvg} alt="France Flag" />French</a>
      ) : Cookies.get("googtrans") == "/en/de" ? (
        <a className={styles.selectedLang}>
          <Image height={24} width={24} src={GermanSvg} alt="German Flag" />
          German
        </a>
      ) : Cookies.get("googtrans") == "/en/ja" ? (
        <a className={styles.selectedLang}>
          <Image height={24} width={24} src={JapanSvg} alt="Japan Flag" />
          Japanese
        </a>
      ) : Cookies.get("googtrans") == "/en/pt" ? (
        <a className={styles.selectedLang}>
          <Image height={24} width={24} src={PortSvg} alt="Port Flag" />
          Portuguese
        </a>
      ) : Cookies.get("googtrans") == "/en/es" ? (
        <a className={styles.selectedLang}>
          <Image height={24} width={24} src={SpainSvg} alt="Spain Flag" />
          Spanish
        </a>
      ) : (
        <a className={styles.selectedLang} data-lang="en">
          <Image height={24} width={24} src={EngSvg} alt="Eng Flag" />
          English
        </a>
      )}

      <div className={styles.languageInnerBlock}>
        <div className={styles.translationLinks + " " + styles.notranslate}>
          {!Cookies.get("googtrans") ||
            (Cookies.get("googtrans") !== "/en/en" && (
              <a className="english" onClick={() => { handleTranslateChange("en"); }} data-lang="en">
                <Image height={24} width={24} src={EngSvg} alt="Eng Flag" />
                English
              </a>
            ))}
          {Cookies.get("googtrans") !== "/en/zh-CN" && (
            <a className="english" onClick={() => { handleTranslateChange("zh-CN"); }} data-lang="zh-CN">
              <Image height={24} width={24} src={ChinaSvg} alt="Chinese Flag" />
              Chinese (Simplified)
            </a>
          )}
          {Cookies.get("googtrans") !== "/en/fr" && (
            <a className="spanish" onClick={() => { handleTranslateChange("fr"); }} data-lang="fr">
              <Image height={24} width={24} src={FranceSvg} alt="France Flag" />
              French
            </a>
          )}
          {Cookies.get("googtrans") !== "/en/de" && (
            <a className="french" onClick={() => { handleTranslateChange("de"); }} data-lang="de">
              <Image height={24} width={24} src={GermanSvg} alt="German Flag" />
              German
            </a>
          )}
          {Cookies.get("googtrans") !== "/en/ja" && (
            <a className="german" onClick={() => { handleTranslateChange("ja"); }} data-lang="ja">
              <Image height={24} width={24} src={JapanSvg} alt="Japan Flag" />
              Japanese
            </a>
          )}
          {Cookies.get("googtrans") !== "/en/pt" && (
            <a className="german" onClick={() => { handleTranslateChange("pt"); }} data-lang="pt">
              <Image height={24} width={24} src={PortSvg} alt="Port Flag" />
              Portuguese
            </a>
          )}
          {Cookies.get("googtrans") !== "/en/es" && (
            <a className="german" onClick={() => { handleTranslateChange("es"); }} data-lang="es">
              <Image height={24} width={24} src={SpainSvg} alt="Spain Flag" />
              Spanish
            </a>
          )}
        </div>
        {/* <div id="google_translate_element"></div> */}
      </div>
    </div>
  )
}
export default LanguageDropdown;