import React, { useEffect, useState } from "react";
import Image from "next/image";
import Link from "next/link";
import { useDispatch, useSelector } from "react-redux";
import { pendingCart, getCart } from "../../reducer/woocommerceSlice";
import storeApi from "../../helper/StoreApi";
import styles from "../Header/Header.module.scss";
import UrlReplace from "../Common/UrlReplace";

import CartIcon from "../../../public/images/cart-icon.svg";

const MiniCart = () => {
  const dispatch = useDispatch();
  const [isPending, setIsPending] = useState(false);
  const [removeProductId, setRemoveProductId] = useState("");
  const { cart } = useSelector((state) => state.woocommerce);
  const removeItemFromCart = async (item) => {
    setIsPending(true);
    setRemoveProductId(item.id);
    dispatch(pendingCart());
    const getcartResponse = await storeApi({ endpoint: "cart/remove-item", method: "POST", params: { key: item.key } });
    dispatch(getCart(getcartResponse));
    setIsPending(false);
  };
  const getCartReady = async () => {
    dispatch(pendingCart());
    const getcartResponse = await storeApi({ endpoint: "cart", method: "GET" });
    dispatch(getCart(getcartResponse));
  };
  useEffect(() => {
    getCartReady();
  }, []);
  return (
    <div className={cart.items_count > 0 ? styles.cartIcon + " " + styles.cartCounterSpace : styles.cartIcon}>
      <Link href="/basket" className="dropdown-back" data-toggle="dropdown">
        <Image src={CartIcon} width={20} height={19} alt="cart-icon" />
        <div className={styles.basketItemCount} style={{ display: "inline" }}>
          {cart.items_count > 0 ? (
            <span className={styles.cartItemsCount + " " + styles.count} id="cart-count-auto">
              {cart && cart.items_count}
            </span>
          ) : (
            ""
          )}
        </div>
      </Link>
      <ul className={styles.dropdownMenu + " " + styles.dropdownMenuMiniCart}>
        <li>
          <div className={styles.widgetShoppingCartContent}>
            {cart.items_count == 0 ? (
              <p className={styles.woocommerceMiniCartEmptyMessage}>No products in the basket.</p>
            ) : (
              <>
                <ul className={styles.woocommerceMiniCart + " " + styles.cartList + " " + styles.productListWidget}>
                  {cart &&
                    cart.items &&
                    cart.items.map((cartItem, index) => {
                      return (
                        <li
                          key={index}
                          className={
                            isPending && removeProductId == cartItem.id
                              ? styles.woocommerceMiniCartItem + " " + styles.miniCartItem + " " + styles.processing
                              : styles.woocommerceMiniCartItem + " " + styles.miniCartItem
                          }
                        >
                          <span className={styles.wpcf7Spinner}></span>
                          <a
                            onClick={() => removeItemFromCart(cartItem)}
                            className={styles.remove + " " + styles.removeFromCartButton}
                          >
                            ×
                          </a>
                          <Link href={UrlReplace(cartItem.permalink)}>
                            <Image
                              width={418}
                              height={760}
                              src={cartItem.images[0].src}
                              className="attachment-woocommerce_thumbnail size-woocommerce_thumbnail"
                              alt=""
                              decoding="async"
                              loading="lazy"
                            />
                            <span>{cartItem.name}</span>
                          </Link>
                          <span className={styles.quantity}>
                            {cartItem.quantity} ×
                            <span className={styles.woocommercePriceamount + " " + styles.amount}>
                              <bdi>
                                <span className={styles.woocommercePricecurrencySymbol}>
                                  {cartItem.totals.currency_symbol}
                                </span>
                                {cartItem.totals.line_total}
                              </bdi>
                            </span>
                          </span>
                        </li>
                      );
                    })}
                </ul>
                <p className={styles.woocommerceMiniCartTotal + " " + styles.total}>
                  <strong>Subtotal:</strong>
                  <span className={styles.woocommercePriceamount + " " + styles.amount}>
                    <span className={styles.woocommercePricecurrencySymbol}>
                      {cart && cart.totals && cart.totals.currency_symbol + cart.totals.total_items}
                    </span>
                  </span>
                </p>
                <p className={styles.woocommerceMiniCartButtons + " " + styles.Buttons}>
                  <Link
                    href="/basket"
                    className={styles.button + " " + styles.wcForward + " " + styles.wpElementButton}
                  >
                    View basket
                  </Link>
                  <Link
                    href="/checkout"
                    className={
                      styles.button + " " + styles.wcForward + " " + styles.wpElementButton + " " + styles.checkout
                    }
                  >
                    Checkout
                  </Link>
                </p>
              </>
            )}
          </div>
        </li>
      </ul>
    </div>
  );
};
export default MiniCart;
