import React, { useEffect, useState, useRef } from "react";
import { Formik, Form, Field, ErrorMessage, useFormikContext } from "formik";
import * as Yup from "yup";
import Image from "next/image";
import ReCAPTCHA from "react-google-recaptcha";
import { submitContactFormWithId } from "../../services";
//import '../../styles/shop/enquireproduct.scss';
//import '../../styles/home/staytouch.scss';
import styles from "../../styles/shop/EnquireProduct.module.scss";
import { fetchOptionByParams } from "../../services"

const EnquireProduct = ({ productsData }) => {

  const ref = useRef();

  const [g_recaptcha_response, set_g_recaptcha_response] = useState("");
  const [ReCaptch, SetReCaptch] = useState(null);
  const [buttonText, setButtonText] = useState("Send Message");
  const [buttonTextSecond, setButtonTextSecond] = useState("Save Alert");
  const [contactFormSuccess, setContactFormSuccess] = useState(null);
  const [recaptchaNeeded, setRecaptchaNeeded] = useState(false);
  const [optionData, setOptionData] = useState(null);
  const handleOptionApi = async () => {
    const optionResponse = await fetchOptionByParams("acf.delivery_details,acf.about_william_walter_antiques,acf.how_to_buy,acf.product_enquire_form,acf.product_page_form_1");
    if (optionResponse) {
      setOptionData(optionResponse)
    }
  }

  const resetCaptcha = () => {
    ref.current.reset();
    SetReCaptch(null);
    set_g_recaptcha_response("");
  };

  const onChangeCaptchavalue = (value) => {
    SetReCaptch(true);
    set_g_recaptcha_response(value);
    setContactFormSuccess(null);
  };

  const onExpiredCaptchavalue = () => {
    SetReCaptch(false);
    set_g_recaptcha_response("");
    setContactFormSuccess(null);
  };

  const contactFormSchema = Yup.object().shape({
    firstName: Yup.string().required("This field is required."),
    lastName: Yup.string().required("This field is required."),
    yourEmail: Yup.string().email("The e-mail address entered is invalid.").required("This field is required."),
  });

  const contactFormSecondSchema = Yup.object().shape({
    yourEmail: Yup.string().email("The e-mail address entered is invalid.").required("This field is required."),
  });
  const AutoSubmitToken = () => {
    const { values } = useFormikContext();
    React.useEffect(() => {
      if (values.yourEmail)
        setRecaptchaNeeded(true)
    }, [values]);
    return null;
  };
  useEffect(() => {
    handleOptionApi();
  }, [])
  return productsData.length > 0 ? (
    <section className={styles.root}>
      <div className={styles.contactSection + " " + styles.enquireProduct} id="contact-form">
        <div className={styles.wrapper}>
          <div className={styles.contactInnerSection}>
            {optionData &&
              <div className={styles.contactLeft}>
                <div className={styles.imagesFixHeight}>
                  <Image
                    height={200}
                    width={200}
                    sizes="100vw"
                    className={styles.img + " " + styles.webpexpressProcessed}
                    src={optionData.acf.productEnquireForm.stayInTouchImage.sizes.woocommerceSingle}
                    alt={optionData.acf.productEnquireForm.stayInTouchImage.alt}
                  />
                </div>
              </div>
            }
            <div className={styles.contactRight}>
              <div className={styles.formPart}>
                {optionData &&
                  <div className={styles.formOuter}>
                    <h2>
                      {productsData[0].stockStatus == "outofstock"
                        ? optionData.acf.productPageForm1.stayInTouchTitle
                        : optionData.acf.productEnquireForm.stayInTouchTitle}
                    </h2>
                    <p>
                      {productsData[0].stockStatus == "outofstock"
                        ? optionData.acf.productPageForm1.stayInTouchContent
                        : optionData.acf.productEnquireForm.stayInTouchContent}
                    </p>
                  </div>
                }
                <div className="wpcf7 js" id="wpcf7-f309-p17724-o1" lang="en-US" dir="ltr">
                  <div className="screen-reader-response">
                    <p role="status" aria-live="polite" aria-atomic="true" />
                  </div>
                  {productsData[0].stockStatus == "outofstock" ? (
                    <Formik
                      initialValues={{
                        firstName: "",
                        lastName: "",
                        yourEmail: "",
                        receiveMail: "",
                        productPermalink: productsData[0].permalink.replace(
                          process.env.ADMIN_URL + "/",
                          process.env.SITE_URL,
                        ),
                        productTitle: productsData[0].name,
                      }}
                      validationSchema={contactFormSecondSchema}
                      onSubmit={async (values, { resetForm }) => {
                        setButtonTextSecond("Saving...");
                        if (ReCaptch == true) {
                          const form = new FormData();
                          form.append("first-name", values.firstName);
                          form.append("last-name", values.lastName);
                          form.append("your-email", values.yourEmail);
                          if (values.receiveMail != "") {
                            form.append("receive-mail[]", values.receiveMail);
                          }
                          form.append("product-title", values.productTitle);
                          form.append("product-permalink", values.productPermalink);
                          form.append("g-recaptcha-response", g_recaptcha_response);

                          const joinOurNewsletterResponse = await submitContactFormWithId(303, form);
                          setContactFormSuccess(joinOurNewsletterResponse);
                          setButtonTextSecond("Save Alert");
                          resetCaptcha();
                          resetForm();
                        } else {
                          SetReCaptch(false);
                          setButtonTextSecond("Save Alert");
                          setContactFormSuccess(null);
                        }
                      }}
                    >
                      {() => (
                        <Form method="post" className="wpcf7 js save-alert">
                          <AutoSubmitToken />
                          <div className="input-block">
                            <div className="input-part half">
                              <p>
                                <Field name="firstName" placeholder="First Name" className="input" />
                                <ErrorMessage component="div" className={styles.formError + " formError"} name="firstName" />
                              </p>
                            </div>
                            <div className="input-part half">
                              <p>
                                <Field name="lastName" placeholder="Last Name" className="input" />
                                <ErrorMessage component="div" className={styles.formError + " formError"} name="lastName" />
                              </p>
                            </div>
                            <div className="input-part">
                              <p>
                                <Field name="yourEmail" placeholder="Your Email Address" className="input" />
                                <ErrorMessage component="div" className={styles.formError + " formError"} name="yourEmail" />
                              </p>
                            </div>

                            <div className="input-part checkbox">
                              <p>
                                <Field
                                  type="checkbox"
                                  name="receiveMail"
                                  value="I consent to receive future marketing"
                                />
                                <label className="wpcf7-list-item-label" for="receiveMail">
                                  I consent to receive future marketing
                                </label>
                                <ErrorMessage component="div" className={styles.formError + " formError"} name="receiveMail" />
                              </p>
                            </div>
                            {recaptchaNeeded &&
                              <ReCAPTCHA
                                className="cap-div"
                                sitekey="6LcMGWkUAAAAAM5vA9rkbH1rbYyu19H1Nwg8rXet"
                                onChange={onChangeCaptchavalue}
                                onExpired={onExpiredCaptchavalue}
                                ref={ref}
                              />
                            }
                            <div className="sumbit_button">
                              <p>
                                <button className="wpcf7-form-control has-spinner wpcf7-submit button" type="submit">
                                  {buttonTextSecond}
                                </button>
                              </p>
                            </div>
                          </div>

                          <div className={styles.formError + " formError"}>
                            {ReCaptch == false ? "Please verify that you are not a robot." : ""}
                          </div>
                        </Form>
                      )}
                    </Formik>
                  ) : (
                    <Formik
                      initialValues={{
                        firstName: "",
                        lastName: "",
                        yourEmail: "",
                        yourPhone: "",
                        yourMessage: "",
                        productPermalink: productsData[0].permalink.replace(
                          process.env.ADMIN_URL + "/",
                          process.env.SITE_URL,
                        ),
                        productTitle: productsData[0].name,
                      }}
                      validationSchema={contactFormSchema}
                      onSubmit={async (values, { resetForm }) => {
                        setButtonText("Sending...");
                        if (ReCaptch == true) {
                          const form = new FormData();
                          form.append("first-name", values.firstName);
                          form.append("last-name", values.lastName);
                          form.append("your-email", values.yourEmail);
                          form.append("your-phone", values.yourPhone);
                          form.append("your-message", values.yourMessage);
                          form.append("product-title", values.productTitle);
                          form.append("product-permalink", values.productPermalink);
                          form.append("g-recaptcha-response", g_recaptcha_response);

                          const joinOurNewsletterResponse = await submitContactFormWithId(309, form);
                          setContactFormSuccess(joinOurNewsletterResponse);
                          setButtonText("Send Message");
                          resetCaptcha();
                          resetForm();
                        } else {
                          SetReCaptch(false);
                          setButtonText("Send Message");
                          setContactFormSuccess(null);
                        }
                      }}
                    >
                      {() => (
                        <Form method="post" className="wpcf7 js">
                          <AutoSubmitToken />
                          <div className="input-block">
                            <div className="input-part half">
                              <p>
                                <Field name="firstName" placeholder="First Name" className="input" />
                                <ErrorMessage component="div" className={styles.formError + " formError"} name="firstName" />
                              </p>
                            </div>
                            <div className="input-part half">
                              <p>
                                <Field name="lastName" placeholder="Last Name" className="input" />
                                <ErrorMessage component="div" className={styles.formError + " formError"} name="lastName" />
                              </p>
                            </div>
                            <div className="input-part">
                              <p>
                                <Field name="yourEmail" placeholder="Your Email Address" className="input" />
                                <ErrorMessage component="div" className={styles.formError + " formError"} name="yourEmail" />
                              </p>
                            </div>
                            <div className="input-part">
                              <p>
                                <Field name="yourPhone" placeholder="Your Phone Number" className="input" />
                                <ErrorMessage component="div" className={styles.formError + " formError"} name="yourPhone" />
                              </p>
                            </div>
                            <div className="input-part">
                              <p>
                                <Field name="yourMessage" placeholder="Your Message" as="textarea" rows="3" />
                                <ErrorMessage component="div" className={styles.formError + " formError"} name="yourMessage" />
                              </p>
                            </div>
                            {recaptchaNeeded &&
                              <ReCAPTCHA
                                className="cap-div"
                                sitekey="6LcMGWkUAAAAAM5vA9rkbH1rbYyu19H1Nwg8rXet"
                                onChange={onChangeCaptchavalue}
                                onExpired={onExpiredCaptchavalue}
                                ref={ref}
                              />
                            }
                            <div className="sumbit_button">
                              <p>
                                <button className="wpcf7-form-control has-spinner wpcf7-submit button" type="submit">
                                  {buttonText}
                                </button>
                              </p>
                            </div>
                          </div>

                          <div className="formError">
                            {ReCaptch == false ? "Please verify that you are not a robot." : ""}
                          </div>
                        </Form>
                      )}
                    </Formik>
                  )}

                  {contactFormSuccess ? <div className="success-msg">{contactFormSuccess.message}</div> : ""}
                </div>
              </div>
            </div>
          </div>
        </div>
      </div>
    </section>
  ) : "";
};

export default EnquireProduct;
