import React,{useEffect,useState} from "react";
import axios from "axios";
import Link from "next/link";
import UrlReplace from "../Common/UrlReplace";
import Image from "next/image";
import styles from "../../styles/shop/ProductContact.module.scss";

const ProductContact = () => {
  const [optionData,setOptionData] = useState();
  useEffect(()=>{
    if(!optionData){
      axios.get(process.env.API_URL + 'acf/v3/options/options?_fields=acf.contact_us_image,acf.contact_us_title,acf.contact_us_short_content,acf.contact_us_button')
      .then(function (response) {
        setOptionData(response.data)
      })      
    }  
  },[])
  return optionData?(
    <div className={styles.root}>
      <div className={styles.contactSection + " " + styles.productCat}>
        <div className={styles.wrapper}>
          <div className={styles.contactInnerSection}>
            <div className={styles.contactLeft}>
              <div className={styles.imagesFixHeight}>
                <Image
                  width={200}
                  height={200}
                  sizes="100vw"
                  className={styles.img + " " + styles.webpexpressProcessed}
                  src={optionData.acf.contact_us_image.url}
                  alt={optionData.acf.contact_us_image.alt}
                />
              </div>
            </div>
            <div className={styles.contactRight}>
              <div className={styles.formPart}>
                <div className={styles.formOuter}>
                  <h2>{optionData.acf.contact_us_title}</h2>
                  <p>{optionData.acf.contact_us_short_content}</p>
                </div>
                {optionData.acf.contact_us_button.button_link_type == "internal" ? (
                  <Link href={UrlReplace(optionData.acf.contact_us_button.internal_link)}>
                    {optionData.acf.contact_us_button.button_text}
                  </Link>
                ) : (
                  <a target="_blank" href={optionData.acf.contact_us_button.external_link}>
                    {optionData.acf.contact_us_button.button_text}
                  </a>
                )}
              </div>
            </div>
          </div>
        </div>
      </div>
    </div>
  ):"";
};

export default ProductContact;
