import React, { useState, useEffect } from 'react';
import Link from 'next/link';
import Image from 'next/image';
import Slider from "react-slick";
//import ImageLightbox from 'react-image-lightbox';
//import 'react-image-lightbox/style.css';
import Lightbox from "yet-another-react-lightbox";
import Captions from "yet-another-react-lightbox/plugins/captions";
import Video from "yet-another-react-lightbox/plugins/video";
import { InlineShareButtons } from 'sharethis-reactjs';
import Breadcrumb from '../../components/Common/breadcrumb';
import AddToBasket from '../popup/AddToBasket';
import AddToCart from '../Common/AddToCart';
import VisaIcon from '../../assets/visa.svg';
import MasterIcon from '../../assets/Mastercard.svg';
import AmericanIcon from '../../assets/BlueBox.svg';
import FullScreen from '../../assets/full-screen-arrow.svg';
import "slick-carousel/slick/slick.css";
import "slick-carousel/slick/slick-theme.css";
import styles from '../../styles/shop/ProductFullDetails.module.scss';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome'
import { faPrint } from '@fortawesome/free-solid-svg-icons';
import "yet-another-react-lightbox/styles.css";

const ProductFullDetails = ({ productsData }) => {

    const [productsModalData, setProductSModalData] = useState([]);
    const [modalIsOpen, setIsOpen] = useState(false);

    function openModal(productItemObj) {
        setProductSModalData(productItemObj)
        setIsOpen(true);
    }

    function closeModal() {
        setIsOpen(false);
    }


    const OnlyShareThis = (productsData) => {

        return (
            <InlineShareButtons
                config={{
                    alignment: 'center',
                    color: 'social',
                    enabled: true,
                    font_size: 15,
                    labels: 'cta',
                    language: 'en',
                    networks: [
                        'twitter',
                        'facebook',
                        'sharethis',
                    ],
                    padding: 10,
                    radius: 0,
                    show_total: true,
                    size: 40,
                    url: (productsData.permalink.replace(process.env.ADMIN_URL + '/', process.env.SITE_URL)),
                    image: '',
                    description: productsData.shortDescription,
                    title: productsData.name,
                    message: productsData.shortDescription,
                    subject: productsData.name,
                }}
            />
        )
    }

    const [nav1, setNav1] = useState(null);
    const [nav2, setNav2] = useState(null);
    const [slider1, setSlider1] = useState(null);
    const [slider2, setSlider2] = useState(null);

    useEffect(() => {
        setNav1(slider1);
        setNav2(slider2);
    }, []);


    const [lightboxOpen, setLightboxOpen] = useState(false);
    const [selectedImage, setSelectedImage] = useState(0);
    const settingsMain = {
        slidesToShow: 1,
        slidesToScroll: 1,
        arrows: false,
        asNavFor: '.slider-nav',
    };

    const settingsThumbs = {
        slidesToShow: 3,
        slidesToScroll: 1,
        asNavFor: '.slider-for',
        dots: false,
        swipeToSlide: true,
        focusOnSelect: true,
        infinite: false

    };

    const openLightbox = (index) => {
        setSelectedImage(index);
        setLightboxOpen(true);
    };

    return ((productsData.length > 0) ?
        <section className={styles.root}>
            <div className='about-product'>
                <div className={styles.wrapper}>
                    {((productsData[0].categories && productsData[0].categories.length >= 2) ?
                        <Breadcrumb breadcrumbMenu={
                            [
                                { title: "Home", link: '/' },
                                { title: productsData[0].categories[productsData[0].categories.length - 1].name, link: '/shop/' + productsData[0].categories[productsData[0].categories.length - 1].slug + '/' },
                                { title: productsData[0].categories[productsData[0].categories.length - 2].name, link: '/shop/' + productsData[0].categories[productsData[0].categories.length - 1].slug + '/' + productsData[0].categories[productsData[0].categories.length - 2].slug + '/' },
                                { title: productsData[0].name, link: '' }
                            ]} /> : '')
                    }
                    <div className='product-detail-main'>
                        <div className='left-content'>
                            <div className="slider-wrapper">
                                <Slider
                                    {...settingsMain}
                                    asNavFor={nav2}
                                    ref={slider => (setSlider1(slider))}
                                >
                                    {productsData[0].images.map((imageItem, index) => (
                                        <>
                                            <div className='img-box' key={index} onClick={() => openLightbox(index)}>
                                                <Image width={518} height={610} sizes="100vw" src={imageItem.src} alt={imageItem.name} priority />
                                            </div>
                                            <a onClick={() => openLightbox(index)} className='fullscreen-icon'><Image src={FullScreen} alt='full-screen' width={20} height={20} /></a>
                                        </>

                                    ))}
                                </Slider>
                                {lightboxOpen && <Lightbox
                                    open={lightboxOpen}
                                    close={() => setLightboxOpen(false)}
                                    slides={productsData[0].images}
                                    index={selectedImage}
                                    plugins={[Captions, Video]}
                                />}
                                <div className="thumbnail-slider-wrap">
                                    <Slider
                                        {...settingsThumbs}
                                        asNavFor={nav1}
                                        ref={slider => (setSlider2(slider))}>
                                        {productsData[0].images.map((imageInnerItem, index) => (
                                            <Image width={96} height={91} key={index} src={imageInnerItem.src} alt={imageInnerItem.name} />
                                        ))}
                                    </Slider>
                                </div>
                            </div>
                        </div>
                        <div className='right-content'>
                            <div className="summary entry-summary">
                                <div className="fixed-block">
                                    {((productsData[0].stockStatus == "outofstock") ? <p className="sticker">Item Sold</p> : '')}
                                    <h1 className="product_title entry-title">{productsData[0].name}</h1>
                                    <p className="price"><span className="woocommerce-Price-amount amount">
                                        <bdi><span className="woocommerce-Price-currencySymbol">{((productsData[0].stockStatus == "outofstock") ? 'Sold' : '£' + productsData[0].price)}</span></bdi></span>
                                    </p>
                                    {
                                        ((productsData[0].maker.length > 0) ? <div className="maker"><span className="maker-label">Maker: </span>
                                            <Link href={"/maker/" + productsData[0].maker[0].slug}><span dangerouslySetInnerHTML={{ __html: productsData[0].maker[0].name }}></span></Link>
                                        </div> : '')
                                    }

                                    <div className="table-section pagebreak">
                                        <div dangerouslySetInnerHTML={{ __html: productsData[0].shortDescription }}></div>
                                        <table cellSpacing={0} cellPadding={0}>
                                            <tbody>
                                                <tr>
                                                    <td>Date</td>
                                                    <td>{productsData[0].acf.productDateFrom}</td>
                                                </tr>
                                                {((productsData[0].maker.length > 0) ?
                                                    <tr>
                                                        <td>Made By</td>
                                                        <td><Link href={"/maker/" + productsData[0].maker[0].slug}><span dangerouslySetInnerHTML={{ __html: productsData[0].maker[0].name }}></span></Link></td>
                                                    </tr> : '')}
                                                <tr>
                                                    <td>Location</td>
                                                    <td>{productsData[0].acf.productCountry}</td>
                                                </tr>
                                                <tr>
                                                    <td>Stock Number</td>
                                                    <td>{productsData[0].sku}</td>
                                                </tr>
                                            </tbody>
                                        </table>
                                    </div>
                                    <div className="social-icon">
                                        <ul>
                                            <h4>Share With a Friend</h4>
                                            <div className='share-icons'> {OnlyShareThis(productsData[0])} </div>
                                        </ul>
                                        <ul>
                                            <h4>Print PDF</h4>
                                            <li><button type='button' onClick={() => window.print()}><FontAwesomeIcon icon={faPrint} /></button></li>
                                        </ul>
                                    </div>
                                    <div className="cart single-produact-details">
                                        {/* <div className="quantity">
                                            <label className="screen-reader-text" htmlFor="quantity_644070c0a67c1">Antique Silver Victorian Claret Jug made in 1891 quantity</label>
                                            <input type="hidden" id="quantity_644070c0a67c1" className="input-text qty text" name="quantity" defaultValue={1} title="Qty" size={4} min={1} max={1} step={1} placeholder inputMode="numeric" autoComplete="off" />
                                        </div> */}
                                        {((productsData[0].acf.buyingOptions && productsData[0].acf.buyingOptions.includes('allow_buy_online')) ? <AddToCart product={productsData[0]} openModal={openModal} page="detail" /> : '')}
                                        {((productsData[0].acf.buyingOptions && productsData[0].acf.buyingOptions.includes('allow_enquire_online')) ? <a href="#contact-form" className="button enquire_only_btn" style={{}}>ENQUIRE ABOUT THIS PIECE </a> : '')}
                                    </div>
                                    <div className="payment-card-container">
                                        <div className="payment-card-wrap">
                                            <Image width={20} height={20} src={VisaIcon} className="img-visa" alt="icon" />
                                            <Image width={20} height={20} src={MasterIcon} className="img-ms" alt="icon" />
                                            <Image width={20} height={20} src={AmericanIcon} className="img-bb" alt="icon" />
                                        </div>
                                    </div>
                                    <div className="product_meta">
                                        <div className="product-custom-mata">
                                            <div className="woocommerce-sku">{productsData[0].sku}</div>
                                            <div className="product-date-label">
                                                Date:
                                                <div className="woocommerce-sku">{productsData[0].acf.productDateFrom} </div>
                                            </div>
                                            {((productsData[0].maker.length > 0) ?
                                                <div className="maker"><span className="maker-label">Maker: </span><span dangerouslySetInnerHTML={{ __html: productsData[0].maker[0].name }}></span></div> : '')}
                                            <div className="price"><span className="woocommerce-Price-amount amount"><bdi><span className="woocommerce-Price-currencySymbol">£</span>{productsData[0].price}</bdi></span></div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <AddToBasket productData={productsModalData} modalIsOpen={modalIsOpen} closeModal={closeModal} />
            </div>
        </section> : ''
    );
};

export default ProductFullDetails;
