import React, { useEffect, useState } from "react";
import Link from "next/link";
import Image from "next/image";
import { useDispatch } from "react-redux";
import { fetchProductFilters, fetchProductLists } from "../../services";
import { categoriesSuccess } from "../../reducer/productCategoriesSlice";
import UrlReplace from "../Common/UrlReplace";
import AddToCart from "../Common/AddToCart";
import AddToBasket from "../popup/AddToBasket";
import roundloader from "../../assets/round-loader.svg";
import PreviousIcon from "../../assets/slider-arrow-left.svg";
import NextIcon from "../../assets/slider-arrow.svg";
import { useRouter } from "next/router";
//import '../../styles/shop/productlistingmain.scss';

import styles from "../../styles/shop/ProductListingMain.module.scss";
import ExpandMoreIcon from "@mui/icons-material/ExpandMore";
import Accordion from "@mui/material/Accordion";
import AccordionDetails from "@mui/material/AccordionDetails";
import Typography from "@mui/material/Typography";
import AccordionSummary from "@mui/material/AccordionSummary";
import { Range, getTrackBackground } from "react-range";
import "react-range-slider-input/dist/style.css";

export default function ProductListing(props) {
  const router = useRouter();
  const dispatch = useDispatch();
  const category_slug = router.query.slug ? router.query.slug[0] : "all";
  const sub_category_slug = router.query.slug ? router.query.slug[1] : "all";
  const [values, setValues] = useState([]);
  const [isActive, setActive] = useState("grid");
  const [isLoading, setIsLoading] = useState(true);
  const [xWpTotal, setXWpTotal] = useState(0);
  const [xWpTotalpages, setXWpTotalpages] = useState(0);
  const [perPage, setPerPage] = useState(12);
  const [productsData, setProductsData] = useState([]);
  const [currentPage, setCurrentPage] = useState(1);
  const [refreshComponet, setRefreshComponet] = useState("");
  const [orderType, setOrderType] = useState("desc");
  const [orderKey, setOrderKey] = useState("date");
  const [filtersData, setFiltersData] = useState([]);
  const [isFiltersLoading, setIsFiltersLoading] = useState(false);

  const [showClearFilterState, setShowClearFilterState] = useState(false);
  const [categoryState, setCategoryState] = useState([]);
  const [availabilityState, setAvailabilityState] = useState([]);
  const [makerState, setMakerState] = useState([]);
  const [periodsState, setPeriodsState] = useState([]);
  const [monarchsState, setMonarchsState] = useState([]);
  const [minPriceState, setMinPriceState] = useState(0);
  const [maxPriceState, setMaxPriceState] = useState(1);

  const [productSimilarObjData, setProductSimilarObjData] = useState({});
  const [modalIsOpen, setIsOpen] = useState(false);
  const [filterToggle, setFilterToggle] = useState(false);
  const handleFilterToggle = () => {
    setFilterToggle(!filterToggle)
  }
  function openModal(productItemObj) {
    setProductSimilarObjData(productItemObj);
    setIsOpen(true);
  }
  function closeModal() {
    setIsOpen(false);
  }
  const handleProducts = async (page, per_page, order, orderby, filterParams = "") => {
    setIsLoading(true);
    try {

      // const productResponse = await fetchProducts('?page=1&per_page=51&status=publish&order=desc&orderby=date&filter[maker]=charles-stuart-harris');
      let categoryProduct =
        categoryState.length > 0
          ? "&category=" + categoryState
          : props.currentCatResponse && props.currentCatResponse.currentCat && props.currentCatResponse.currentCat.termId
            ? "&category=" + props.currentCatResponse.currentCat.termId
            : "";
      let params = '';
      let fields = "&_fields=name,id,permalink,sku,images,acf,maker,price,stock_status,description";
      if (router.query['view-archived'] == "true") {
        params = "?status=publish&view-archived&page=" + page + "&per_page=" + per_page + "&order=" + order + "&orderby=" + orderby + categoryProduct + filterParams + fields;
      } else {
        params = "?status=publish&stock_status=instock&page=" + page + "&per_page=" + per_page + "&order=" + order + "&orderby=" + orderby + categoryProduct + filterParams + fields;
      }

      const productResponse = await fetchProductLists(params);
      setXWpTotal(productResponse.headers.xWpTotal);
      setXWpTotalpages(productResponse.headers.xWpTotalpages);
      setProductsData(productResponse.data);
      setIsLoading(false);
    } catch (e) { }
  };
  const handleFilters = async (slugParam) => {
    const filtersResponse = await fetchProductFilters(slugParam);
    setFiltersData(filtersResponse && filtersResponse);
    dispatch(categoriesSuccess(filtersResponse && filtersResponse));
    setMinPriceState(Number(filtersResponse && filtersResponse.price.min));
    setMaxPriceState(Number(filtersResponse && filtersResponse.price.max));
    setValues([Number(filtersResponse && filtersResponse.price.min), Number(filtersResponse && filtersResponse.price.max)]);
    // handleProducts(currentPage,perPage,orderType,orderKey,);
  }

  useEffect(() => {
    window.scrollTo(0, 0);
    handleFilters(props.slugParam);
  }, [category_slug, sub_category_slug, refreshComponet]);

  const ToggleClass = (type) => {
    setActive(type);
  };

  const handlePageChange = (page) => {
    setProductsData([]);
    setCurrentPage(page);
    setRefreshComponet(Math.random());
  };
  const handleCategoryFilter = (event) => {
    setShowClearFilterState(true);
    if (event.target.checked) {
      setCategoryState((prevArray) => [...prevArray, event.target.value]);
    } else {
      setCategoryState(
        categoryState.filter(function (val) {
          return val !== event.target.value;
        }),
      );
      if (filtersData.currentCat) {
        setCategoryState(filtersData.currentCat.termId);
      }
    }
  };
  const handleAvailabilityFileter = (event) => {
    setShowClearFilterState(true);
    if (event.target.checked) {
      setAvailabilityState((prevArray) => [...prevArray, event.target.value]);
    } else {
      setAvailabilityState(
        availabilityState.filter(function (val) {
          return val !== event.target.value;
        }),
      );
    }
  };
  const handleMakersFileter = (event) => {
    setShowClearFilterState(true);
    if (event.target.checked) {
      setMakerState((prevArray) => [...prevArray, event.target.value]);
    } else {
      setMakerState(
        makerState.filter(function (val) {
          return val !== event.target.value;
        }),
      );
    }
  };
  const handlePeriodsFileter = (event) => {
    setShowClearFilterState(true);
    if (event.target.checked) {
      setPeriodsState((prevArray) => [...prevArray, event.target.value]);
    } else {
      setPeriodsState(
        periodsState.filter(function (val) {
          return val !== event.target.value;
        }),
      );
    }
  };
  const handleMonarchsFileter = (event) => {
    setShowClearFilterState(true);
    if (event.target.checked) {
      setMonarchsState((prevArray) => [...prevArray, event.target.value]);
    } else {
      setMonarchsState(
        monarchsState.filter(function (val) {
          return val !== event.target.value;
        }),
      );
    }
  };
  const handlePriceFileter = (price) => {
    setShowClearFilterState(true);
    setMinPriceState(Number(price[0]));
    setMaxPriceState(Number(price[1]));
  };

  const handleClearFilter = () => {
    setMinPriceState(values[0]);
    setMaxPriceState(values[1]);
    setShowClearFilterState(false);
    setCategoryState([]);
    setAvailabilityState([]);
    setMakerState([]);
    setPeriodsState([]);
    setMonarchsState([]);
  };
  useEffect(() => {
    let filterParams = "&minprice=" + minPriceState;
    filterParams += "&maxprice=" + maxPriceState;
    if (availabilityState.length > 0) {
      filterParams += "&availability=" + availabilityState;
    }
    if (makerState.length > 0) {
      filterParams += "&maker=" + makerState;
    }
    if (periodsState.length > 0) {
      filterParams += "&period=" + periodsState;
    }
    if (monarchsState.length > 0) {
      filterParams += "&monarch=" + monarchsState;
    }
    if (filterParams != undefined && maxPriceState > 1) {
      handleProducts(currentPage, perPage, orderType, orderKey, filterParams);
    }
    //handleProducts(currentPage,perPage,orderType,orderKey,filterParams)
  }, [
    minPriceState,
    maxPriceState,
    availabilityState,
    makerState,
    periodsState,
    monarchsState,
    categoryState,
    currentPage,
    filtersData,
    router.query
  ]);
  const sortByFilter = (value) => {
    var sortByArr = value.split("-");
    setProductsData([]);
    setCurrentPage(1);
    setOrderKey(sortByArr[0]);
    setOrderType(sortByArr[1]);
    setRefreshComponet(Math.random());
  };
  const tablePagination = (count) => {
    var indents = [];
    if (currentPage > 1) {
      indents.push(
        <li className="previous-page" key={0}>
          <button onClick={() => handlePageChange(Number(currentPage) - 1)} className="page-numbers">
            <Image width={6} height={18} src={PreviousIcon.src} className="" alt="previous" loading="lazy" />
          </button>
        </li>,
      );
    }

    var startIndex = currentPage == 1 ? currentPage : currentPage - 1;
    var endIndex = Number(currentPage + 8) > xWpTotalpages ? xWpTotalpages : Number(currentPage + 8);

    if (Math.ceil(count / perPage) > 1) {
      for (let index = startIndex; index <= endIndex; index++) {
        var activeClass = currentPage == index ? "page-numbers current" : "page-numbers";
        indents.push(
          <li key={index}>
            <span aria-current="page" onClick={() => handlePageChange(index)} className={activeClass}>
              {index}
            </span>
          </li>,
        );
      }
    }

    if (Math.ceil(count / perPage) > currentPage) {
      indents.push(
        <li key={count + 1}>
          <button onClick={() => handlePageChange(Number(currentPage) + 1)} className="page-numbers next-page">
            <Image width={6} height={18} src={NextIcon.src} className="" alt="next" loading="lazy" />
          </button>
        </li>,
      );
    }

    return indents;
  };
  return (
    <div className={styles.root}>
      <div className={showClearFilterState ? "clear-checkbox filter" : "filter"}>
        <div className={filterToggle ? "filterMobile active" : "filterMobile"}>
          {props.currentCatResponse && props.currentCatResponse.currentCat && (
            <div className="widget_text">
              <div className="textwidget custom-html-widget">
                <h2 className="widget-title">{props.currentCatResponse.currentCat.name}</h2>
                <div
                  className="read-more js-read-more readmore-content"
                  data-rm-words={30}
                  dangerouslySetInnerHTML={{ __html: props.currentCatResponse.currentCat.description }}
                ></div>
              </div>
            </div>
          )}
          <div className="clearfilter">
            <h2 className="widget-title">Filter</h2>
            {showClearFilterState ? (
              <>
                <button className="button woof_reset_search_form" onClick={() => handleClearFilter()} data-link="">
                  Clear
                </button>

              </>
            ) : (
              ""
            )}
            <a onClick={() => { handleFilterToggle() }} className="close-filter-bar">
              Back
            </a>
          </div>
          {isFiltersLoading ? (
            <Image height={40} width={40} className="loader-image" src={roundloader} style={{ display: isFiltersLoading ? "" : "none" }} />
          ) : (
            <>
              <Accordion>
                <AccordionSummary expandIcon={<ExpandMoreIcon />} aria-controls="panel1a-content">
                  <Typography>
                    Availability
                  </Typography>
                </AccordionSummary>
                <AccordionDetails>
                  <div className="MuiTypography-body1">
                    <ul className="woof_list woof_list_checkbox">
                      {

                        filtersData && filtersData.taxonomies && filtersData.taxonomies.availability && Object.values(filtersData.taxonomies.availability).map((availabilitysItem, index) => {
                          return ((availabilitysItem.termId != 41) ? <li key={index}>
                            <input type="checkbox" name="" checked={availabilityState && availabilityState.find((el) => el == availabilitysItem.termId)} className="woof_checkbox_term" value={availabilitysItem.termId} onClick={(e) => handleAvailabilityFileter(e)} />
                            <label className="woof_checkbox_label" htmlFor="for-sale4">{availabilitysItem.name}<span className="woof_checkbox_count">({availabilitysItem.count})</span></label>
                          </li> : '')
                        })
                      }
                    </ul>
                  </div>
                </AccordionDetails>
              </Accordion>
              {((sub_category_slug) ? '' :
                <Accordion>
                  <AccordionSummary
                    expandIcon={<ExpandMoreIcon />}
                    aria-controls="panel1a-content">
                    <Typography>
                      Category Name
                    </Typography>
                  </AccordionSummary>
                  <AccordionDetails>
                    <div className="MuiTypography-body1">
                      <ul className="woof_list woof_list_checkbox">
                        {
                          filtersData && filtersData.taxonomies && filtersData.taxonomies.productCat && Object.values(filtersData.taxonomies.productCat).map((categoriesItem, index) => {
                            return ((Object.values(categoriesItem.childs).length > 0) ? <li>
                              <Accordion className='inner-accordion'>
                                <AccordionSummary
                                  expandIcon={<ExpandMoreIcon />}
                                  aria-controls="panel1a-content"
                                >
                                  <input type="checkbox" className="woof_checkbox_term" checked={categoryState && categoryState.find((el) => el == categoriesItem.termId)} value={categoriesItem.termId} onClick={(e) => { handleCategoryFilter(e) }} />
                                  <label className="woof_checkbox_label" htmlFor="for-sale4"><span dangerouslySetInnerHTML={{ __html: categoriesItem.name }}></span><span className="woof_checkbox_count">({categoriesItem.count})</span></label>
                                </AccordionSummary>
                                <AccordionDetails>
                                  <ul className="woof_list woof_list_checkbox">
                                    {Object.values(categoriesItem.childs).map((childItem, index) => {
                                      return <li key={index}>
                                        <input type="checkbox" className="woof_checkbox_term" checked={categoryState && categoryState.find((el) => el == childItem.termId)} value={childItem.termId} onClick={(e) => { handleCategoryFilter(e) }} />
                                        <label className="woof_checkbox_label" htmlFor="for-sale4"><span dangerouslySetInnerHTML={{ __html: childItem.name }}></span><span className="woof_checkbox_count">({childItem.count})</span></label>
                                      </li>
                                    })
                                    }
                                  </ul>
                                </AccordionDetails>
                              </Accordion>
                            </li> :
                              <li>
                                <li key={index}>
                                  <input type="checkbox" checked={categoryState && categoryState.find((el) => el == categoriesItem.termId)} className="woof_checkbox_term" value={categoriesItem.termId} onClick={(e) => { handleCategoryFilter(e) }} />
                                  <label className="woof_checkbox_label" htmlFor="for-sale4"><span dangerouslySetInnerHTML={{ __html: categoriesItem.name }}></span><span className="woof_checkbox_count">({categoriesItem.count})</span></label>
                                </li>
                              </li>)
                          })
                        }
                      </ul>
                    </div>
                  </AccordionDetails>

                </Accordion>
              )}
              <Accordion>
                <AccordionSummary expandIcon={<ExpandMoreIcon />} aria-controls="panel1a-content">
                  <Typography>
                    Maker
                  </Typography>
                </AccordionSummary>
                <AccordionDetails>
                  <div className="MuiTypography-body1">
                    <ul className="woof_list woof_list_checkbox">
                      {
                        filtersData && filtersData.taxonomies && filtersData.taxonomies.maker && Object.values(filtersData.taxonomies.maker).map((makersItem, index) => {
                          return <li key={index}>
                            <input type="checkbox" checked={makerState && makerState.find((el) => el == makersItem.termId)} className="woof_checkbox_term" onClick={(e) => { handleMakersFileter(e) }} value={makersItem.termId} />
                            <label className="woof_checkbox_label" htmlFor="for-sale4"><span dangerouslySetInnerHTML={{ __html: makersItem.name }}></span><span className="woof_checkbox_count">({makersItem.count})</span></label>
                          </li>
                        })
                      }
                    </ul>
                  </div>
                </AccordionDetails>
              </Accordion>
              <div className="price-filter">
                <h4>Price</h4>
                {filtersData && filtersData.price && values.length > 0 ? (
                  <Range
                    values={values}
                    step={1}
                    min={filtersData && filtersData.price && Number(filtersData.price.min)}
                    max={filtersData && filtersData.price && Number(filtersData.price.max)}
                    onChange={(values) => {
                      handlePriceFileter(values);
                      setValues(values);
                    }}
                    renderTrack={({ props, children }) => (
                      <div
                        onMouseDown={props.onMouseDown}
                        onTouchStart={props.onTouchStart}
                        style={{
                          ...props.style,
                          height: "36px",
                          display: "flex",
                          width: "100%",
                        }}
                      >
                        <div
                          ref={props.ref}
                          style={{
                            height: "1px",
                            width: "90%",
                            margin: "0 auto",
                            background: getTrackBackground({
                              values,
                              colors: ["#d6dbe3", "#d6dbe3", "#d6dbe3"],
                              min: filtersData && filtersData.price && Number(filtersData.price.min),
                              max: filtersData && filtersData.price && Number(filtersData.price.max),
                            }),
                            alignSelf: "center",
                          }}
                        >
                          {children}
                        </div>
                      </div>
                    )}
                    renderThumb={({ index, props, isDragged, isFocused }) => (
                      <div
                        {...props}
                        style={{
                          ...props.style,
                          height: "11px",
                          width: "11px",
                          backgroundColor: "#d6dbe3",
                          display: "flex",
                          justifyContent: "center",
                          alignItems: "center",
                          outline: "none",
                        }}
                      >
                        <div
                          style={{
                            position: "absolute",
                            top: "25px",
                            color: "#404040",
                            fontWeight: "400",
                            fontSize: "16px",
                            padding: "0",
                          }}
                        >
                          {"£" + values[index]}
                        </div>
                        <div
                          style={{
                            height: "16px",
                            width: "5px",
                            backgroundColor: isDragged ? "#d6dbe3" : "#d6dbe3",
                            display: "none",
                          }}
                        />
                      </div>
                    )}
                  />
                ) : (
                  ""
                )}
              </div>
              <Accordion>
                <AccordionSummary expandIcon={<ExpandMoreIcon />} aria-controls="panel1a-content">
                  <Typography>
                    Period
                  </Typography>
                </AccordionSummary>
                <AccordionDetails>
                  <div className="MuiTypography-body1">
                    <ul className="woof_list woof_list_checkbox">
                      {
                        filtersData && filtersData.taxonomies && filtersData.taxonomies.period && Object.values(filtersData.taxonomies.period).map((periodsItem, index) => {
                          return <li key={index}>
                            <input type="checkbox" checked={periodsState && periodsState.find((el) => el == periodsItem.termId)} className="woof_checkbox_term" onClick={(e) => { handlePeriodsFileter(e) }} value={periodsItem.termId} />
                            <label className="woof_checkbox_label" htmlFor="for-sale4"><span dangerouslySetInnerHTML={{ __html: periodsItem.name }}></span><span className="woof_checkbox_count">({periodsItem.count})</span></label>
                          </li>
                        })
                      }
                    </ul>
                  </div>
                </AccordionDetails>
              </Accordion>
              <Accordion>
                <AccordionSummary expandIcon={<ExpandMoreIcon />} aria-controls="panel1a-content">
                  <Typography>
                    Monarch
                  </Typography>
                </AccordionSummary>
                <AccordionDetails>
                  <div className="MuiTypography-body1">
                    <ul className="woof_list woof_list_checkbox">
                      {
                        filtersData && filtersData.taxonomies && filtersData.taxonomies.monarch && Object.values(filtersData.taxonomies.monarch).map((monarchsItem, index) => {
                          return <li key={index}>
                            <input type="checkbox" checked={monarchsState && monarchsState.find((el) => el == monarchsItem.termId)} className="woof_checkbox_term" onChange={(e) => handleMonarchsFileter(e)} value={monarchsItem.termId} />
                            <label className="woof_checkbox_label" htmlFor="for-sale4"><span dangerouslySetInnerHTML={{ __html: monarchsItem.name }}></span><span className="woof_checkbox_count">({monarchsItem.count})</span></label>
                          </li>
                        })
                      }
                    </ul>
                  </div>
                </AccordionDetails>
              </Accordion>
            </>
          )}

          <div className="archive-block">
            <div className="archive-block-inner">
              <a href="#" className="archived">
                View this Category’s Archive
              </a>
            </div>
          </div>
        </div>
      </div>

      <div className="list-products">
        <div className="filter-bars">
          <span>Sort by:</span>
          <select name="orderby" defaultValue="title-asc" className="orderby" aria-label="Shop order" onChange={(e) => sortByFilter(e.target.value)}>
            <option value="title-asc" selected={orderKey + "-" + orderType == "title-asc" ? "selected" : ""}>
              {" "}
              Name A-Z{" "}
            </option>
            <option value="title-desc" selected={orderKey + "-" + orderType == "title-desc" ? "selected" : ""}>
              {" "}
              Name Z-A{" "}
            </option>
            <option value="price-desc" selected={orderKey + "-" + orderType == "price-desc" ? "selected" : ""}>
              {" "}
              Price: High to Low{" "}
            </option>
            <option value="price-asc" selected={orderKey + "-" + orderType == "price-asc" ? "selected" : ""}>
              {" "}
              Price: Low to High{" "}
            </option>
            <option value="date-desc" selected={orderKey + "-" + orderType == "date-desc" ? "selected" : ""}>
              {" "}
              Recently Added{" "}
            </option>
          </select>
          <button
            className={isActive == "grid" ? "grid-view-data selected" : "grid-view-data"}
            onClick={() => ToggleClass("grid")}
          >
            <i className="fa fa-th"></i>
          </button>
          <button
            className={isActive == "list" ? "list-view-data selected" : "list-view-data"}
            onClick={() => ToggleClass("list")}
          >
            <i className="fa fa-bars"></i>
          </button>

          <nav className="woocommerce-pagination">
            <div>View All</div>
            <ul className="page-numbers">{tablePagination(xWpTotal)}</ul>
          </nav>
        </div>
        <span className="mobile-filter" onClick={() => { handleFilterToggle() }}>FIlTER</span>
        <div className="product-block">
          <ul className={isActive == "grid" ? "products columns-4" : "products columns-4 list-view"}>
            {productsData &&
              productsData.map((productsItem, index) => {
                return (
                  <li key={index}>
                    <Link href={UrlReplace(productsItem.permalink)}>
                      <div className="product-img">
                        <Image
                          width={327}
                          height={310}
                          src={productsItem.images[0].src}
                          className="attachment-product-image size-product-image wp-post-image"
                          alt="image"
                          sizes="100vw"
                        />
                      </div>
                      <div className="list-view-set">
                        <h2 className="woocommerce-loop-product__title">{productsItem.name}</h2>
                        <span className="price">
                          <span className="woocommerce-Price-amount amount">
                            <bdi>
                              {/* <span className="woocommerce-Price-currencySymbol">£{productsItem.price}</span> */}
                            </bdi>
                          </span>
                        </span>
                        <div className="product-custom-mata">
                          <div className="woocommerce-sku">{productsItem.sku}</div>
                          <div className="product-date-label">
                            Date:
                            <div className="woocommerce-sku">{productsItem.acf.productDateFrom} </div>
                          </div>
                          {productsItem.maker.length > 0 ? (
                            <div className="maker">
                              <span className="maker-label">Maker: </span>
                              <span dangerouslySetInnerHTML={{ __html: productsItem.maker[0].name }}></span>
                            </div>
                          ) : (
                            ""
                          )}

                          <div className="price">
                            {productsItem.stockStatus == "outofstock" ? (
                              "Sold"
                            ) : (
                              <span className="woocommerce-Price-amount amount">
                                <bdi>
                                  <span className="woocommerce-Price-currencySymbol">£{productsItem.price}</span>
                                </bdi>
                              </span>
                            )}
                          </div>
                          <div className="lgv_description lgv_description_simple">
                            <div className="woocommerce-product-details__short-description">
                              <p>{productsItem.shortDescription}</p>
                            </div>
                          </div>
                        </div>
                      </div>
                    </Link>
                    {/* {((productsItem.acf.buyingOptions && productsItem.acf.buyingOptions.includes('allow_buy_online')) ? <button type="submit" name="add-to-cart" className="single_add_to_cart_button_general_plist button alt single-details-basket-btn btn-basket-cus shop-basket-btn-cus">Add to Basket</button> : '' )} */}
                    {productsItem.acf.buyingOptions &&
                      productsItem.acf.buyingOptions.includes("allow_buy_online") &&
                      productsItem.stockStatus == "instock" ? (
                      <AddToCart product={productsItem} openModal={openModal} page="list" />
                    ) : (
                      ""
                    )}
                    <Link href={UrlReplace(productsItem.permalink)} className="button enquire_only_btn">
                      ENQUIRE ABOUT THIS PIECE{" "}
                    </Link>
                  </li>
                );
              })}
            <Image height={40} width={40} className="loader-image" src={roundloader} style={{ display: isLoading ? "" : "none" }} />
          </ul>
          <div className="filter-bars">
            <span>Sort by:</span>
            <select name="orderby" defaultValue="title-asc" className="orderby" aria-label="Shop order" onChange={(e) => sortByFilter(e.target.value)}>
              <option value="title-asc" selected={orderKey + "-" + orderType == "title-asc" ? "selected" : ""}>
                {" "}
                Name A-Z{" "}
              </option>
              <option value="title-desc" selected={orderKey + "-" + orderType == "title-desc" ? "selected" : ""}>
                {" "}
                Name Z-A{" "}
              </option>
              <option value="price-desc" selected={orderKey + "-" + orderType == "price-desc" ? "selected" : ""}>
                {" "}
                Price: High to Low{" "}
              </option>
              <option value="price-asc" selected={orderKey + "-" + orderType == "price-asc" ? "selected" : ""}>
                {" "}
                Price: Low to High{" "}
              </option>
              <option value="date-desc" selected={orderKey + "-" + orderType == "date-desc" ? "selected" : ""}>
                {" "}
                Recently Added{" "}
              </option>
            </select>
            <button
              className={isActive == "grid" ? "grid-view-data selected" : "grid-view-data"}
              onClick={() => ToggleClass("grid")}
            >
              <i className="fa fa-th"></i>
            </button>
            <button
              className={isActive == "list" ? "list-view-data selected" : "list-view-data"}
              onClick={() => ToggleClass("list")}
            >
              <i className="fa fa-bars"></i>
            </button>

            <nav className="woocommerce-pagination">
              <div>View All</div>
              <ul className="page-numbers">{tablePagination(xWpTotal)}</ul>
            </nav>
          </div>
        </div>

        {/* <div className="loadMore">
          <button className="round-loader">View More</button>
        </div> */}

        <AddToBasket productData={productSimilarObjData} modalIsOpen={modalIsOpen} closeModal={closeModal} />
      </div>
    </div>
  );
}
