import React, { useState, useEffect } from 'react';
import Link from 'next/link';
import Slider from "react-slick";
import { fetchProducts } from '../../services';
import UrlReplace from "../Common/UrlReplace";
import AddToBasket from '../popup/AddToBasket';
import AddToCart from '../Common/AddToCart';
//import '../../styles/shop/similarproducts.scss';
import "slick-carousel/slick/slick.css";
import "slick-carousel/slick/slick-theme.css";
import Image from 'next/image';
import styles from '../../styles/shop/SimilarProducts.module.scss';

const SimilarProducts = ({ productsData }) => {


    const [similarProductsData, setSimilarProductsData] = useState([]);
    const [productSimilarObjData, setProductSimilarObjData] = useState({});
    const [modalIsOpen, setIsOpen] = useState(false);

    function openModal(productItemObj) {
        setProductSimilarObjData(productItemObj)
        setIsOpen(true);
    }

    function closeModal() {
        setIsOpen(false);
    }


    const handleSimilarProducts = async (relatedIds) => {
        try {
            if (relatedIds) {
                const similarProductResponse = await fetchProducts('?include=' + relatedIds);
                setSimilarProductsData(similarProductResponse);
            }

        } catch (e) {
            console.log(e)
        }
    }
    useEffect(() => {
        handleSimilarProducts(productsData.length > 0 && productsData[0].relatedIds);
    }, [productsData.length > 0]);


    var settings = {
        dots: false,
        arrows: true,
        infinite: true,
        loop: true,
        autoplay: false,
        slidesToShow: 3,
        slidesToScroll: 1,
        responsive: [
            {
                breakpoint: 1024,
                settings: {
                    slidesToShow: 3
                }
            },
            {
                breakpoint: 767,
                settings: {
                    slidesToShow: 1
                }
            },
        ]
    };


    return ((productsData.length == 0 || similarProductsData && similarProductsData.length == 0) ? '' :
        <section className={styles.root}>
            <div className="products">
                <div className={styles.wrapper}>
                    <div className="recently-viewed-inner-section similar-product-slider">
                        <div className="recently-viewed-inner">
                            <div className="similar-product">
                                <div className="similar-product-slider">
                                    <h2>Similar Products for Sale</h2>
                                    {((productsData[0].categories && productsData[0].categories.length >= 2) ?
                                        <Link href={'/shop/' + productsData[0].categories[productsData[0].categories.length - 1].slug + '/' + productsData[0].categories[productsData[0].categories.length - 2].slug + '/'}>View All</Link> : '')}
                                </div>
                            </div>
                            <div className="products columns-3">
                                <Slider {...settings}>
                                    {
                                        similarProductsData && similarProductsData.map((similarProductsItem, index) => {
                                            return <ul key={index}><li className='single-slide' >
                                                <div className="product">
                                                    <div className="product-block">
                                                        <Link href={UrlReplace(similarProductsItem.permalink)}>
                                                            <Image className="img" sizes='100vw' src={similarProductsItem.images[0].src} alt="Antique Silver Victorian Claret Jug made in c.1895" width={300} height={300} />
                                                        </Link>
                                                        <div className="product-content-qr">
                                                            <Link className="product-title-qr" href={UrlReplace(similarProductsItem.permalink)}>
                                                                <p>{similarProductsItem.name}</p>
                                                            </Link>
                                                            <span className="price">
                                                                <span className="woocommerce-Price-amount amount">
                                                                    <bdi><span className="woocommerce-Price-currencySymbol">£</span>{similarProductsItem.price}</bdi></span>
                                                            </span>

                                                            {((similarProductsItem.acf.buyingOptions && similarProductsItem.acf.buyingOptions.includes('allow_buy_online') && similarProductsItem.stockStatus == "instock") ? <AddToCart product={similarProductsItem} openModal={openModal} page="similar" /> : <Link className='single_add_to_cart_button_general_plist button alt single-details-basket-btn btn-basket-similar-pro-cus' href={UrlReplace(similarProductsItem.permalink)}>ENQUIRE ABOUT THIS PIECE </Link>)}
                                                            {/* <button onClick={() => openModal(similarProductsItem)} type="button" className="single_add_to_cart_button_general_plist button alt single-details-basket-btn btn-basket-similar-pro-cus">Add to Basket</button> */}
                                                        </div>
                                                    </div>
                                                </div>
                                            </li>
                                            </ul>
                                        })

                                    }

                                </Slider>
                            </div>
                        </div>
                    </div>
                </div>
                <AddToBasket productData={productSimilarObjData} modalIsOpen={modalIsOpen} closeModal={closeModal} />
            </div>
        </section>
    );
};

export default SimilarProducts;
