import React, { useEffect, useState, useRef } from 'react';
import { useDispatch, useSelector } from 'react-redux';
import  Link  from 'next/link';
import axios from "axios";
import Image from "next/image"
import UrlReplace from '../Common/UrlReplace';
import { pendingCart, getCart } from "../../reducer/woocommerceSlice";
import Product1 from '../../assets/product1.jpg';
import VisaIcon from '../../assets/visa.svg';
import MasterIcon from '../../assets/Mastercard.svg';
import AmericanIcon from '../../assets/BlueBox.svg';
import storeApi from "../../helper/StoreApi";
import styles from "styles/basket/MainCartContent.module.scss";
import { usePathname } from 'next/navigation'
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import { faStickyNote, faCheckCircle } from "@fortawesome/free-solid-svg-icons";


const MainCartContent = () => {

    const { cart, isCartReady } = useSelector(state => state.woocommerce);
    const dispatch = useDispatch();
    const pathname = usePathname()
    const redirect = new URLSearchParams(pathname.search).get("redirect");

    const [isPending, setIsPending] = useState(false);
    const [removeKeyData, setRemoveKeyData] = useState('');
    const [removeProductId, setRemoveProductId] = useState('');
    const [notAddedIntoCartLoaded, setNotAddedIntoCartLoaded] = useState(false);
    const [notAddedIntoCartData, setNotAddedIntoCartData] = useState(false);
    const [addedIntoCartLoaded, setAddedIntoCartLoaded] = useState(false);
    
    

    const removeItemFromCart = (async (item) => {
        setIsPending(true);
        setRemoveProductId(item.id);
        dispatch(pendingCart());
        const getcartResponse = await storeApi({ endpoint: "cart/remove-item", method: "POST", params: { 'key' : item.key }, });
        dispatch(getCart(getcartResponse));
        setRemoveKeyData(item);
        getCartReady();
        setIsPending(false);
    });

    const undoRemovedItem = (async (item) => {
        
        setIsPending(true);
        setRemoveKeyData();
        dispatch(pendingCart());
        await axios({
            url: process.env.API_URL + 'wp/v2/undo-item?undo_item=' + item.key,
            withCredentials: true,
            method: 'GET',
        }).then(function (response) {
            getCartReady();
            setIsPending(false);
        })
        
    })

    const getCartReady = async () => {
        dispatch(pendingCart())
        const getcartResponse = await storeApi({ endpoint: "cart" })
        dispatch(getCart(getcartResponse))
    }

    if (typeof window !== 'undefined') {
        var notAddedIntoCart = localStorage.getItem('notAddedIntoCart');
        var addedIntoCart = localStorage.getItem('addedIntoCart');
      }



    const notAddedIntoCartComponet = (data,flag) => {
        if(flag == false)
        {
            localStorage.setItem('notAddedIntoCart','');
            setNotAddedIntoCartData(data);
            setNotAddedIntoCartLoaded(true);
        }
        return ((flag) ? <ul className="woocommerce-error" role="alert">
        <li> { notAddedIntoCartData.split(',').length } items from your previous order are currently unavailable and could not be added to your basket.		</li>
    </ul> : <ul className="woocommerce-error" role="alert">
        <li> { data.split(',').length } items from your previous order are currently unavailable and could not be added to your basket.		</li>
    </ul>) 
    }

    const addedIntoCartComponet = (flag) => {
        if(flag == false)
        {
            localStorage.setItem('addedIntoCart','');
            setAddedIntoCartLoaded(true);
        }
        return <div className="woocommerce-message" role="alert">
                The basket has been filled with the items from your previous order.	
            </div> 
    }
    
    
    return (
    <div className='content-part'>
          
        <div className={styles.mainCartContent + ' main-cart-content'}>


            <div className={styles.wrapper}>
                <div className="notices-wrapper">

                <div className="woocommerce-notices-wrapper">
                    { (((notAddedIntoCart != "" && notAddedIntoCart != null) || notAddedIntoCartLoaded) ? 
                        notAddedIntoCartComponet(notAddedIntoCart,notAddedIntoCartLoaded)
                     : '' ) }

                    { (((addedIntoCart != "" && addedIntoCart != null) || addedIntoCartLoaded) ? 
                        addedIntoCartComponet(addedIntoCartLoaded)
                     : '' ) }

                </div>

                {
                    ((removeKeyData != "" && removeKeyData != undefined && isPending == false) ? 
                    <div className="woocommerce-message" role="alert"><FontAwesomeIcon icon={faCheckCircle} />
                        {(removeKeyData.name) ? removeKeyData.name : ''} removed. <button onClick={() => undoRemovedItem(removeKeyData)} className="restore-item">Undo?</button>	
                    </div>
                    : '') 
                }

                { ((cart && cart.items && cart.items.length == 0 && redirect == "checkout") ? <><p className="cart-empty woocommerce-info"><FontAwesomeIcon icon={faStickyNote} /> Checkout is not available whilst your basket is empty.</p> <br /></> : '') }

                { ((cart && cart.items && cart.items.length == 0) ? <> <p className="cart-empty woocommerce-info"><FontAwesomeIcon icon={faStickyNote} /> Your basket is currently empty.</p>  <br /></> : '') }
                
                </div>
                { ((cart && cart.items && cart.items.length == 0) ?
                <p className="return-to-shop">
		            <Link className="button wc-backward wp-element-button" href="/shop/">Return to shop</Link>
	            </p>
                : '') }
                 { ((cart && cart.items && cart.items.length > 0) ?
                 <>
                    <div className="woocommerce-cart-form">
                        <table className="shop_table shop_table_responsive cart woocommerce-cart-form__contents" cellSpacing={0}>
                        <thead>
                            <tr>
                            <th colSpan={2} className="product-name">Product</th>
                            <th className="product-sku">Stock Number</th>
                            <th className="product-price">Price</th>
                            </tr>
                        </thead>
                        <tbody>
                            {
                                cart && cart.items && cart.items.map((cartItem,index) => {
                                    return <tr key={index} className={((isPending && removeProductId == cartItem.id) ? "woocommerce-cart-form__cart-item cart_item processing" : "woocommerce-cart-form__cart-item cart_item" )}>
                                        <td key={index} className="product-thumbnail">
                                            <Link href={UrlReplace(cartItem.permalink)}>
                                                <Image width={548} height={760} src={cartItem.images[0].src} className="" alt="" decoding="async" loading="lazy" />
                                            </Link>
                                        </td>
                                        <td className="product-name" data-title="Product">
                                            <Link href={UrlReplace(cartItem.permalink)}>{cartItem.name}</Link>
                                        </td>
                                        <td className="product-sku" data-title="Stock Number">{cartItem.sku}</td>
                                        <td className="product-price" data-title="Price">
                                            <span className="woocommerce-Price-amount amount">
                                                <span className="woocommerce-Price-currencySymbol">{cartItem.totals.currency_symbol+cartItem.totals.line_total}</span>
                                            </span>
                                        </td>
                                        <td className="product-remove">
                                            <a onClick={() => removeItemFromCart(cartItem)} className='remove'>× remove</a>
                                        </td>
                                        <span className="wpcf7-spinner"></span>
                                    </tr>
                                })
                            }
                            

                        </tbody>
                        </table>
                    </div>
                    <div className="cart-collaterals">
                        <div className={ (isPending) ? "cart_totals processing" : "cart_totals"}>
                            <span className="wpcf7-spinner"></span>
                            <div className="cart_totlas_box">
                                <h4>Basket Summary</h4>
                                
                                <table cellSpacing={0} className="shop_table shop_table_responsive">
                                
                                    <tbody>
                                        <tr className={ (isPending) ? "cart-subtotal processing" : "cart-subtotal"} >
                                            <th>Subtotal</th>
                                            <td data-title="Subtotal">
                                                <span className="woocommerce-Price-amount amount">
                                                    <span className="woocommerce-Price-currencySymbol">
                                                        {cart.totals.currency_symbol+(((cart && cart.totals && cart.totals.total_items > 0) ? cart.totals.total_items : 0))}
                                                    </span>
                                                </span>
                                            </td>
                                        </tr>
                                        <tr className={ (isPending) ? "order-total processing" : "order-total"}>
                                            <th>Grand Total </th>
                                            <td data-title="Grand Total ">
                                                <strong>
                                                    <span className="woocommerce-Price-amount amount">
                                                        <span className="woocommerce-Price-currencySymbol">
                                                            {
                                                            cart.totals.currency_symbol+
                                                            (((cart && cart.totals && cart.totals.total_items > 0) ? cart.totals.total_items : 0))}
                                                        </span>
                                                        
                                                    </span>
                                                </strong> 
                                            </td>
                                        </tr>
                                    </tbody>

                                
                                </table> 
                            </div>
                            <div className="wc-proceed-to-checkout">
                                <Link href="/checkout" className="checkout-button button alt wc-forward">Checkout</Link>
                            </div>
                            <div className="enquiry-button"> <a href="https://williamwalter.co.uk/shop/" className="button">Continue Shopping</a></div>   <div className="payment-card-container">
                                <div className="payment-card-wrap">
                                    <Image src={VisaIcon} className="img-visa" alt="icon" />
                                    <Image src={MasterIcon} className="img-ms" alt="icon" />
                                    <Image src={AmericanIcon} className="img-bb" alt="icon" />
                                </div>
                            </div>
                        </div>
                    </div>
                </> : '') }
            </div>
        </div>
         
    </div>
  );
};

export default MainCartContent;