import React, { useState, useEffect } from 'react';
import { useDispatch, useSelector } from 'react-redux';
import  Link  from 'next/link';
import Image from 'next/image'
import Slider from "react-slick";
import { fetchProducts } from '../../services';
import UrlReplace from "../Common/UrlReplace";
//import '../../style/shop/similarproducts.scss';
import styles from "../../styles/shop/SimilarProducts.module.scss";
import "slick-carousel/slick/slick.css";
import "slick-carousel/slick/slick-theme.css";


const RecentlyBasketViewed = () => {

    const { cart, isCartReady } = useSelector(state => state.woocommerce);

    const [recentProductsData,setRecentProductsData] = useState([]);

    const handleRecentProducts = async (recentlyIds) => {

        try {
            if(recentlyIds)
            {
                const recentlyProductResponse = await fetchProducts('?per_page=8&include='+recentlyIds);
                setRecentProductsData(recentlyProductResponse.data);
            }
            
        } catch (e) {
        }
    }

    useEffect(() => { 
       
        if(localStorage.getItem('recentlyViewedProduct'))
        {
            var recentlyArr = localStorage.getItem('recentlyViewedProduct').split(','); 
            var recentlyArr = recentlyArr.filter((value, index, array) => array.indexOf(value) === index).reverse();
           
            handleRecentProducts(recentlyArr);
        }

    },[cart.items.length]);

  
    var settings = {
        dots: false,
        arrows:true,
        infinite: false,
        loop:true,
        autoplay:true,
        slidesToShow: 4,
        slidesToScroll: 1,
        draggable: false,
        responsive: [
            {
                breakpoint: 1024,
                settings: {
                    slidesToShow: 3
                }
            },
            {
                breakpoint: 767,
                settings: {
                    slidesToShow: 1
                }
            },
        ]
    };

    return ((recentProductsData && recentProductsData.length > 0 && cart.items.length > 0) ? 
        <div className={styles.root}>
            <div className="products recent-products">
                <div className='wrapper'>
                    <h2 className="title-main">Recently Viewed</h2>
                    <div className="recently-viewed-inner-section">
                        <div className="recently-viewed-inner">
                            <ul className="products columns-3">
                                <Slider {...settings}>
                                {
                                    recentProductsData && recentProductsData.map((recentProductsItem,index) => {
                                        return  <li key={index} className='single-slide'>
                                        <div className="product">
                                            <div className="product-block">
                                                <Link href={UrlReplace(recentProductsItem.permalink)}>
                                                    <Image height={300} width={300} size="100vw" className="img" src={recentProductsItem.images[0].src} alt={recentProductsItem.name} /> 
                                                </Link>
                                            </div>
                                        </div>
                                    </li>  })
                                } 

                                </Slider>
                            </ul>
                        </div>
                    </div>
                </div>
            </div>
        </div> : ''
  );
};

export default RecentlyBasketViewed;
