import React, { useState, useEffect, useRef } from 'react';
import { useDispatch, useSelector } from 'react-redux';
import  Link  from 'next/link';
import Image from 'next/image'
import Slider from "react-slick";
import axios from "axios";
import UrlReplace from "../Common/UrlReplace";
import AddToBasket from '../popup/AddToBasket';
import AddToCart from '../Common/AddToCart';
import styles from '../../styles/shop/SimilarProducts.module.scss';
import "slick-carousel/slick/slick.css";
import "slick-carousel/slick/slick-theme.css";


const SimilarProductsForBasket = () => {

    const { cart, isCartReady } = useSelector(state => state.woocommerce);

    const [similarProductsData, setSimilarProductsData] = useState([]);
    const [productSimilarObjData, setProductSimilarObjData] = useState({});
    const [modalIsOpen, setIsOpen] = useState(false);

    function openModal(productItemObj) {
        setProductSimilarObjData(productItemObj)
        setIsOpen(true);
    }

    function closeModal() {
        setIsOpen(false);
    }




    const handleSimilarProducts = (async () => {

        await axios({
            url: process.env.API_URL + 'wp/v2/similar_product_for_cart',
            withCredentials: true,
            method: 'GET',
            crossDomain: true,
        }).then(function (response) {
            setSimilarProductsData(response.data)

        })

    })

    useEffect(() => {
        handleSimilarProducts();
    }, [cart.items.length]);

    var settings = {
        dots: false,
        arrows: true,
        infinite: true,
        loop: true,
        autoplay: false,
        slidesToShow: 3,
        slidesToScroll: 1,
        responsive: [
            {
                breakpoint: 1024,
                settings: {
                    slidesToShow: 3
                }
            },
            {
                breakpoint: 767,
                settings: {
                    slidesToShow: 2
                }
            },
            {
                breakpoint: 480,
                settings: {
                    slidesToShow: 1
                }
            },
        ]
    };

    return ((similarProductsData.length == 0 || cart.items.length == 0) ? '' :
        <div className={styles.root}>
            <div className="products">
                <div className={styles.wrapper}>
                    <div className="recently-viewed-inner-section similar-product-slider">
                        <div className="recently-viewed-inner">
                            <div className="similar-product">
                                <div className="similar-product-slider">
                                    <h2>Similar Products for Sale</h2>
                                    <Link href={'/shop/'}>View All</Link>
                                </div>
                            </div>
                            <ul className="products columns-3">
                                <Slider {...settings}>
                                    {
                                   similarProductsData && similarProductsData.map((similarProductsItem, index) => {
                                            return <li className='single-slide' key={index}>
                                                <div className="product">
                                                    <div className="product-block">
                                                        <Link href={UrlReplace(similarProductsItem.link)}>
                                                            <Image className="img" height={300} width={300} sizes='100vw' src={similarProductsItem.image} alt="Antique Silver Victorian Claret Jug made in c.1895" />
                                                        </Link>
                                                        <div className="product-content-qr">
                                                            <Link className="product-title-qr" href={UrlReplace(similarProductsItem.link)}>
                                                                <p>{similarProductsItem.name}</p>
                                                            </Link>
                                                            <span className="price">
                                                                <span className="woocommerce-Price-amount amount">
                                                                    <bdi><span className="woocommerce-Price-currencySymbol">£</span>{similarProductsItem.price}</bdi></span>
                                                            </span>

                                                            {((similarProductsItem.stock_status == "instock") ? <AddToCart product={similarProductsItem} openModal={openModal} page="similar" /> : <Link className='single_add_to_cart_button_general_plist button alt single-details-basket-btn btn-basket-similar-pro-cus' href={UrlReplace(similarProductsItem.link)}>ENQUIRE ABOUT THIS PIECE </Link>)}
                                                            {/* <button onClick={() => openModal(similarProductsItem)} type="button" className="single_add_to_cart_button_general_plist button alt single-details-basket-btn btn-basket-similar-pro-cus">Add to Basket</button> */}
                                                        </div>
                                                    </div>
                                                </div>
                                            </li>
                                        })
                                    }
                                </Slider>
                            </ul>
                        </div>
                    </div>
                </div>
                <AddToBasket productData={productSimilarObjData} modalIsOpen={modalIsOpen} closeModal={closeModal} />
            </div>
        </div>
    );
};

export default SimilarProductsForBasket;
