import React, { useCallback, useEffect, useState } from 'react';

import { useDispatch, useSelector } from 'react-redux';
import { Formik, Form, Field, ErrorMessage } from 'formik';
import * as Yup from 'yup';
import Image from 'next/image'
import moment from 'moment';
import axios from 'axios';
import { InlineShareButtons } from 'sharethis-reactjs';
import { useRouter } from 'next/router'
import { fetchOrderHistory } from '../../services';
import UsersApis from "../../helper/UsersApi";
import styles from "../../styles/checkout/orderReceived.module.scss";


const OrderReceivedMainContent = () => {

    const router = useRouter();
    const { slug, key } = router.query;
    //const key = new URLSearchParams(location.search).get("key");

    const { userIsLogin, userIsLoading, userData } = useSelector(state => state.user);
    // const { generalSettingsIsLoading, generalSettingsData, generalSettingsError } = useSelector(state => state.generalSettings);

    const [isOrderDetailLoading, setIsOrderDetailLoading] = useState(true);
    const [orderDetailData, setOrderDetailData] = useState('');
    const [passwordInputType, setPasswordInputType] = useState(false);
    const [buttonText, setButtonText] = useState('REGISTER');
    const [responseMessageStatus, setResponseMessageStatus] = useState('');
    const [optionData, setOptionData] = useState(null);

    const handleOrderDetails = async (orderId) => {
        setIsOrderDetailLoading(true);
        const orderDetailsResponse = await fetchOrderHistory('?include=' + orderId);
        if (orderDetailsResponse.data.length > 0) {
            setOrderDetailData(orderDetailsResponse.data[0]);
        }
        setIsOrderDetailLoading(false);
    }

    const handleGeneralSetting = async () => {
        await axios
            .get(process.env.API_URL + 'acf/v3/options/options?_fields=acf.content_title,acf.content_description')
            .then(function (response) {
                setOptionData(response.data)
            })
    }
    useEffect(() => {
        handleOrderDetails(slug);
        handleGeneralSetting()
    }, []);

    const RegisterSchema = Yup.object().shape({
        first_name: Yup.string().required("First Name Is Required!"),
        last_name: Yup.string().required("Last Name Is Required!"),
        email: Yup.string().required("Email Address Is Required!").email("Email address format not valid"),
        password: Yup.string().required("Password is required.").matches(
            /^(?=.*[a-z])(?=.*[A-Z])(?=.*[0-9])(?=.*[!@#\$%\^&\*])(?=.{8,})/,
            "Must Contain 8 Characters, One Uppercase, One Lowercase, One Number and One Special Case Character"
        ),
        confirm_password: Yup.string().required("Confirm password is required.").oneOf([Yup.ref('password'), null], 'Passwords must match'),
    });
    const OnlyShareThis = () => {

        return (
            <InlineShareButtons
                config={{
                    alignment: 'center',
                    color: 'social',
                    enabled: true,
                    font_size: 15,
                    labels: 'cta',
                    language: 'en',
                    networks: [
                        'twitter',
                        'facebook',
                        'whatsapp',
                        'linkedin',
                        'pinterest',
                        'email',
                        'blogger',
                        'delicious',
                        'digg',
                        'flipboard',
                        'livejournal',
                        'mailru',
                        'meneame',
                        'messenger',
                        'oknoklassniki',
                        'print',
                        'reddit',
                        'sharethis',
                        'sms',
                        'stumbleupon',
                        'telegram',
                        'tumblr',
                        'vk',
                        'wechat',
                        'weibo',
                        'xing',
                        'blogger',
                        'digg',
                        'github',
                        'instagram',
                        'medium',
                        'messenger',
                        'oknoklassniki',
                        'patreon',
                        'pinterest',
                        'quora',
                        'reddit',
                        'snapchat',
                        'soundcloudm',
                        'spotify',
                        'telegram',
                        'tumblr',
                        'twitch',
                        'vk',
                        'wechat',
                        'weibo',
                        'yelp',
                        'youtube'
                    ],
                    padding: 10,
                    radius: 0,
                    show_total: true,
                    size: 40,
                    url: process.env.SITE_URL + 'checkout/',
                    image: '',
                    description: 'Thank you for your order',
                    title: 'Thank you for your order',
                    message: 'Thank you for your order',
                    subject: 'Thank you for your order ',
                }}
            />
        )
    }

    return ((orderDetailData.length == 0) ? ((isOrderDetailLoading == false) ? <div className={styles.root + styles.wrapper}>
        <div className="woocommerce">
            <div className="woocommerce-notices-wrapper">
                <div className="woocommerce-info">
                    Something went wrong
                </div>
            </div>
        </div>
    </div> : '') :
        <div className={styles.root}>
            <div className="content-part">
                <div className={styles.wrapper}>
                    {((key != orderDetailData.orderKey) ?
                        <div className="woocommerce">
                            <div className="woocommerce-notices-wrapper">
                                <div className="woocommerce-info">
                                    Something went wrong
                                </div>
                            </div>
                        </div> :
                        <div className="main-content-part thank-you-order-style">
                            <div className="woocommerce">
                                <div className="woocommerce-order main-product-div">
                                    <div className="left-thank-you">
                                        <table className="shop_table table-thank-you">
                                            <tbody>
                                                <tr>
                                                    <th className="woocommerce-thank-pro">PRODUCT</th>
                                                    <th className="woocommerce-thank-stock-no">STOCK NUMBER</th>
                                                    <th className="woocommerce-thank-price">PRICE</th>
                                                </tr>
                                                {orderDetailData && orderDetailData.lineItems.map((orderDetailItem, index) => {
                                                    return <tr key={index}>
                                                        <td className="pro-name-th">
                                                            <Image width={810} height={426} src={orderDetailItem.image.src} className="attachment-100x100 size-100x100" />
                                                            <span className="product-name-az">
                                                                {orderDetailItem.name}
                                                            </span>
                                                        </td>
                                                        <td>{orderDetailItem.sku}</td>
                                                        <td>{orderDetailData.currencySymbol}{orderDetailItem.price}</td>
                                                    </tr>
                                                })}

                                            </tbody>
                                        </table>
                                        <div className="thank-lt-hp">
                                            {((optionData) &&
                                                <div className="thankyou-notes">
                                                    <h3>{optionData.acf.contentTitle}</h3>
                                                    <p>{optionData.acf.contentDescription}</p>
                                                </div>
                                            )}
                                            <div className=" order-content account-page-ty">
                                                {(((userIsLoading) ? '' : (userIsLogin == false) ?
                                                    <>
                                                        <h3>Create an Account</h3>
                                                        <span>Save time on your next order</span>

                                                        <div className="col-xl-6 ml-auto account-page-thn" id="newUser">
                                                            {((responseMessageStatus == "") ?
                                                                <Formik
                                                                    initialValues={{
                                                                        first_name: orderDetailData.billing.firstName,
                                                                        last_name: orderDetailData.billing.lastName,
                                                                        email: orderDetailData.billing.email,
                                                                        password: '',
                                                                        confirm_password: ''
                                                                    }}
                                                                    validationSchema={RegisterSchema}
                                                                    onSubmit={async (values, { resetForm }) => {

                                                                        setButtonText('Registering...');

                                                                        const nonceResponse = await UsersApis({
                                                                            endpoint: 'get_nonce', method: "GET",
                                                                            params: {
                                                                                'json': 'get_nonce',
                                                                                'controller': 'user',
                                                                                'method': 'register'
                                                                            },
                                                                        });

                                                                        if (nonceResponse.status == "ok") {
                                                                            const registerResponse = await UsersApis({
                                                                                endpoint: 'user/register', method: "GET",
                                                                                params: {
                                                                                    'username': values.email,
                                                                                    'email': values.email,
                                                                                    'nonce': nonceResponse.nonce,
                                                                                    'notify': 'both',
                                                                                    'insecure': 'cool',
                                                                                    'user_pass': values.password,
                                                                                    'first_name': values.first_name,
                                                                                    'last_name': values.last_name
                                                                                },
                                                                            });

                                                                            if (registerResponse.status == "ok") {
                                                                                localStorage.setItem('cookieAuth', registerResponse.cookie);
                                                                                setResponseMessageStatus("success");
                                                                            } else {
                                                                                alert(registerResponse.error);
                                                                                setButtonText('buttonText');
                                                                            }
                                                                        }

                                                                    }} >
                                                                    {({ errors, touched }) => (
                                                                        <Form method="post" className="woocommerce-form woocommerce-form-register register">

                                                                            <div className="row gutters-7 woocommerce_register_account">
                                                                                <div className="woocommerce-form-row woocommerce-form-row--wide form-group form-row-wide ">
                                                                                    <span className="password-input">

                                                                                        <Field type={((passwordInputType == false) ? "password" : "text")} name='password' placeholder="Password*" className="woocommerce-Input woocommerce-Input--text input-text form-control" />
                                                                                        <ErrorMessage component='div' className='formError' name="password" />
                                                                                        <span className="show-password-input" onClick={() => setPasswordInputType((passwordInputType == false) ? true : false)}></span>
                                                                                    </span>
                                                                                </div>
                                                                                <div className="woocommerce-form-row form-group form-row-wide">
                                                                                    <Field type="password" name='confirm_password' placeholder="Confirm Password*" className="input-text form-control" />
                                                                                    <ErrorMessage component='div' className='formError' name="confirm_password" />
                                                                                </div>
                                                                                <div className="registrationFormAlert" id="divCheckPasswordMatch"></div>

                                                                                <div className="woocommerce-FormRow form-group submit-col col text-right btn-register-thanks">
                                                                                    <button type="submit" className="woocommerce-Button btn btn-primary" name="register" id="registrationNew" value="Register">
                                                                                        {buttonText}
                                                                                    </button>
                                                                                </div>

                                                                            </div>

                                                                        </Form>
                                                                    )}
                                                                </Formik> : <h2>Account has been created</h2>)}
                                                        </div> </> : ''))}

                                            </div>
                                        </div>
                                    </div>
                                    <div className="right-thank-you">
                                        <div className="thank-order-summary">
                                            <div className="d-flex flex-wrap align-items-start justify-content-between heading-title">
                                                <h2 className="entry-title">Order Summary</h2>
                                            </div>
                                            <div className="order-summary-part">
                                                <div className="order-s-1">
                                                    <div className="order-id w-50">
                                                        <span className="clr-a2">Order Number </span>
                                                        <br />
                                                        <span>#{orderDetailData.number}</span>
                                                    </div>
                                                    <div className="order-date w-50">
                                                        <span className="clr-a2">Order Date </span> <br />
                                                        <span>{moment(orderDetailData.dateCreated).format('DD, MMMM YYYY')}</span>
                                                    </div>
                                                </div>
                                                <div className="order-s-2">
                                                    <div className="order-delivery w-50">
                                                        <span className="clr-a2">Delivery </span> <br />
                                                        {orderDetailData && orderDetailData.shippingLines.map((shippingLinesItem, index) => {
                                                            return <> <span key={index}>{shippingLinesItem.methodTitle}</span><br /></>
                                                        })}

                                                    </div>
                                                    <div className="order-personal-details w-50">
                                                        <span className="clr-a2"> Personal Details </span> <br />
                                                        <span>
                                                            {orderDetailData.billing.firstName}&nbsp;{orderDetailData.billing.lastName}
                                                            <br />
                                                            {orderDetailData.billing.email}
                                                        </span>
                                                    </div>
                                                </div>
                                                <div className="order-s-3">
                                                    <div className="order-billing-add w-50">
                                                        <span className="clr-a2">Billing Address </span> <br />


                                                        <span>{orderDetailData.billing.address1}<br /></span>
                                                        <span>{((orderDetailData.billing.address2) ? orderDetailData.billing.address2 : '')}</span>
                                                        <span>{((orderDetailData.billing.address2) ? <br /> : '')}</span>
                                                        <span>{orderDetailData.billing.city}<br /></span>
                                                        <span>{orderDetailData.billing.state}</span>
                                                    </div>
                                                    <div className="order-shipping-add w-50">
                                                        <span className="clr-a2">Shipping Address </span>  <br />
                                                        <span>{orderDetailData.shipping.address1}<br /></span>
                                                        <span>{((orderDetailData.shipping.address2) ? orderDetailData.shipping.address2 : '')}</span>
                                                        <span>{((orderDetailData.shipping.address2) ? <br /> : '')}</span>
                                                        <span>{orderDetailData.shipping.city}<br /></span>
                                                        <span>{orderDetailData.shipping.state}</span>
                                                    </div>
                                                </div>
                                                <div className="order-share-with">
                                                    <label>Share This: </label>
                                                    <div className="addtoany_shortcode">
                                                        <div className="a2a_kit a2a_kit_size_26 addtoany_list" data-a2a-title="Thank you for your order" >
                                                            {OnlyShareThis()}
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
                                        <div className="thankyou-total">
                                            <div className="order-subtotal f-w-4">
                                                <span>Subtotal </span>
                                                <span>
                                                    <span className="woocommerce-Price-amount amount">
                                                        <bdi>
                                                            <span className="woocommerce-Price-currencySymbol">
                                                                £{Number(orderDetailData.total) - Number(orderDetailData.shippingTotal)}
                                                            </span>
                                                        </bdi>
                                                    </span>
                                                </span>
                                            </div>
                                            {((Number(orderDetailData.discountTotal) > 0) ?
                                                <div className="order-discount f-w-4">
                                                    <span>Discount Code</span>
                                                    <span>
                                                        <span className="woocommerce-Price-amount amount">
                                                            <bdi>
                                                                <span className="woocommerce-Price-currencySymbol">
                                                                    £{orderDetailData.discountTotal}
                                                                </span>
                                                            </bdi>
                                                        </span>
                                                    </span>
                                                </div> : '')}
                                            <div className="order-discount f-w-4">
                                                <span>Delivery </span>
                                                <span>£{orderDetailData.shippingTotal}</span>
                                            </div>
                                            <div className="order-grand-total f-w-4">
                                                <span>Grand Total </span>
                                                <span>£{orderDetailData.total}</span>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>)}
                </div>
            </div>
        </div>
    );
};

export default OrderReceivedMainContent;