import dynamic from 'next/dynamic'
import React, { useState, useRef } from 'react';
import { Formik, Form, Field, ErrorMessage, useFormikContext } from 'formik';
import * as Yup from 'yup';
import Image from "next/image";
const ReCAPTCHA = dynamic(() => import("react-google-recaptcha"));

import { submitContactFormWithId } from '../../services';
//import '../../style/contact/contactform.scss';
import styles from '../../styles/cmspage/Contactform.module.scss';


const ContactForm = ({ contactUsData }) => {

    const ref = useRef();

    const [g_recaptcha_response, set_g_recaptcha_response] = useState('');
    const [ReCaptch, SetReCaptch] = useState(null);
    const [buttonText, setButtonText] = useState('SEND MESSAGE');
    const [contactFormSuccess, setContactFormSuccess] = useState(null);
    const [recaptchaNeeded, setRecaptchaNeeded] = useState(false);

    const resetCaptcha = () => {
        ref.current.reset();
        SetReCaptch(null);
        set_g_recaptcha_response('')
    }

    const onChangeCaptchavalue = (value) => {
        SetReCaptch(true);
        set_g_recaptcha_response(value)
        setContactFormSuccess(null)
    }

    const onExpiredCaptchavalue = (value) => {
        SetReCaptch(false);
        set_g_recaptcha_response('')
        setContactFormSuccess(null)
    }

    const ContactSchema = Yup.object().shape({
        firstName: Yup.string().required("This field is required."),
        lastName: Yup.string().required("This field is required."),
        yourMessage: Yup.string().required("This field is required."),
        yourEmail: Yup.string().email('The e-mail address entered is invalid.').required("This field is required.")
    });

    const AutoSubmitToken = () => {
        const { values } = useFormikContext();
        React.useEffect(() => {
            if (values.firstName)
                setRecaptchaNeeded(true)
        }, [values]);
        return null;
    };

    return (
        <section className={styles.root}>
            <div className="contact-Us">
                <div className="wrapper">
                    <div className="form-section">
                        <div className="form-left-block">
                            <div className="wpcf7 js" id="wpcf7-f50-o1" lang="en-US" dir="ltr">

                                <Formik
                                    initialValues={{
                                        yourEmail: '',
                                        firstName: '',
                                        lastName: '',
                                        yourPhone: '',
                                        yourMessage: '',
                                        reason: '',
                                        confirm: false
                                    }}

                                    validationSchema={ContactSchema}
                                    onSubmit={async (values, { resetForm }) => {

                                        setButtonText('Submitting...')
                                        if (ReCaptch == true) {
                                            const form = new FormData();

                                            form.append('first-name', values.firstName);
                                            form.append('last-name', values.lastName);
                                            form.append('your-email', values.yourEmail);
                                            form.append('your-phone', values.yourPhone);
                                            form.append('reason', values.reason);
                                            form.append('your-message', values.yourMessage);
                                            form.append('confirm[]', values.confirm);
                                            form.append('g-recaptcha-response', g_recaptcha_response);

                                            const contactFormResponse = await submitContactFormWithId(50, form);
                                            setContactFormSuccess(contactFormResponse)
                                            setButtonText('SEND MESSAGE')
                                            resetCaptcha();
                                            resetForm()
                                        } else {
                                            SetReCaptch(false)
                                            setButtonText('SEND MESSAGE')
                                            setContactFormSuccess(null)
                                        }

                                    }} >
                                    {({ errors, touched }) => (

                                        <Form method="post" className="wpcf7-form mailchimp-ext-0.5.67 init">
                                            <AutoSubmitToken />
                                            <div className="contact">
                                                <h3>Email Us</h3>

                                                <div className="input-part half">
                                                    <p>
                                                        <span className="wpcf7-form-control-wrap" data-name="firstName">
                                                            <Field name='firstName' className="wpcf7-form-control wpcf7-text wpcf7-validates-as-required" placeholder="First Name*" />
                                                            <ErrorMessage component='div' className='formError' name="firstName" />
                                                        </span>
                                                    </p>
                                                </div>


                                                <div className="input-part half">
                                                    <p>
                                                        <span className="wpcf7-form-control-wrap" data-name="lastName">
                                                            <Field name='lastName' className="wpcf7-form-control wpcf7-text wpcf7-validates-as-required" placeholder="Last Name*" />
                                                            <ErrorMessage component='div' className='formError' name="lastName" />
                                                        </span>
                                                    </p>
                                                </div>

                                                <div className="input-part">
                                                    <p>
                                                        <span className="wpcf7-form-control-wrap" data-name="yourEmail">
                                                            <Field name='yourEmail' className="wpcf7-form-control wpcf7-text wpcf7-email wpcf7-validates-as-required wpcf7-validates-as-email" placeholder="Your Email Address*" />
                                                            <ErrorMessage component='div' className='formError' name="yourEmail" />
                                                        </span>
                                                    </p>
                                                </div>

                                                <div className="input-part">
                                                    <p>
                                                        <span className="wpcf7-form-control-wrap" data-name="yourPhone">
                                                            <Field name='yourPhone' className="wpcf7-form-control wpcf7-text" placeholder="Phone Number" />
                                                        </span>
                                                    </p>
                                                </div>

                                                <div className="input-part">
                                                    <p>
                                                        <span className="wpcf7-form-control-wrap" data-name="reason">
                                                            <Field as="select" className="wpcf7-form-control wpcf7-select" name="reason">
                                                                <option value>Reason (please select)</option>
                                                                <option value="Wish to make a purchase">Wish to make a purchase</option>
                                                                <option value="Make a general enquiry">Make a general enquiry</option>
                                                                <option value="Need an Insurance Valuation">Need an Insurance Valuation</option>
                                                            </Field>
                                                        </span>
                                                    </p>
                                                </div>

                                                <div className="input-part">
                                                    <p>
                                                        <span className="wpcf7-form-control-wrap" data-name="yourMessage">
                                                            <Field component="textarea" cols="40" rows="10" className="wpcf7-form-control wpcf7-textarea wpcf7-validates-as-required" placeholder="Your Message*" name="yourMessage" />
                                                            <ErrorMessage component='div' className='formError' name="yourMessage" />
                                                        </span>
                                                    </p>
                                                </div>

                                                <div className="input-part checkbox-part">
                                                    <p>
                                                        <span className="wpcf7-form-control-wrap" data-name="confirm">
                                                            <span className="wpcf7-form-control wpcf7-checkbox">
                                                                <span className="wpcf7-list-item first last">
                                                                    <label>
                                                                        <input type="checkbox" name="confirm" value="I consent to receive future marketing" />
                                                                        <span className="wpcf7-list-item-label">I consent to receive future marketing</span>
                                                                    </label>
                                                                </span>
                                                            </span>
                                                        </span>
                                                    </p>
                                                </div>
                                                {recaptchaNeeded && <div className="captcha">
                                                    <ReCAPTCHA
                                                        sitekey='6LcMGWkUAAAAAM5vA9rkbH1rbYyu19H1Nwg8rXet'
                                                        onChange={onChangeCaptchavalue}
                                                        onExpired={onExpiredCaptchavalue}
                                                        ref={ref}
                                                    />
                                                </div>}
                                                <div className='formError'>{(ReCaptch == false) ? 'Please verify that you are not a robot.' : ''}</div>

                                                <div className="button-section">
                                                    <p>
                                                        <button className="wpcf7-form-control has-spinner wpcf7-submit" type="submit">{buttonText}</button>
                                                        <span className="wpcf7-spinner" />
                                                    </p>
                                                </div>
                                            </div>
                                        </Form>
                                    )}
                                </Formik>

                                {((contactFormSuccess) ? <div className='success-msg'>{contactFormSuccess.message}</div> : '')}


                            </div>
                        </div>
                        <div className="img-right-block">
                            <Image sizes='100vw' priority width={591} height={671} className="img webpexpress-processed" src={contactUsData.acf.formImage.sizes.contactFrmImg} alt="Contact-Us" />
                        </div>
                    </div>
                </div>
            </div>
        </section>
    );
};



export default ContactForm;