import React, { useState, useEffect } from 'react';
import  Link  from 'next/link';
import Image from 'next/image';
import { useDispatch } from 'react-redux';
import { Formik, Form, Field, ErrorMessage, getIn } from 'formik';
import * as Yup from 'yup';
import { userUpdate } from '../../reducer/userSlice';
import AddressApi from "../../helper/AddressApi";
import eye from '../../assets/eye-icon.svg';
import styles from '../../styles/myaccount/AccountPages.module.scss';


const EditAccountMain = ({userData}) => {

    const dispatch = useDispatch();
    const [btnText, setButtonText] = useState("Save changes");
    const [passwordDisplayObj, setPasswordDisplayObj] = useState({"currentPassword" : false,"newPassword" : false,"confirmPassword" : false});
    const [responseMessage, setResponseMessage] = useState('');
    const [responseMessageStatus, setResponseMessageStatus] = useState(null);
    const [refreshComponet, setRefreshComponet] = useState('');
    const [userSuffixTitle, setUserSuffixTitle] = useState('');

    const AccountSchema = Yup.object().shape({
        account_first_name: Yup.string().required("Field Is Required!"),
        account_last_name: Yup.string().required("Field Is Required!"),
        account_email: Yup.string().required("Field Is Required!"),
    });
    
    const diaplayPassword = (type) => {
        if(type == "currentPassword")
        {
            setPasswordDisplayObj({...passwordDisplayObj, currentPassword : !passwordDisplayObj.currentPassword});
        }else if(type == "newPassword")
        {
            setPasswordDisplayObj({...passwordDisplayObj, newPassword : !passwordDisplayObj.newPassword});
        }else
        {
            setPasswordDisplayObj({...passwordDisplayObj, confirmPassword : !passwordDisplayObj.confirmPassword});
        }
    }

    const handleUserSuffixTitle = async (userId) => {
        const userSuffixTitleResponse = await AddressApi({ endpoint: 'wp/v2/get_user_suffix_title', method: "GET", 
                                params: { 
                                    'user_id' : userId 
                                    }, 
                                });
        setUserSuffixTitle(userSuffixTitleResponse.user_suffix_title);
        setRefreshComponet(Math.random());
    }

    useEffect(() => {
        if(userSuffixTitle == "")
        {
            handleUserSuffixTitle(userData.id);
        }
    },[]);

   
    
    return (
    <section className={styles.root}>
        <div className="content-part">
            <div className={styles.wrapper}>
                <div className="main-content-part">
                    <div className="woocommerce">
                        <nav className="woocommerce-MyAccount-navigation">
                            <ul>
                            <li className="woocommerce-MyAccount-navigation-link woocommerce-MyAccount-navigation-link--edit-account is-active">
                                <Link href="/my-account/edit-account/">Dashboard</Link>
                            </li>
                            <li className="woocommerce-MyAccount-navigation-link woocommerce-MyAccount-navigation-link--edit-address">
                                <Link href="/my-account/edit-address/">Address Book</Link>
                            </li>
                            <li className="woocommerce-MyAccount-navigation-link woocommerce-MyAccount-navigation-link--orders">
                                <Link href="/my-account/orders/">Order History</Link>
                            </li>
                            </ul>
                        </nav>
                        <div className="woocommerce-MyAccount-content">
                            
                            <div className="woocommerce-notices-wrapper">
                                { ((responseMessageStatus == true) ? <div className="woocommerce-message" role="alert"> {responseMessage} </div> : '')  }
                                { ((responseMessageStatus == false) ? <div className="woocommerce-error" role="alert"> {responseMessage && responseMessage.map((errorItem,index) => {
                                    return <span key={index}>{errorItem[1]}<br /></span>
                                })} </div> : '')  }
                            </div>

                            <div className="block-title">
                                <h3 className="title">Your contact details</h3>
                            </div> 
                                <Formik
                                    initialValues={{
                                        user_id: userData.id,
                                        user_suffix_title: userSuffixTitle ? userSuffixTitle : "",
                                        account_first_name: userData.firstname,
                                        account_last_name: userData.lastname,
                                        account_email: userData.email,
                                        password_current: '',
                                        password_1: '',
                                        password_2: '',
                                    }}
                                    validationSchema={AccountSchema}
                                    onSubmit={ async (values,  { resetForm }) => {
                                        
                                        
                                            setButtonText('Saving...');

                                            const updateAccountResponse = await AddressApi({ endpoint: 'wp/v2/updateAccount', method: "POST", 
                                                params: values, 
                                            });
                                            
                                            setResponseMessageStatus(updateAccountResponse.status);
                                            if(updateAccountResponse.status == false)
                                            {
                                                setResponseMessage( Object.keys(updateAccountResponse.msg).map((key) => [key, updateAccountResponse.msg[key]]));
                                            }else
                                            {
                                                dispatch(userUpdate(values));
                                                setResponseMessage(updateAccountResponse.msg);
                                            }
                                            
                                            setButtonText('Save changes');
                                    }} >
                                    {({ errors, touched }) => (

                                        <Form method="post">

                                            <div className="woocommerce-EditAccountForm edit-account d-flex d-flex-wrap form-row-outer">

                                                <p className="form-row select-box validate-required" id="user_suffix_title_field" data-priority>
                                                    <span className="woocommerce-input-wrapper">
                                                        <Field as="select" name="user_suffix_title" id="user_suffix_title" className="select">
                                                            <option value="mr">Mr.</option>
                                                            <option value="ms">Ms.</option>
                                                            <option value="mrs">Mrs.</option>
                                                        </Field>
                                                    </span>
                                                </p>
                                                
                                                <div className="woocommerce-form-row woocommerce-form-row--first form-row form-row-first form-row-half">
                                                    <label htmlFor="account_first_name">First name&nbsp;<span className="required">*</span></label>
                                                    <Field className="woocommerce-Input woocommerce-Input--text input-text" name="account_first_name"  placeholder="First Name*" />
                                                    <ErrorMessage component='div' className='formError' name="account_first_name" />
                                                </div>

                                                <div className="woocommerce-form-row woocommerce-form-row--last form-row form-row-last form-row-half">
                                                    <label htmlFor="account_last_name">Last name&nbsp;<span className="required">*</span></label>
                                                    <Field className="woocommerce-Input woocommerce-Input--text input-text" name="account_last_name" placeholder="Last Name*" />
                                                    <ErrorMessage component='div' className='formError' name="account_last_name" />
                                                </div>

                                                <div className="woocommerce-form-row woocommerce-form-row--last form-row form-row-last form-row-half">
                                                    <label htmlFor="account_email">Email address&nbsp;<span className="required">*</span></label>
                                                    <Field className="woocommerce-Input woocommerce-Input--email input-text" name="account_email" placeholder="Eamil*" />
                                                    <ErrorMessage component='div' className='formError' name="account_email" />
                                                </div>

                                                <div className="woocommerce-form-row woocommerce-form-row--wide form-row form-row-half">
                                                    <label htmlFor="password_current">Current password (leave blank to leave unchanged)</label>
                                                    <span className="password-input">
                                                        <Field type={((passwordDisplayObj.currentPassword) ? "text" : "password")} className="woocommerce-Input woocommerce-Input--password input-text" name="password_current" placeholder="Current password" />   
                                                        <span onClick={() => diaplayPassword('currentPassword')} className="show-password-input"><Image src={eye} /></span>
                                                    </span>
                                                </div>

                                                <div className="woocommerce-form-row woocommerce-form-row--wide form-row form-row-half">
                                                    <label htmlFor="password_1">New password (leave blank to leave unchanged)</label>
                                                    <span className="password-input">
                                                        <Field type={((passwordDisplayObj.newPassword) ? "text" : "password")} className="woocommerce-Input woocommerce-Input--password input-text" name="password_1" placeholder="New password" />   
                                                        <span onClick={() => diaplayPassword('newPassword')} className="show-password-input"><Image src={eye} /></span>
                                                    </span>
                                                </div>


                                                <div className="woocommerce-form-row woocommerce-form-row--wide form-row form-row-half">
                                                    <label htmlFor="password_2">Confirm new password</label>
                                                    <span className="password-input">
                                                        <Field type={((passwordDisplayObj.confirmPassword) ? "text" : "password")} className="woocommerce-Input woocommerce-Input--password input-text" name="password_2" placeholder="Confirm new password" />   
                                                        <span onClick={() => diaplayPassword('confirmPassword')} className="show-password-input"><Image src={eye} /></span>
                                                    </span>
                                                </div>

                                                <div className="woocommerce-form-row woocommerce-form-row--first form-row form-row-wide">
                                                    <button type="submit" className="woocommerce-Button button btn btn-primary save-change" name="save_account_details" value="Save changes">{btnText}</button>
                                                </div>

                                            </div>      
                                        </Form>
                                    )}
                                </Formik>
                             
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </section>
  );
};

export default EditAccountMain;
