import React, { useState, useEffect } from 'react';
import  Link  from 'next/link';
import Image from 'next/image'
import AddressApi from "../../helper/AddressApi";
import { fetchShippingCountries } from '../../services';
import AddNewAddress from '../popup/AddNewAddress';
import roundloader from '../../assets/round-loader.svg';
import styles from '../../styles/myaccount/AccountPages.module.scss';


const EditAddressMain = ({userData}) => {

    const [isAddressLoading,setIsAddressLoading] = useState(true);
    const [modalIsOpen, setIsOpen] = useState(false);
    const [userAddressData,setUserAddressData] = useState([]);
    const [shippingCountriesData,setShippingCountriesData] = useState([]);
    const [refreshComponet, setRefreshComponet] = useState('');
    const [addressIndexData, setAddressIndexData] = useState('');

    function openModal() {
        setAddressIndexData('');
        setIsOpen(true);
    }

    function closeModal(refreshC = false) {
        if(refreshC == true)
        {
            setRefreshComponet(Math.random());
        }
        setIsOpen(false);
    }

    const handleUserAddress = async (userId) => {
        const userAddressResponse = await AddressApi({ endpoint: 'wp/v2/ocwma_get_address', method: "GET", 
                                params: { 
                                    'user_id' : userId 
                                    }, 
                                });
        setIsAddressLoading(false);
        setUserAddressData(userAddressResponse);
    }

    const editAddress = (indexData) => {
        setAddressIndexData(indexData);
        setIsOpen(true);
    }

    const deleteAddress = async (addressId) => {
        if(window.confirm("Are you sure? \nYou want to delete this address ?"))
        {
            setIsAddressLoading(true);
            const deleteAddressResponse = await AddressApi({ 
                                    endpoint: 'wp/v2/ocwma_delete_address', 
                                    method: "POST", 
                                    params: { 
                                        'did' : addressId 
                                        }, 
                                    });
            if(deleteAddressResponse.status == true)
            {
                setRefreshComponet(Math.random());
            }else
            {
                alert(deleteAddressResponse.message);
                setIsAddressLoading(false);
            }
        }
    }

    const setBillingDefaultAddress = async (userId, addressId) => {
        setIsAddressLoading(true);
        const billingAddressResponse = await AddressApi({ 
                                endpoint: 'wp/v2/ocwma_setdefault_billing', 
                                method: "POST", 
                                params: { 
                                    'defuser' : userId,
                                    'did' : addressId 
                                    }, 
                                });
        if(billingAddressResponse.status == true)
        {
            setRefreshComponet(Math.random());
        }else
        {
            alert(billingAddressResponse.message);
            setIsAddressLoading(false);
        }
    }

    const setShippingDefaultAddress = async (userId, addressId) => {
        setIsAddressLoading(true);
        const shippingAddressResponse = await AddressApi({ 
                                endpoint: 'wp/v2/ocwma_setdefault_shipping', 
                                method: "POST", 
                                params: { 
                                    'defuser' : userId,
                                    'did-ship' : addressId 
                                    }, 
                                });
        if(shippingAddressResponse.status == true)
        {
            setRefreshComponet(Math.random());
        }else
        {
            alert(shippingAddressResponse.message);
            setIsAddressLoading(false);
        }
    }

    const handleShippingCountries = async () => {
        const shippingCountriesResponse = await fetchShippingCountries();
        setShippingCountriesData(Object.keys(shippingCountriesResponse).map((key) => [key, shippingCountriesResponse[key]]));
    }
    
    useEffect(() => {
        handleShippingCountries(); 
        handleUserAddress(userData.id);
    },[refreshComponet]);

    return (
    <section className={styles.root}>
        <div className="content-part">
            <div className={styles.wrapper}>
                <div className="main-content-part">
                    <div className="woocommerce">
                        <nav className="woocommerce-MyAccount-navigation">
                            <ul>
                            <li className="woocommerce-MyAccount-navigation-link woocommerce-MyAccount-navigation-link--edit-account">
                                <Link href="/my-account/edit-account/">Dashboard</Link>
                            </li>
                            <li className="woocommerce-MyAccount-navigation-link woocommerce-MyAccount-navigation-link--edit-address is-active">
                                <Link href="/my-account/edit-address/">Address Book</Link>
                            </li>
                            <li className="woocommerce-MyAccount-navigation-link woocommerce-MyAccount-navigation-link--orders">
                                <Link href="/my-account/orders/">Order History</Link>
                            </li>
                            </ul>
                        </nav>
                        <div className="woocommerce-MyAccount-content">
                            <div className="woocommerce-notices-wrapper"></div>
                            <div className="block-title"><h3 className="title">Address Book</h3></div>
                            <div className="ocwma_table_custom">
                                <div className="ocwma_table_bill">                
                                    <div className="cus_menu cus-bill-add">
                                        <div className="billling-button">
                                            <button onClick={() => openModal()} className="form_option_billing">Add</button>
                                        </div>
                                    </div> 
                                    
                                    {((isAddressLoading) ? '' :
                                        userAddressData && userAddressData.map((userAddressItem,index) => {
                                            return <div key={index} className="cus-bill-add">
                                                {((userAddressItem.default_status == "selected" && (userAddressItem.type == "both" || userAddressItem.type == "billing")) ? <><span>DEFAULT BILLING ADDRESS</span><br /></> : '')}
                                                {((userAddressItem.default_status == "selected" && (userAddressItem.type == "both" || userAddressItem.type == "shipping")) ? <><span>DEFAULT SHIPPING ADDRESS</span><br /></> : '')}
                                                {userAddressItem.userdata.reference_field}<br />
                                                {userAddressItem.userdata.billing_first_name}&nbsp;&nbsp;{userAddressItem.userdata.billing_last_name},<br />
                                                { ((userAddressItem.userdata.billing_company) ? (userAddressItem.userdata.billing_company) +',' : '') }
                                                { ((userAddressItem.userdata.billing_company) ?  <br /> : '') }
                                                {userAddressItem.userdata.billing_address_1},&nbsp;{userAddressItem.userdata.billing_address_2},<br />
                                                {userAddressItem.userdata.billing_city},&nbsp;{userAddressItem.userdata.billing_state}&nbsp;{userAddressItem.userdata.billing_country},&nbsp;{userAddressItem.userdata.billing_postcode}
                                                <div className="actions-add-link">
                                                    <button onClick={() => editAddress(userAddressItem)} type='button' className="form_option_edit">edit</button>
                                                    <a onClick={() => deleteAddress(userAddressItem.id)}>Remove</a>
                                                    { ((userAddressItem.default_status == null) ? <a onClick={() => setBillingDefaultAddress(userAddressItem.userid,userAddressItem.id)}>Set As Default Billing Address</a> : '' ) } 
                                                    { ((userAddressItem.default_status == null) ? <a onClick={() => setShippingDefaultAddress(userAddressItem.userid,userAddressItem.id)}>Set As Default Shipping Address</a> : '' ) } 
                                                </div>
                                            </div>
                                        }))
                                    }
                                    <Image className="loader-image" height={30} width={30} src={roundloader} style={{display: ((isAddressLoading) ? '' :  'none')}} />
                                </div>            
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <AddNewAddress addressIndexData={addressIndexData} setIsAddressLoading={setIsAddressLoading} modalIsOpen={modalIsOpen} closeModal={closeModal} userData={userData} shippingCountriesData={shippingCountriesData} />
        </div>
    </section>
  );
};

export default EditAddressMain;
