import React, { useState } from 'react';
import { Formik, Form, Field, ErrorMessage } from 'formik';
import * as Yup from 'yup';
import UsersApis from "../../helper/UsersApi";
//import '../../style/my-account/login.scss';

const ForgotPassword = () => {

    const [buttonText, setButtonText] = useState('Reset password');
    const [responseMessage, setResponseMessage] = useState('');
    const [responseMessageStatus, setResponseMessageStatus] = useState('');

    const ForgotPasswordSchema = Yup.object().shape({
        user_login: Yup.string().required("Enter a username or email address."),
    });

    return (
        <>
            <div className="content-part">
                <div className="wrapper">
                    <div className="login-register">
                        <div className="woocommerce-notices-wrapper">
                            {
                                (responseMessageStatus == "error") ?
                                    <ul className="woocommerce-error" role="alert">
                                        <li dangerouslySetInnerHTML={{ __html: responseMessage }}>
                                        </li>
                                    </ul> : ''
                            }

                            {
                                (responseMessageStatus == "success") ?
                                    <ul className="woocommerce-message" role="alert">
                                        <li dangerouslySetInnerHTML={{ __html: responseMessage }}>
                                        </li>
                                    </ul> : ''
                            }
                        </div>
                        <div className="woocommerce"><div className="woocommerce-notices-wrapper" />
                            <div className="entry-content-woocommerce">

                                {((responseMessageStatus == "success") ?

                                    <p>A password reset email has been sent to the email address on file for your account, but may take several minutes to show up in your inbox. Please wait at least 10 minutes before attempting another reset.</p>
                                    :

                                    <Formik
                                        initialValues={{
                                            user_login: ''
                                        }}
                                        validationSchema={ForgotPasswordSchema}
                                        onSubmit={async (values, { resetForm }) => {

                                            setButtonText('Loading...')

                                            const forgotPasswordResponse = await UsersApis({
                                                endpoint: 'user/retrieve_password', method: "GET",
                                                params: {
                                                    'user_login': values.user_login,
                                                    'insecure': 'cool'
                                                },
                                            });

                                            if (forgotPasswordResponse.status == "ok") {

                                                setResponseMessage('Password reset email has been sent.');
                                                setResponseMessageStatus("success");
                                            } else {
                                                setResponseMessage(forgotPasswordResponse.error);
                                                setResponseMessageStatus("error");
                                                setButtonText('Reset password');
                                            }

                                        }} >
                                        {({ errors, touched }) => (

                                            <Form method="post" className="woocommerce-ResetPassword lost_reset_password">

                                                <div>
                                                    <p>Lost your password? Please enter your username or email address. You will receive a link to create a new password via email.</p>
                                                    <p className="woocommerce-form-row woocommerce-form-row--first form-row form-row-first">
                                                        <Field name='user_login' className="woocommerce-Input woocommerce-Input--text input-text" />
                                                        <ErrorMessage component='div' className='formError' name="user_login" />
                                                    </p>
                                                    <div className="clear">
                                                        <p className="woocommerce-form-row form-row">
                                                            <button type="submit" className="woocommerce-Button button" value="Reset password">{buttonText}</button>
                                                        </p>
                                                    </div>
                                                </div>
                                            </Form>
                                        )}
                                    </Formik>
                                )}
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </>
    );
};

export default ForgotPassword;
