import React, { useCallback, useEffect, useState } from 'react';
import Link from 'next/link';
import Image from 'next/image'
import { useDispatch, useSelector } from 'react-redux';
import moment from 'moment';
//import { useParams } from 'react-router-dom';
import { fetchOrderHistory } from '../../services';
import { pendingCart, getCart } from "../../reducer/woocommerceSlice";
import storeApi from "../../helper/StoreApi";
import roundloader from '../../assets/round-loader.svg';
//import '../../style/my-account/accountpages.scss';
import { useRouter } from 'next/router'
import styles from '../../styles/myaccount/AccountPages.module.scss';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome'
import { faEnvelope, faPhone } from '@fortawesome/free-solid-svg-icons';


const OrderDetailsMain = ({ userData, params }) => {

    const router = useRouter();
    const order_id = router.query.slug;
    const dispatch = useDispatch()

    const [isOrderDetailLoading, setIsOrderDetailLoading] = useState(true);
    const [orderDetailData, setOrderDetailData] = useState('');
    const [btnText, setBtnText] = useState('Order again');

    const handleOrderDetails = async (userId, orderId) => {
        setIsOrderDetailLoading(true);
        const orderDetailsResponse = await fetchOrderHistory('?customer=' + userId + '&include=' + orderId);
        if (orderDetailsResponse.data.length > 0) {
            setOrderDetailData(orderDetailsResponse.data[0]);
        }
        setIsOrderDetailLoading(false);
    }


    useEffect(() => {
        handleOrderDetails(userData.id, order_id);
    }, []);

    const orderAgain = async (products) => {
        setBtnText('Order adding...');
        const addTOcartData = products.map((productItem, index) => {
            var id = productItem.productId;
            var quantity = productItem.quantity;
            return addToCart(id, quantity);
        })


        await Promise.all(addTOcartData).then((res) => {
            window.location.href = "/basket";
        });


    }


    const addToCart = useCallback(async (id, quantity) => {
        dispatch(pendingCart());
        const getcartResponse = await storeApi({ endpoint: "cart/add-item", params: { id, quantity }, method: "POST", });
        if (getcartResponse && getcartResponse.data && getcartResponse.data.status == 400) {
            if (localStorage.getItem('notAddedIntoCart') == null || localStorage.getItem('notAddedIntoCart') == "") {
                localStorage.setItem('notAddedIntoCart', id);
            } else {
                localStorage.setItem('notAddedIntoCart', localStorage.getItem('notAddedIntoCart') + ',' + id);
            }

            return 'not_added';
        }
        else {
            dispatch(getCart(getcartResponse));
            localStorage.setItem('addedIntoCart', 'Yes');
            return 'added';
        }

    }, [])

    return (
        <section className={styles.root}>
            <div className="content-part">
                <div className={styles.wrapper}>
                    <div className="main-content-part">
                        <div className="woocommerce">
                            <nav className="woocommerce-MyAccount-navigation">
                                <ul>
                                    <li className="woocommerce-MyAccount-navigation-link woocommerce-MyAccount-navigation-link--edit-account">
                                        <Link href="/my-account/edit-account/">Dashboard</Link>
                                    </li>
                                    <li className="woocommerce-MyAccount-navigation-link woocommerce-MyAccount-navigation-link--edit-address">
                                        <Link href="/my-account/edit-address/">Address Book</Link>
                                    </li>
                                    <li className="woocommerce-MyAccount-navigation-link woocommerce-MyAccount-navigation-link--orders is-active">
                                        <Link href="/my-account/orders/">Order History</Link>
                                    </li>
                                </ul>
                            </nav>
                            <div className="woocommerce-MyAccount-content">
                                <div className="woocommerce-notices-wrapper"></div>
                                {((orderDetailData == "" && isOrderDetailLoading == false) ?
                                    <div className="woocommerce-error">
                                        Invalid order.&nbsp;
                                        <Link href="/my-account/" className="wc-forward">My account</Link>
                                    </div> : '')}

                                <Image height={30} width={30} className="loader-image" src={roundloader} style={{ display: ((isOrderDetailLoading) ? '' : 'none') }} />

                                {((orderDetailData != "") ?
                                    <div className='account-order-details'>
                                        <p> Order #<mark className="order-number">{orderDetailData.id} </mark> was placed on <mark className="order-date"> {moment(orderDetailData.dateCreated).format('MMMM DD, YYYY')} </mark> and is currently <mark className="order-status"> {((orderDetailData.status == "pending") ? 'pending payment' : orderDetailData.status)}</mark>.</p>
                                        <div className="woocommerce-order-details main-order-details">
                                            <h2 className="woocommerce-order-details__title">Order details</h2>
                                            <table className="woocommerce-table woocommerce-table--order-details shop_table order_details">
                                                <thead>
                                                    <tr>
                                                        <th className="woocommerce-table__product-name product-name">Product</th>
                                                        <th className="woocommerce-table__product-table product-total">Total</th>
                                                    </tr>
                                                </thead>
                                                <tbody>
                                                    {orderDetailData.lineItems && orderDetailData.lineItems.map((orderDetailItem, index) => {
                                                        return <tr className="woocommerce-table__line-item order_item">

                                                            <td key={index} className="woocommerce-table__product-name product-name">
                                                                <Link href="#"><span dangerouslySetInnerHTML={{ __html: orderDetailItem.name }}></span></Link>
                                                                <strong className="product-quantity">×&nbsp;{orderDetailItem.quantity}</strong>
                                                            </td>

                                                            <td className="woocommerce-table__product-total product-total">
                                                                <span className="woocommerce-Price-amount amount">
                                                                    <span className="woocommerce-Price-currencySymbol">£{orderDetailItem.total}</span>
                                                                </span>
                                                            </td>
                                                        </tr>
                                                    })}

                                                </tbody>
                                                <tfoot>
                                                    <tr>
                                                        <th scope="row">Subtotal:</th>
                                                        <td>
                                                            <span className="woocommerce-Price-amount amount">
                                                                <span className="woocommerce-Price-currencySymbol">£{Number(orderDetailData.total) - Number(orderDetailData.shippingTotal)}</span>
                                                            </span>
                                                        </td>
                                                    </tr>
                                                    {((Number(orderDetailData.discountTotal) > 0) ?
                                                        <tr>
                                                            <th scope="row">Discount:</th>
                                                            <td>
                                                                <span className="woocommerce-Price-amount amount">
                                                                    <span className="woocommerce-Price-currencySymbol">-£{orderDetailData.discountTotal}</span>
                                                                </span>
                                                            </td>
                                                        </tr> : '')}

                                                    {orderDetailData.shippingLines.map((shippingItem, index) => {
                                                        return <tr key={index}>
                                                            <th scope="row">Shipping:</th>
                                                            <td>
                                                                {((shippingItem.methodId == "free_shipping") ? <> <span className="woocommerce-Price-amount amount">
                                                                    <span className="woocommerce-Price-currencySymbol">{shippingItem.methodTitle}</span>
                                                                </span> </> :
                                                                    <>
                                                                        <span className="woocommerce-Price-amount amount">
                                                                            <span className="woocommerce-Price-currencySymbol">£{shippingItem.total}</span>
                                                                        </span>&nbsp;
                                                                        <small className="shipped_via">via {shippingItem.methodTitle}</small> </>
                                                                )}
                                                            </td>
                                                        </tr>
                                                    })}

                                                    {((orderDetailData.paymentMethodTitle != 'Other') ?
                                                        <tr>
                                                            <th scope="row">Payment method:</th>
                                                            <td>{orderDetailData.paymentMethodTitle}</td>
                                                        </tr> : '')}
                                                    <tr>
                                                        <th scope="row">Total:</th>
                                                        <td>
                                                            <span className="woocommerce-Price-amount amount">
                                                                <span className="woocommerce-Price-currencySymbol">£{orderDetailData.total}</span>
                                                            </span>
                                                        </td>
                                                    </tr>
                                                    {((orderDetailData.paymentMethodTitle == 'Other') ?
                                                        <tr>
                                                            <th>Note:</th>
                                                            <td>Notes</td>
                                                        </tr> : '')}
                                                </tfoot>
                                            </table>

                                            {
                                                ((orderDetailData.status == "completed") ? <p className="order-again">
                                                    <button onClick={() => orderAgain(orderDetailData.lineItems)} type='button' className="button">{btnText}</button>
                                                </p> : '')
                                            }


                                        </div>
                                        <div className="woocommerce-customer-details bill-ship-add">
                                            <div className="woocommerce-columns woocommerce-columns--2 woocommerce-columns--addresses col2-set addresses">
                                                <div className="woocommerce-column woocommerce-column--1 woocommerce-column--billing-address col-1">
                                                    <h2 className="woocommerce-column__title">Billing address</h2>
                                                    <address>
                                                        {orderDetailData.billing.firstName + ' ' + orderDetailData.billing.lastName}<br />
                                                        {((orderDetailData.billing.company) ? orderDetailData.billing.company : '')}
                                                        {((orderDetailData.billing.company) ? <br /> : '')}
                                                        {orderDetailData.billing.address1}<br />
                                                        {((orderDetailData.billing.address2) ? orderDetailData.billing.address2 : '')}
                                                        {((orderDetailData.billing.address2) ? <br /> : '')}
                                                        {orderDetailData.billing.city}<br />
                                                        {orderDetailData.billing.state}<br />
                                                        {orderDetailData.billing.postcode}
                                                        {/* <br />{orderDetailData.billing.country} */}
                                                        <div className="contact-bill">
                                                            {((orderDetailData.billing.phone) ? <p className="woocommerce-customer-details--phone"><FontAwesomeIcon icon={faPhone} />{orderDetailData.billing.phone}</p> : '')}
                                                            {((orderDetailData.billing.email) ? <p className="woocommerce-customer-details--email"><FontAwesomeIcon icon={faEnvelope} />{orderDetailData.billing.email}</p> : '')}
                                                        </div>
                                                    </address>
                                                </div>
                                                <div className="woocommerce-column woocommerce-column--2 woocommerce-column--shipping-address col-2">
                                                    <h2 className="woocommerce-column__title">Shipping address</h2>
                                                    <address>
                                                        {orderDetailData.shipping.firstName + ' ' + orderDetailData.shipping.lastName}<br />
                                                        {((orderDetailData.shipping.company) ? orderDetailData.shipping.company : '')}
                                                        {((orderDetailData.shipping.company) ? <br /> : '')}
                                                        {orderDetailData.shipping.address1}<br />
                                                        {((orderDetailData.shipping.address2) ? orderDetailData.shipping.address2 : '')}
                                                        {((orderDetailData.shipping.address2) ? <br /> : '')}
                                                        {orderDetailData.shipping.city}<br />
                                                        {orderDetailData.shipping.state}<br />
                                                        {orderDetailData.shipping.postcode}
                                                        {/* <div className="contact-bill">
                                                        {((orderDetailData.shipping.phone) ? <p className="woocommerce-customer-details--phone">{orderDetailData.shipping.phone}</p> : '') }
                                                        {((orderDetailData.shipping.email) ? <p className="woocommerce-customer-details--email">{orderDetailData.shipping.email}</p> : '') }
                                                    </div> */}
                                                    </address>
                                                </div>
                                            </div>
                                        </div>
                                    </div> : '')}
                            </div>

                        </div>
                    </div>
                </div>
            </div>
        </section>
    );
};

export default OrderDetailsMain;
