import React, { useEffect, useState } from 'react';
import Link from 'next/link';
import moment from 'moment';
import Image from 'next/image';
import { fetchOrderHistory } from '../../services';
import roundloader from '../../assets/round-loader.svg';
import PreviousIcon from '../../assets/slider-arrow-left.svg';
import NextIcon from '../../assets/slider-arrow.svg';
import styles from '../../styles/myaccount/AccountPages.module.scss';

const OrderHistoryMain = ({ userData }) => {

    const [isOrderLoading, setIsOrderLoading] = useState(true);
    const [orderHistoryData, setOrderHistoryData] = useState([]);
    const [perPage, setPerPage] = useState(5);
    const [currentPage, setCurrentPage] = useState(1);
    const [xWpTotal, setXWpTotal] = useState(0);
    const [xWpTotalpages, setXWpTotalpages] = useState(0);
    const [refreshComponet, setRefreshComponet] = useState('');

    const handleOrderHistory = async (userId, page, per_page) => {
        setIsOrderLoading(true);
        const orderHistoryResponse = await fetchOrderHistory('?customer=' + userId + '&order=desc&orderby=date&page=' + page + '&per_page=' + per_page);
        setXWpTotal(orderHistoryResponse.headers.xWpTotal)
        setXWpTotalpages(orderHistoryResponse.headers.xWpTotalpages);
        setOrderHistoryData(orderHistoryResponse.data);
        setIsOrderLoading(false);
    }

    useEffect(() => {
        handleOrderHistory(userData.id, currentPage, perPage);
    }, [refreshComponet]);

    const handlePageChange = (setPage) => {
        setCurrentPage(setPage);
        setRefreshComponet(Math.random());
    }

    const tablePagination = (count) => {
        var indents = [];
        if (currentPage > 1) {
            indents.push(
                <li className='previous-page' key={0}>
                    <button onClick={() => handlePageChange((Number(currentPage) - 1))} className="page-numbers">
                        <Image src={PreviousIcon} className="" alt="" loading="lazy" />
                    </button>
                </li>)
        }

        var startIndex = ((currentPage == 1) ? currentPage : (Number(currentPage) - 1));
        var endIndex = ((Number(currentPage + 8) > xWpTotalpages) ? xWpTotalpages : Number(currentPage + 8));

        if (Math.ceil(count / perPage) > 1) {
            for (let index = startIndex; index <= endIndex; index++) {
                var activeClass = (currentPage == index) ? 'page-numbers current' : 'page-numbers';
                indents.push(
                    <li key={index}>
                        <span aria-current="page" onClick={() => handlePageChange(index)} className={activeClass}>{index}</span>
                    </li>
                )
            }
        }

        if (Math.ceil(count / perPage) > currentPage) {
            indents.push(
                <li key={count + 1}>
                    <button onClick={() => handlePageChange(Number(currentPage) + 1)} className="page-numbers next-page">
                        <Image src={NextIcon} className="" alt="" loading="lazy" />
                    </button>
                </li>
            )
        }

        return indents;

    }

    return (
        <section className={styles.root}>
            <div className="content-part">
                <div className={styles.wrapper}>
                    <div className="main-content-part">
                        <div className="woocommerce">
                            <nav className="woocommerce-MyAccount-navigation">
                                <ul>
                                    <li className="woocommerce-MyAccount-navigation-link woocommerce-MyAccount-navigation-link--edit-account">
                                        <Link href="/my-account/edit-account/">Dashboard</Link>
                                    </li>
                                    <li className="woocommerce-MyAccount-navigation-link woocommerce-MyAccount-navigation-link--edit-address">
                                        <Link href="/my-account/edit-address/">Address Book</Link>
                                    </li>
                                    <li className="woocommerce-MyAccount-navigation-link woocommerce-MyAccount-navigation-link--orders is-active">
                                        <Link href="/my-account/orders/">Order History</Link>
                                    </li>
                                </ul>
                            </nav>
                            <div className="woocommerce-MyAccount-content">
                                <div className="woocommerce-notices-wrapper"></div>

                                {((xWpTotalpages > 1) ?
                                    <div className="pagination cus-order-history-pagination">
                                        <nav className="woocommerce-pagination">
                                            <ul className="page-numbers">
                                                {tablePagination(xWpTotal)}
                                            </ul>
                                        </nav>
                                    </div> : '')}

                                <Image className="loader-image" src={roundloader} style={{ display: ((isOrderLoading) ? '' : 'none') }} />
                                {((isOrderLoading == false) ? ((orderHistoryData.length == 0) ? <div className="pagination cus-order-history-pagination">
                                    <div className="no-order-cus">
                                        <div className="woocommerce-message woocommerce-message--info woocommerce-Message woocommerce-Message--info woocommerce-info">No order has been made yet.</div>
                                        <Link href="/shop/" className="go-shop-btn" >Go to the shop</Link>
                                    </div>
                                </div> :

                                    <table className="woocommerce-orders-table woocommerce-MyAccount-orders shop_table shop_table_responsive my_account_orders account-orders-table  order-history-table ">
                                        <thead>
                                            <tr>
                                                <th className="woocommerce-orders-table__header woocommerce-orders-table__header-order-pro"><span className="nobr">Product</span></th>
                                                <th className="woocommerce-orders-table__header woocommerce-orders-table__header-order-number"><span className="nobr">Order</span></th>
                                                <th className="woocommerce-orders-table__header woocommerce-orders-table__header-order-status"><span className="nobr">Item</span></th>
                                                <th className="woocommerce-orders-table__header woocommerce-orders-table__header-order-total"><span className="nobr">Total</span></th>
                                                <th className="woocommerce-orders-table__header woocommerce-orders-table__header-order-date"><span className="nobr">Date</span></th>
                                                <th className="woocommerce-orders-table__header woocommerce-orders-table__header-order-actions"><span className="nobr" /></th>
                                            </tr>
                                        </thead>
                                        <tbody>
                                            {orderHistoryData && orderHistoryData.map((orderHistoryItem, index) => {
                                                return <tr key={index} className="woocommerce-orders-table__row woocommerce-orders-table__row--status-processing order order-history-set">
                                                    <td className="woocommerce-orders-table__cell woocommerce-orders-table__cell-order-pro" data-title="Product">
                                                        <Image width={800} height={579} src={orderHistoryItem.lineItems[(Number(orderHistoryItem.lineItems.length) - 1)].image.src} className="attachment-woocommerce_thumbnail size-woocommerce_thumbnail webpexpress-processed" alt="" decoding="async" loading="lazy" />
                                                        <span className="history-img-hs">{orderHistoryItem.lineItems[(Number(orderHistoryItem.lineItems.length) - 1)].name}</span>
                                                    </td>
                                                    <td className="woocommerce-orders-table__cell woocommerce-orders-table__cell-order-number" data-title="Order">
                                                        <Link href={"/my-account/view-order/" + orderHistoryItem.id}>#{orderHistoryItem.id}</Link>
                                                    </td>
                                                    <td className="woocommerce-orders-table__cell woocommerce-orders-table__cell-order-status" data-title="Product">
                                                        {orderHistoryItem.lineItems.length} item
                                                    </td>
                                                    <td className="woocommerce-orders-table__cell woocommerce-orders-table__cell-order-total" data-title="Total">
                                                        <span className="woocommerce-Price-amount amount">
                                                            <span className="woocommerce-Price-currencySymbol">£{orderHistoryItem.total}</span>
                                                        </span>
                                                    </td>
                                                    <td className="woocommerce-orders-table__cell woocommerce-orders-table__cell-order-date" data-title="Date">
                                                        <time dateTime={orderHistoryItem.dateCreated}>{moment(orderHistoryItem.dateCreated).format('DD/MM/YY')}</time>
                                                    </td>
                                                    <td className="woocommerce-orders-table__cell woocommerce-orders-table__cell-order-actions" data-title="Actions">
                                                        {/* {((orderHistoryItem.status == "pending" || orderHistoryItem.status == "failed") ? <a className="woocommerce-button button pay">Pay</a> : '')} */}
                                                        <Link className="woocommerce-button button view" href={"/my-account/view-order/" + orderHistoryItem.id}>VIEW ORDER</Link>
                                                        {/* {((orderHistoryItem.status == "pending" || orderHistoryItem.status == "failed") ? <a className="woocommerce-button button cancel">Cancel</a> : '')} */}
                                                    </td>
                                                </tr>
                                            })}

                                        </tbody>
                                    </table>

                                ) : '')}
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
    );
};

export default OrderHistoryMain;
