import React, { useState } from 'react';
import Link from 'next/link';
import Image from 'next/image';
import { Formik, Form, Field, ErrorMessage } from 'formik';
import * as Yup from 'yup';
import UsersApis from "../../helper/UsersApi";
//import '../../style/my-account/login.scss';
import styles from '../../styles/myaccount/Login.module.scss';
import eye from '../../assets/eye-icon.svg';

const Registeration = () => {

    const [passwordInputType, setPasswordInputType] = useState(false);
    const [buttonText, setButtonText] = useState('CREATE AN ACCOUNT');
    const [responseMessage, setResponseMessage] = useState('');
    const [responseMessageStatus, setResponseMessageStatus] = useState('');

    const RegisterSchema = Yup.object().shape({
        first_name: Yup.string().required("First Name is Required!"),
        last_name: Yup.string().required("Last Name is Required!"),
        email: Yup.string().required("Email Address is Required!").email("Email address format not valid"),
        password: Yup.string().required("Password is Required.").matches(
            /^(?=.*[a-z])(?=.*[A-Z])(?=.*[0-9])(?=.*[!@#\$%\^&\*])(?=.{8,})/,
            "Must Contain 8 Characters, One Uppercase, One Lowercase, One Number and One Special Case Character"
        ),
        confirm_password: Yup.string().required("Confirm Password is Required.").oneOf([Yup.ref('password'), null], 'Passwords must match'),
    });


    return (
        <section className={styles.root}>
            <div className="content-part login-signup-section">
                <div className={styles.wrapper}>
                    <div className="login-register">

                        <div className="woocommerce-notices-wrapper">
                            {
                                (responseMessageStatus == "error") ?
                                    <ul className="woocommerce-error" role="alert">
                                        <li dangerouslySetInnerHTML={{ __html: responseMessage }}>
                                        </li>
                                    </ul> : ''
                            }
                        </div>

                        <div className="col-md-12 col-lg-5 max-width register-login-form mx-auto">
                            <h2 className="banner-subtitle"><span>Sign up</span></h2>
                            <span className="tag-line">Welcome! It’s quick and easy to set up an account </span>
                            <div className="woocommerce-form woocommerce-form-register register">


                                <Formik
                                    initialValues={{
                                        first_name: '',
                                        last_name: '',
                                        email: '',
                                        password: '',
                                        confirm_password: ''
                                    }}
                                    validationSchema={RegisterSchema}
                                    onSubmit={async (values) => {

                                        setButtonText('Creating account...');

                                        const nonceResponse = await UsersApis({
                                            endpoint: 'get_nonce', method: "GET",
                                            params: {
                                                'json': 'get_nonce',
                                                'controller': 'user',
                                                'method': 'register'
                                            },
                                        });

                                        if (nonceResponse.status == "ok") {
                                            const registerResponse = await UsersApis({
                                                endpoint: 'user/register', method: "GET",
                                                params: {
                                                    'username': values.email,
                                                    'email': values.email,
                                                    'nonce': nonceResponse.nonce,
                                                    'notify': 'both',
                                                    'insecure': 'cool',
                                                    'user_pass': values.password,
                                                    'first_name': values.first_name,
                                                    'last_name': values.last_name
                                                },
                                            });
                                            if (registerResponse.status == "ok") {
                                                localStorage.setItem('cookieAuth', registerResponse.cookie);
                                                document.cookie = registerResponse.cookie_name + "=" + registerResponse.cookie + ";domain=" + process.env.COOKIE_DOMAIN
                                                window.location.href = "/my-account/";
                                            } else {
                                                setResponseMessage(registerResponse.error);
                                                setResponseMessageStatus("error");
                                                setButtonText('CREATE AN ACCOUNT');
                                            }
                                        }


                                    }} >
                                    {() => (
                                        <Form method="post">

                                            <div>
                                                <div className="d-flex form-row-outer d-flex-wrap">
                                                    <div className="woocommerce-form-row woocommerce-form-row--wide form-group form-row-half">
                                                        <Field name='first_name' placeholder="First Name*" className="input-text form-control" />
                                                        <ErrorMessage component='div' className='formError' name="first_name" />
                                                    </div>
                                                    <div className="woocommerce-form-row woocommerce-form-row--wide form-group form-row-half">
                                                        <Field name='last_name' placeholder="Last Name*" className="input-text form-control" />
                                                        <ErrorMessage component='div' className='formError' name="last_name" />
                                                    </div>
                                                </div>

                                                <div className="woocommerce-form-row woocommerce-form-row--wide form-group form-row-wide">
                                                    <Field name='email' placeholder="Email*" className="woocommerce-Input woocommerce-Input--text input-text form-control" />
                                                    <ErrorMessage component='div' className='formError' name="email" />
                                                </div>

                                                <div className="registrationFormAlert" id="divCheckEmaildMatch">

                                                    <div className="woocommerce-form-row woocommerce-form-row--wide form-group form-row-wide">
                                                        <span className="password-input">
                                                            <Field type={((passwordInputType == false) ? "password" : "text")} name='password' placeholder="Password*" className="woocommerce-Input woocommerce-Input--text input-text form-control" />
                                                            <span className="show-password-input" onClick={() => setPasswordInputType((passwordInputType == false) ? true : false)} ><Image src={eye} /></span>
                                                            <ErrorMessage component='div' className='formError' name="password" />
                                                        </span>
                                                        <div className="woocommerce-password-strength bad" aria-live="polite">Weak - Please enter a stronger password.</div>
                                                        <span className="woocommerce-password-hint">Hint: The password should be at least twelve characters long. To make it stronger, use upper and lower case letters, numbers, and symbols like ! " ? $ % ^ & ).</span>
                                                    </div>

                                                    <div className="woocommerce-form-row form-group form-row-wide">
                                                        <Field type="password" name='confirm_password' placeholder="Confirm Password*" className="input-text form-control" />
                                                        <ErrorMessage component='div' className='formError' name="confirm_password" />
                                                    </div>
                                                    <div className="registrationFormAlert" id="divCheckPasswordMatch">
                                                        <div className="woocommerce-FormRow form-group text-right">
                                                            <button type="submit" className="woocommerce-Button btn btn-primary" name="register" id="registration" value="Register">{buttonText}</button>
                                                        </div>
                                                    </div>
                                                </div>

                                                <div className="login-section">
                                                    <h2 className="banner-subtitle"><span>Already have an account?</span></h2>
                                                    <Link href="/my-account" className="btn btn-secondary">SIGN IN</Link>
                                                </div>
                                            </div>

                                        </Form>
                                    )}
                                </Formik>

                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
    );
};

export default Registeration;
