import React, { useState } from 'react';
import Link from 'next/link';
import Image from 'next/image';
import { useDispatch } from 'react-redux';
import { Formik, Form, Field, ErrorMessage } from 'formik';
import * as Yup from 'yup';
import UsersApis from "../../helper/UsersApi";
import { userSuccess } from '../../reducer/userSlice';
import eye from '../../assets/eye-icon.svg';
import styles from '../../styles/myaccount/Login.module.scss';


const Login = () => {

    const dispatch = useDispatch();
    const [buttonText, setButtonText] = useState('Sign In');
    const [responseMessage, setResponseMessage] = useState('');
    const [responseMessageStatus, setResponseMessageStatus] = useState('');
    const [passwordInputType, setPasswordInputType] = useState(false);

    const LoginSchema = Yup.object().shape({
        user_login: Yup.string().required("This field is required."),
        user_password: Yup.string().required("This field is required.")
    });

    return (
        <section className={styles.root}>
            <div className="content-part login-signup-section">
                <div className={styles.wrapper}>
                    <div className="login-register">

                        <div className="woocommerce-notices-wrapper">
                            {
                                (responseMessageStatus == "error") ?
                                    <ul className="woocommerce-error" role="alert">
                                        <li dangerouslySetInnerHTML={{ __html: responseMessage }}>
                                        </li>
                                    </ul> : ''
                            }
                        </div>
                        <div className="entry-content-woocommerce">
                            <div className="row gutters-10 justify-content-between customer_login" id="customer_login">
                                <div className="col-md-12">
                                    <h2 className="banner-subtitle"><span>Sign in</span></h2>
                                    <span className="tag-line">Enter your details below to sign in</span>
                                </div>
                                <div className="col-md-12 col-lg-5 contact-from max-width contact-from-block contact-from-login">

                                    <Formik
                                        initialValues={{
                                            user_login: '',
                                            user_password: ''
                                        }}
                                        validationSchema={LoginSchema}
                                        onSubmit={async (values, { resetForm }) => {

                                            setButtonText('Signing...')

                                            const loginResponse = await UsersApis({
                                                endpoint: 'user/generate_auth_cookie', method: "GET",
                                                params: {
                                                    'username': values.user_login,
                                                    'password': values.user_password,
                                                    'insecure': 'cool'
                                                },
                                            });
                                            if (loginResponse.status == "ok") {
                                                var Cookies = document.cookie.split(';');
                                                if (Cookies) {
                                                    for (var i = 0; i < Cookies.length; i++)
                                                        document.cookie = Cookies[i] + "=;expires=" + new Date(0).toUTCString();
                                                }
                                                localStorage.setItem('cookieAuth', loginResponse.cookie);
                                                document.cookie = loginResponse.cookie_name + "=" + loginResponse.cookie + ";domain=" + process.env.COOKIE_DOMAIN
                                                dispatch(userSuccess(loginResponse.user));
                                            } else {
                                                setResponseMessage(loginResponse.error);
                                                setResponseMessageStatus("error");
                                                setButtonText('Sign in');
                                                resetForm();
                                            }

                                        }} >
                                        {() => (

                                            <Form method="post" className="woocommerce-form woocommerce-form-login login">

                                                <div>

                                                    <div className='woocommerce-form-row woocommerce-form-row--wide form-group form-row-wide'>
                                                        <Field name='user_login' placeholder="Email*" className="woocommerce-Input woocommerce-Input--text input-text form-control" />
                                                        <ErrorMessage component='div' className='formError' name="user_login" />
                                                    </div>

                                                    <div className='woocommerce-form-row woocommerce-form-row--wide form-group form-row-wide'>
                                                        <span className="password-input">
                                                            <Field type={((passwordInputType == false) ? "password" : "text")} name='user_password' placeholder="Password*" className="woocommerce-Input woocommerce-Input--text input-text form-control" />
                                                            <span onClick={() => setPasswordInputType((passwordInputType == false) ? true : false)} className='show-password-input'><Image src={eye} /></span>
                                                        </span>
                                                        <ErrorMessage component='div' className='formError' name="user_password" />
                                                    </div>

                                                    <div className="woocommerce-LostPassword lost_password form-group form-group-space">
                                                        <Link className="forgot_password" href="/my-account/lost-password"><u>Forgot password</u></Link>
                                                        <label className="woocommerce-form__label woocommerce-form__label-for-checkbox woocommerce-form-login__rememberme">
                                                        </label>
                                                        <button type="submit" id="login_accout" className="woocommerce-button  btn btn-primary woocommerce-form-login__submit" name="login" value="Login">
                                                            {buttonText}
                                                        </button>
                                                    </div>

                                                </div>

                                            </Form>
                                        )}
                                    </Formik>
                                </div>
                                <div className="login-section login-page">
                                    <h2 className="banner-subtitle"><span>Sign up</span></h2>
                                    <span className="tag-line">Welcome! It's quick and easy to set up an account </span>
                                    <Link href="/my-account/?action=register" className="btn btn-secondary" >CREATE AN ACCOUNT</Link>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
    );
};

export default Login;
