import React, { useEffect, useState } from "react";
import { useDispatch, useSelector } from 'react-redux';
import Link from 'next/link';
import moment from 'moment';
import { categoriesPending, categoriesSuccess, categoriesFail } from '../../reducer/categoriesSlice';
import { fetchCategories, fetchPostsWithfilter } from '../../services';
//import '../../style/news/filter.scss';
import roundloader from '../../assets/round-loader.svg';
import UrlReplace from "../Common/UrlReplace";
import Image from 'next/image'
import styles from '../../styles/cmspage/Filter.module.scss';

const Filter = () => {

    const dispatch = useDispatch();
    const [postsData, setPostsData] = useState([]);
    const [currentPage, setCurrentPage] = useState(1);
    const [isPostLoading, setIsPostLoading] = useState(true);
    const [perPage, setper_page] = useState(6);
    const [xWpTotalpages, setXWpTotalpages] = useState(0);
    const [searchText, setSearchText] = useState('');
    const [refreshComponet, setRefreshComponet] = useState('');
    const [clearBtnDisplay, setClearBtnDisplay] = useState(false);
    const [categoryArr, setCategoryArr] = useState([]);

    const [isActive, setActive] = useState(false);
    const ToggleClass = () => {
        setActive(!isActive);
    };


    const { categoriesIsLoading, categoriesData, categoriesError } = useSelector(state => state.categoriesPage);

    const handleCategories = async () => {
        dispatch(categoriesPending());
        try {
            const categoriesResponse = await fetchCategories();
            dispatch(categoriesSuccess(categoriesResponse));
        } catch (e) {
            dispatch(categoriesFail(e));
        }
    }

    const handlePosts = async (page, per_page, search, categories) => {
        setIsPostLoading(true)
        try {
            const postsResponse = await fetchPostsWithfilter('?page=' + page + '&per_page=' + per_page + '&_embed' + ((search) ? '&search=' + search : '') + ((categories.length > 0) ? '&categories=' + categories : ''));

            setXWpTotalpages(postsResponse.headers.xWpTotalpages)
            setPostsData(postsData => [...postsData, ...postsResponse.data]);
            setIsPostLoading(false)
        } catch (e) {

        }
    }

    useEffect(() => {
        if (categoriesIsLoading == true) {
            handleCategories();
        }

        handlePosts(currentPage, perPage, searchText, categoryArr);
    }, [refreshComponet]);

    const loadMorePage = (setPage) => {
        setCurrentPage(setPage);
        setRefreshComponet(setPage)
    }

    const searchPostData = (searchTextB) => {
        if (searchTextB) {
            setCurrentPage(1);
            setPostsData([]);
            setRefreshComponet(searchTextB)
            setClearBtnDisplay(true)
        }
    }

    const clearSearchText = () => {
        setClearBtnDisplay(false);
        setSearchText('');
        setCurrentPage(1);
        setPostsData([]);
        setCategoryArr([]);
        setRefreshComponet('clearbutton');
    }


    const setCategories = (event) => {
        if (event.target.checked) {
            setCategoryArr([...categoryArr, event.target.value]);
            setRefreshComponet(event.target.value + 'add')
        }
        else {
            setCategoryArr(categoryArr.filter(item => item !== event.target.value))
            setRefreshComponet(event.target.value + 'remove')
        }
        setCurrentPage(1);
        setPostsData([]);
    }

    const handleKeyDown = (event) => {
        if (event.key === 'Enter') {
            setCurrentPage(1);
            setPostsData([]);
            setRefreshComponet(Math.random());
            setClearBtnDisplay(true)
        }
    }

    return (
        <section className={styles.root}>
            <div className="fillter-part">
                <div className={styles.wrapper}>
                    <div className={isActive ? "block-title filter-title icon-change" : "block-title filter-title"} onClick={ToggleClass}>FILTER</div>
                    <div className={isActive ? "fillter-inner-container filter-open" : "fillter-inner-container"}>
                        <h3>Filter the News</h3>
                        <div className="fillter-left">
                            <button onClick={clearSearchText} className={((clearBtnDisplay || categoryArr.length > 0) ? "fillter-clear active" : "fillter-clear")}>CLEAR</button>
                            {categoriesData && categoriesData.map((categoriesItem, index) => {
                                return <div key={index} className="checkbox-part">
                                    <label htmlFor={"news_cat_" + categoriesItem.id}>
                                        <input onChange={(e) => setCategories(e)} checked={(categoryArr.length != 0 && categoryArr.includes(categoriesItem.id.toString()))} name="news_post" type="checkbox" id={"news_cat_" + categoriesItem.id} className="news_cat_chk check-box" value={categoriesItem.id} data-attr={categoriesItem.name} />
                                        <span>{categoriesItem.name}</span>
                                    </label>
                                </div>
                            })}
                        </div>
                        <div className="search-box" onKeyDownCapture={handleKeyDown}>
                            <input type="search" id="news_search" onChange={(e) => setSearchText(e.target.value)} value={searchText} className="search-field" placeholder="Search here" name="s" />
                            <button className="search-submit" onClick={() => searchPostData(searchText)}></button>
                        </div>
                    </div>
                </div>
            </div>

            <div className="bottom-section">
                <div className={styles.wrapper}>
                    <div className="bottom-inner-container">
                        <div className="bottom-section-inner">
                            <div className="new-blog" id="news_post_load">
                                {(postsData.length == 0 && isPostLoading == false) ? <h3>No Post Found</h3> : ''}
                                {postsData && postsData.map((postsDataItem, index) => {
                                    return <div key={index} className={(((Number(index) + 1) % 3 == 0) ? "blog full latest-post-row" : "blog latest-post-row")} >
                                        <div className="content-block">
                                            <Link href={UrlReplace(postsDataItem.link)} className="img">
                                                <Image width={200} height={200} className="img" src={postsDataItem.acf.newsListingSmallImage.sizes.newsListingMidImage} alt="candlesticks for web" />
                                            </Link>
                                            <Link href={UrlReplace(postsDataItem.link)} className="text"> {postsDataItem.title.rendered} </Link>
                                            <p>{moment(postsDataItem.date).format('DD MMMM YYYY')}</p>
                                        </div>
                                    </div>
                                })}
                            </div>
                            <Image width={200} height={200} className="loader-image" src={roundloader} style={{ display: ((isPostLoading) ? 'block' : 'none') }} alt='loader-image' />
                        </div>
                    </div>
                </div>
                <div className="loadMore">
                    {((xWpTotalpages > currentPage) ? <button className="round-loader" disabled={((isPostLoading) ? 'disabled' : '')} onClick={() => loadMorePage(Number(currentPage + 1))}>LOAD MORE</button> : '')}

                </div>
            </div>
        </section>  
    )
}
export default Filter;
