import React, { useState, useEffect } from "react";
import Link from "next/link";
import Image from "next/image";
import Slider from "react-slick";
import { fetchOurExpertProduct } from "../../services";
import Breadcrumb from "../../components/Common/breadcrumb";
import UrlReplace from "../Common/UrlReplace";
import "slick-carousel/slick/slick.css";
import "slick-carousel/slick/slick-theme.css";
//import '../../style/ourexpert/ourexpertsingleinfo.scss';
import styles from "../../styles/cmspage/Ourexpertsingleinfo.module.scss";

const OurExpertSingleInfo = ({ ourExpertDetailData, optionData }) => {
  const [ourExpertProductData, setOurExpertProductData] = useState([]);
  const handleOurExpertProduct = async (products) => {
    try {
      const ourExpertProductResponse = await fetchOurExpertProduct(products);
      setOurExpertProductData(ourExpertProductResponse);
    } catch (e) {}
  };

  const array_column = (array, column) => array.map((e) => e[column]);

  useEffect(() => {
    if (ourExpertDetailData[0].acf.favouriteProductPiece.length > 0) {
      var productsArr = array_column(ourExpertDetailData[0].acf.favouriteProductPiece, "id");
      handleOurExpertProduct(productsArr);
    }
  }, []);

  var settings = {
    dots: false,
    arrows: true,
    infinite: true,
    loop: true,
    autoplay: true,
    autoplayspeed: 3000,
    slidesToShow: 4,
    slidesToScroll: 1,
    responsive: [
      {
        breakpoint: 1024,
        settings: {
          slidesToShow: 3,
        },
      },
      {
        breakpoint: 767,
        settings: {
          slidesToShow: 1,
        },
      },
    ],
  };

  return (
    <section className={styles.root}>
      <div className="team-expert-section">
        <div className={styles.wrapper}>
          <div className="team-expert-inner-container">
            <div className="team-descreption">
              <Breadcrumb
                breadcrumbMenu={[
                  { title: "Our Experts", link: "/our-expert" },
                  { title: ourExpertDetailData[0].title.rendered, link: "" },
                ]}
              />
              <div className="descreption view-less-pos">
                <h1>{ourExpertDetailData[0].title.rendered}</h1>
                <h4>{ourExpertDetailData[0].acf.jobTitle}</h4>
                <div
                  className="read-more js-read-more"
                  data-rm-words={90}
                  dangerouslySetInnerHTML={{ __html: ourExpertDetailData[0].content.rendered }}
                ></div>
              </div>
              <a href={"mailto:" + ourExpertDetailData[0].acf.expertEmailAddress} className="email">
                {ourExpertDetailData[0].acf.expertEmailAddress}
              </a>
            </div>
            <div className="team-expert-profile">
              <div className="hidden-add">
                <Image height={676} width={676} sizes="100vw"
                  className="img"
                  src={
                    ourExpertDetailData[0].embedded
                      ? ourExpertDetailData[0].embedded.wpFeaturedmedia[0].sourceUrl
                      : optionData && optionData.acf && optionData.acf.expertDefaultImage
                      ? optionData.acf.expertDefaultImage.url
                      : ""
                  }
                  alt="John-Walter"
                />
              </div>
            </div>
          </div>
        </div>
      </div>

      <div className="new-arrivals-part">
        <div className={styles.wrapper}>
          <div className="home-arrivals-section">
            <div dangerouslySetInnerHTML={{ __html: ourExpertDetailData[0].acf.expertFavouritePiecesDetail }}></div>
            <Link href="/shop" className="view-all">
              VIEW ALL
            </Link>
          </div>
        </div>
      </div>

      {ourExpertProductData.length > 0 ? (
        <div className={styles.wrapper}>
          <div className="new-arrival-products">
            <Slider {...settings}>
              {ourExpertProductData &&
                ourExpertProductData.map((ourExpertProductItem, index) => {
                  return (
                    <div key={index} className="image-box">
                      <div className="product-block">
                        <Link href={UrlReplace(ourExpertProductItem["link"])}>
                          <Image height={345} width={330} sizes="100vw" src={ourExpertProductItem["image"]} alt={ourExpertProductItem["name"]} />
                        </Link>
                        <Link href={UrlReplace(ourExpertProductItem["link"])}>
                          <p>{ourExpertProductItem["name"]}</p>
                        </Link>
                        <span className="price">£{ourExpertProductItem["price"]}</span>
                      </div>
                    </div>
                  );
                })}
            </Slider>
          </div>
        </div>
      ) : (
        ""
      )}
    </section>
  );
};
export default OurExpertSingleInfo;
