import React, { useEffect, useState } from "react";
import { useDispatch, useSelector } from "react-redux";
import Link from "next/link";
import Image from "next/image";
import { fetchCustomPostTypePagination } from "../../services";
import UrlReplace from "../Common/UrlReplace";
import roundloader from "../../assets/round-loader.svg";
//import '../../style/ourexpert/ourexpertteam.scss';
//import '../../style/news/mainbannertitle.scss';
import styles from "../../styles/cmspage/Ourexpertteam.module.scss";

const OurExpertTeam = ({ optionData }) => {
  const [ourExpertListData, setOurExpertListData] = useState([]);
  const [xWpTotalpages, setXWpTotalpages] = useState(0);
  const [currentPage, setCurrentPage] = useState(1);
  const [isPostLoading, setIsPostLoading] = useState(true);

  const handleOurExpertList = async (page) => {
    setIsPostLoading(true);
    try {
      const ourExpertListResponse = await fetchCustomPostTypePagination(
        "our-experts?_embed&page=" + page + "&per_page=6",
      );
      setXWpTotalpages(ourExpertListResponse.headers.xWpTotalpages);
      setOurExpertListData((ourExpertListData) => [...ourExpertListData, ...ourExpertListResponse.data]);
      setIsPostLoading(false);
    } catch (e) {}
  };

  useEffect(() => {
    handleOurExpertList(currentPage);
  }, [currentPage]);

  const loadMorePage = (setPage) => {
    setCurrentPage(setPage);
  };

  return (
    <section className={styles.root}>
      <div className="team-section">
        <div className={styles.wrapper}>
          <div id="expert_list" className="profile-main-block">
            {ourExpertListData &&
              ourExpertListData.map((ourExpertListItem, index) => {
                return (
                  <div key={index} className="profile-block expert-repeat-list" style={{ display: "block" }}>
                    <div className="block">
                      <Link href={UrlReplace(ourExpertListItem.link)} className="profile-team">
                        <Image
                          height={444} width={444} sizes="100vw" className="img"
                          src={
                            ourExpertListItem.embedded
                              ? ourExpertListItem.embedded.wpFeaturedmedia[0].sourceUrl
                              : optionData && optionData.acf && optionData.acf.expertDefaultImage
                              ? optionData.acf.expertDefaultImage.url
                              : ""
                          }
                          alt={ourExpertListItem.embedded && ourExpertListItem.embedded.wpFeaturedmedia[0].altText}
                        />
                      </Link>
                      <p>{ourExpertListItem.acf.jobTitle}</p>
                      <Link href={UrlReplace(ourExpertListItem.link)}>
                        <h4>{ourExpertListItem.title.rendered}</h4>
                      </Link>
                    </div>
                  </div>
                );
              })}
          </div>
          <Image height={40} width={40} alt="loader" className="loader-image" src={roundloader} style={{ display: isPostLoading ? "" : "none" }} />
          <div className="loadMore">
            {xWpTotalpages > currentPage ? (
              <button
                className="round-loader"
                disabled={isPostLoading ? "disabled" : ""}
                onClick={() => loadMorePage(Number(currentPage + 1))}
              >
                LOAD MORE
              </button>
            ) : (
              ""
            )}
          </div>
        </div>
      </div>
    </section>
  );
};

export default OurExpertTeam;
