import React, { useState, useEffect } from 'react';
import { Formik, Form, Field, ErrorMessage, getIn } from 'formik';
import * as Yup from 'yup';
import Modal from 'react-modal';
import AddressApi from "../../helper/AddressApi";

const AddAddress = (props) => {

    const [btnText, setButtonText] = useState("Save Address");
    const [updateBtnText, setUpdateButtonText] = useState("Update Address");

    const { modalIsOpen, closeModal, userData, shippingCountriesData, setIsAddressLoading, addressIndexData } = props;

    const AddressSchema = Yup.object().shape({
        reference_field: Yup.string().required("Field Is Required!"),
        billing_first_name: Yup.string().required("Field Is Required!"),
        billing_last_name: Yup.string().required("Field Is Required!"),
        billing_postcode: Yup.string().required("Field Is Required!"),
        billing_country: Yup.string().required("Field Is Required!"),
        billing_address_1: Yup.string().required("Field Is Required!"),
        billing_city: Yup.string().required("Field Is Required!"),
        billing_state: Yup.string().required("Field Is Required!"),
        billing_email: Yup.string().required("Field Is Required!"),
        billing_phone: Yup.string().required("Field Is Required!"),
    });

    const getStyles = (errors, touched, fieldName) => {
        if (getIn(errors, fieldName) && getIn(touched, fieldName)) {
          return {
            border: '2px solid red'
          }
        }
      }

    return (

        <Modal
            isOpen={modalIsOpen}
            onRequestClose={closeModal}
            className="add-new-address"
            overlayClassName="overlay-black"
            contentLabel="Example Modal" >
            <div className="product-popup-content">
                <span className="close-btn" onClick={closeModal}>×</span>
                <div id="oc_add_billing_form">
                    <div className="ocwma_woocommerce-address-fields">
                        
                        <Formik
                            initialValues={{
                                user_id: userData.id,
                                edit_id: ((addressIndexData) ? addressIndexData.id : ''),
                                reference_field: ((addressIndexData) ? addressIndexData.userdata.reference_field : ''),
                                billing_first_name: ((addressIndexData) ? addressIndexData.userdata.billing_first_name : ''),
                                billing_last_name: ((addressIndexData) ? addressIndexData.userdata.billing_last_name : ''),
                                billing_postcode: ((addressIndexData) ? addressIndexData.userdata.billing_postcode : ''),
                                billing_country: ((addressIndexData) ? addressIndexData.userdata.billing_country.toLowerCase() : ''),
                                billing_address_1: ((addressIndexData) ? addressIndexData.userdata.billing_address_1 : ''),
                                billing_city: ((addressIndexData) ? addressIndexData.userdata.billing_city : ''),
                                billing_state: ((addressIndexData) ? addressIndexData.userdata.billing_state : ''),
                                billing_email: ((addressIndexData) ? addressIndexData.userdata.billing_email : ''),
                                billing_phone: ((addressIndexData) ? addressIndexData.userdata.billing_phone : ''),
                                billing_company: ((addressIndexData) ? addressIndexData.userdata.billing_company : ''),
                                billing_address_2: ((addressIndexData) ? addressIndexData.userdata.billing_address_2 : ''),
                                address_type_bill : ((addressIndexData && addressIndexData.default_status == "selected" && (addressIndexData.type == "both" || addressIndexData.type == "billing")) ? 'default_bill' : ''),
                                address_type_ship : ((addressIndexData && addressIndexData.default_status == "selected" && (addressIndexData.type == "both" || addressIndexData.type == "shipping")) ? 'default_ship' : ''),
                            }}
                            validationSchema={AddressSchema}
                            onSubmit={ async (values,  { resetForm }) => {
                                
                                if(addressIndexData)
                                {
                                    setUpdateButtonText('Updating...');

                                    const updateUserAddressResponse = await AddressApi({ endpoint: 'wp/v2/ocwma_edit_billing_form_fields', method: "POST", 
                                        params: values, 
                                    });
                                    
                                    if(updateUserAddressResponse.added == "true")
                                    {
                                        setIsAddressLoading(true);
                                        closeModal(true);
                                        setUpdateButtonText('Update Address');
                                    }else
                                    {
                                        alert('Please add valid field');
                                        setUpdateButtonText('Update Address');
                                    }
                                }else
                                {
                                    setButtonText('Saving...');

                                    const addUserAddressResponse = await AddressApi({ endpoint: 'wp/v2/ocwma_add_billing_form_fields', method: "POST", 
                                        params: values, 
                                    });
                                    
                                    if(addUserAddressResponse.added == "true")
                                    {
                                        setIsAddressLoading(true);
                                        closeModal(true);
                                        setButtonText('Save Address');
                                    }else
                                    {
                                        alert('Please add valid field');
                                        setButtonText('Save Address');
                                    }
                                }
                            }} >
                            {({ errors, touched }) => (
                                <div className="ocwma_woocommerce-address-fields_field-wrapper">

                                    <Form method="post">

                                        <p className="form-row form-row-wide">
                                            <span className="woocommerce-input-wrapper">
                                                <Field style={getStyles(errors, touched, 'reference_field')} name='reference_field' placeholder="Reference Name*" className="input-text" />
                                            </span> 
                                        </p>

                                        <p className="form-row form-row-first validate-required half-width">
                                            <span className="woocommerce-input-wrapper">
                                                <Field className="input-text" style={getStyles(errors, touched, 'billing_first_name')} name="billing_first_name" placeholder="First Name*" />
                                            </span> 
                                        </p>

                                        <p className="form-row form-row-last validate-required half-width">
                                            <span className="woocommerce-input-wrapper">
                                                <Field className="input-text" style={getStyles(errors, touched, 'billing_last_name')} name="billing_last_name" placeholder="Last Name*" />
                                            </span>
                                        </p>

                                        <p className="form-row form-row-wide">
                                            <span className="woocommerce-input-wrapper">
                                                <Field className="input-text" name="billing_company" placeholder="Company Name (Optional)" />
                                            </span>
                                        </p>

                                        <p className="form-row form-row-wide address-field validate-required validate-postcode half-width" id="billing_postcode_field">
                                            <span className="woocommerce-input-wrapper">
                                                <Field className="input-text" style={getStyles(errors, touched, 'billing_postcode')} name="billing_postcode" placeholder="Post Code*" />
                                            </span>
                                        </p>

                                        <p className="form-row form-row-wide address-field update_totals_on_change validate-required half-width" id="billing_country_field">
                                            <span className="woocommerce-input-wrapper">
                                                <Field as="select" style={getStyles(errors, touched, 'billing_country')}  name="billing_country" id="billing_country" className="country_to_state country_select">
                                                    <option selected="selected" value="">Select a country / region…</option>
                                                    { shippingCountriesData && shippingCountriesData.map((shippingCountriesItem,index) => {
                                                        return <option key={index} value={shippingCountriesItem[0]}>{shippingCountriesItem[1]}</option>
                                                    }) }
                                                    
                                                </Field>
                                            </span>
                                        </p>
                                        
                                        <p className="form-row form-row-wide address-field validate-required" id="billing_address_1_field">
                                            <span className="woocommerce-input-wrapper">
                                                <Field className="input-text" style={getStyles(errors, touched, 'billing_address_1')} name="billing_address_1" placeholder="Address Line 1*" />
                                            </span>
                                        </p>

                                        <p className="form-row form-row-wide address-field" id="billing_address_2_field">
                                            <span className="woocommerce-input-wrapper">
                                                <Field className="input-text" name="billing_address_2" placeholder="Address Line 2" />
                                            </span>
                                        </p>

                                        <p className="form-row form-row-wide address-field validate-required half-width" id="billing_city_field">
                                            <span className="woocommerce-input-wrapper">
                                                <Field className="input-text" style={getStyles(errors, touched, 'billing_city')} name="billing_city" placeholder="City*" />
                                            </span>
                                        </p>

                                        <p className="form-row form-row-wide address-field validate-state half-width" id="billing_state_field">
                                            <span className="woocommerce-input-wrapper">
                                                <Field className="input-text" style={getStyles(errors, touched, 'billing_state')} placeholder="State/Province*" name="billing_state" />
                                            </span>
                                        </p>

                                        <p className="form-row form-row form-row-wide validate-required validate-phone validate-required half-width" id="billing_phone_field">
                                            <Field className="cus-myacc-add input-text" style={getStyles(errors, touched, 'billing_phone')} placeholder="Telephone Number*" name="billing_phone" />
                                        </p>

                                        <p className="form-row form-row form-row-wide validate-required validate-email validate-required half-width" id="billing_email_field">
                                            <Field className="cus-myacc-add input-text" style={getStyles(errors, touched, 'billing_email')} placeholder="Email Address*" name="billing_email" />
                                        </p>

                                        <p className="cus-address-set-method"> 
                                            {((addressIndexData && addressIndexData.default_status == "selected" && (addressIndexData.type == "both" || addressIndexData.type == "billing")) ? 
                                                <span>It's a default billing address.</span> : 
                                                <label> 
                                                    <Field type="checkbox" className="radio" value="default_bill" name="address_type_bill" />
                                                    <span>Set As Default Billing Address</span> 
                                                </label> )}
                                            {((addressIndexData && addressIndexData.default_status == "selected" && (addressIndexData.type == "both" || addressIndexData.type == "shipping")) ? 
                                                <span>It's a default shipping address.</span> :
                                                <label> 
                                                    <Field type="checkbox" className="radio" value="default_ship" name="address_type_ship" />
                                                    <span>Set As Default Shipping Address</span> 
                                                </label> )}        
                                            
                                             
                                        </p> 
                                        <p> 
                                            <button type="submit" name="add_billing" id="oc_add_billing_form_submit" className="button save-address" value="ocwma_billpp_save_option">{((addressIndexData) ? updateBtnText : btnText)}</button> 
                                        </p>

                                                
                                    </Form>
                                </div>
                            )}
                        </Formik>
                        
                    </div>
                </div>
            </div>
        </Modal>
    );
};

export default React.memo(AddAddress);
