import React, { useState, useEffect } from 'react';
import { useSelector } from 'react-redux';
import  Link  from 'next/link';
import Image from "next/image";
import Slider from "react-slick";
import { fetchProductsByCondition } from '../../services';
import AddToBasket from '../popup/AddToBasket';
import UrlReplace from '../Common/UrlReplace';
import AddToCart from '../Common/AddToCart';
import "slick-carousel/slick/slick.css";
import "slick-carousel/slick/slick-theme.css";
import styles from '../../styles/cmspage/Ourexpertsingleinfo.module.scss';

const NewArrivalOurStore = ({ourStoreData}) => {
    
    const [productsByCondition,setProductsByCondition] = useState([]);
    const [productData, setProductData] = useState({});
    const [modalIsOpen, setIsOpen] = useState(false);

    function openModal(productItemObj) {
        setProductData(productItemObj)
        setIsOpen(true);
    }

    function closeModal() {
        setIsOpen(false);
    }

    var settings = {
        dots: false,
        arrows:true,
        infinite: true,
        loop:true,
        autoplay:true,
        autoplayspeed:3000,
        slidesToShow: 4,
        slidesToScroll: 1,
        responsive: [
            {
                breakpoint: 1024,
                settings: {
                    slidesToShow: 3
                }
            },
            {
                breakpoint: 767,
                settings: {
                    slidesToShow: 1
                }
            },
        ]
    };

    const handleProductsByCondition = async () => {
        try {
          const productsByConditionResponse = await fetchProductsByCondition();
          setProductsByCondition(productsByConditionResponse);
        } catch (e) {
          
        }
      }

    useEffect(() => { 
        handleProductsByCondition();
      },[]);

  return (
    <section className={styles.root}>
    <div className={styles.wrapper}>
        <div className="new-arrivals-part">
            <div className="home-arrivals-section">
                <h2>New Arrivals</h2>
                <p>{ourStoreData.acf.newArrivalsContent}</p>
                <Link className='view-all' href="/shop">VIEW ALL</Link>
                
            </div>
        </div>
        <div className={styles.newArrivalProducts}> 
            <Slider {...settings}>
                
            { productsByCondition && productsByCondition.map((productsByConditionItem, index) => { 
                return <div key={index} className={styles.imageBox}>
                    <div className={styles.productBlock}>
                        <Link href={UrlReplace(productsByConditionItem['link'])}>
                            <Image width={330} height={345} sizes='100vw' src={productsByConditionItem['image']} alt={productsByConditionItem['name']}/>
                        </Link>
                        <Link href={UrlReplace(productsByConditionItem['link'])}>
                            <p>{productsByConditionItem['name']}</p>
                        </Link>
                        <span className={styles.price}>£{productsByConditionItem['price']}</span>
                    </div>
                    <AddToCart product={productsByConditionItem} openModal={openModal} page="home" />
                </div>
            }) }
            </Slider>
        </div>
        <AddToBasket productData={productData}  modalIsOpen={modalIsOpen} closeModal={closeModal}/>
    </div>
    </section>
  );
};

export default NewArrivalOurStore;
