import React, { useEffect, useMemo, useState } from "react";
import {
    useStripe,
    useElements,
    CardNumberElement,
    CardCvcElement,
    CardExpiryElement,
    PaymentElement 
} from "@stripe/react-stripe-js";
import { useDispatch, useSelector } from 'react-redux';
import { updateCheckout, updateStripeToken ,getStripeToken} from "../../reducer/woocommerceSlice";
import useResponsiveFontSize from "./useResponsiveFontSize";
const useOptions = () => {
    const fontSize = useResponsiveFontSize();
    const options = useMemo(
        () => ({
            style: {
                base: {
                    fontSize: '15px',
                    color: "#000",
                    letterSpacing: "0.025em",
                    padding:"15px",
                    border: "1rem solid",
                    fontFamily: "Source Code Pro, monospace",
                    "::placeholder": {
                        color: "#d5dce4"
                    }
                },
                invalid: {
                    color: "#eb1c26"
                }
            }
        }),
        [fontSize]
    );

    return options;
};
const CardForm = () => {
    const { checkout, cart,saveStripeCard } = useSelector((state) => state.woocommerce)
    const [cardNumberError, setCardNumberError] = useState(false)
    const [cardExpError, setCardexpError] = useState(false)
    const [cardCvvError, setCardCvvError] = useState(false)
    const [cardNumberValid, setCardNumberValid] = useState(false)
    const [cardExpValid, setCardexpValid] = useState(false)
    const [cardCvvValid, setCardCvvValid] = useState(false)
    const stripe = useStripe();
    const elements = useElements();
    const options = useOptions();
    const dispatch = useDispatch()

    const handleCardFormSubmitForm = async event => {
        // event.preventDefault();

        if (!stripe || !elements) {
            // Stripe.js has not loaded yet. Make sure to disable
            // form submission until Stripe.js has loaded.
            return;
        }
        const payload = await stripe.createPaymentMethod({
            type: "card",
            card: elements.getElement(CardNumberElement)
        });
        const ownerInfo = {
            owner: {
                name: cart.billing_address.first_name,
                address: {
                    line1: cart.billing_address.address_1,
                    line2: cart.billing_address.address_2,
                    city: cart.billing_address.city,
                    postal_code: cart.billing_address.postcode,
                    country: cart.billing_address.country,
                },
                phone: cart.billing_address.phone,
                email: cart.billing_address.email,
            },
        };
        const stripResonse = await stripe.createSource(elements.getElement(CardNumberElement), ownerInfo).then((function (response) {
            if (response && response.error) {
                setCardNumberError(response.error.message)
            } else {
                let checkout = {
                    payment_method: "stripe",
                    payment_data: [
                        {
                            "key": "stripe_source",
                            value: response.source.id,
                        },
                        {
                            "key": "paymentRequestType",
                            "value": "card"
                        },
                        {
                            "key": "wc-stripe-new-payment-method",
                            "value": saveStripeCard
                        }
                    ]
                }
                dispatch(updateCheckout(checkout))
                dispatch(updateStripeToken(checkout))
                dispatch(getStripeToken(response.source.id))
            }
        }));
    };

    useEffect(() => {
        cardNumberValid && cardExpValid && cardCvvValid && handleCardFormSubmitForm()
    }, [cardNumberValid, cardExpValid, cardCvvValid])
    return (
        <>
            <form>
                <div>
                    Card number <span className="red-star">*</span>
                    <CardNumberElement
                        options={options}
                        onReady={() => {
                            console.log("CardNumberElement [ready]");
                        }}
                        onChange={event => {
                            event && event.complete ? setCardNumberValid(true) : setCardNumberValid(false)
                            event && event.error && setCardNumberError(event.error.message)
                            console.log("CardNumberElement [change]", event);
                        }}
                        onBlur={() => {
                            console.log("CardNumberElement [blur]");
                        }}
                        onFocus={() => {
                            console.log("CardNumberElement [focus]");
                        }}
                    />
                </div>
                <div>
                    Expiry Date <span className="red-star">*</span>
                    <CardExpiryElement
                        options={options}
                        onReady={() => {
                            console.log("CardNumberElement [ready]");
                        }}
                        onChange={event => {
                            event && event.complete ? setCardexpValid(true) : setCardexpValid(false)
                            event && event.error && setCardexpError(event.error.message)
                            console.log("CardNumberElement [change]", event);
                        }}
                        onBlur={() => {
                            console.log("CardNumberElement [blur]");
                        }}
                        onFocus={() => {
                            console.log("CardNumberElement [focus]");
                        }}
                    />
                </div>
                <div>
                    Card Code (CVC)  <span className="red-star">*</span>
                    <CardCvcElement
                        options={options}
                        onReady={() => {
                            console.log("CardNumberElement [ready]");
                        }}
                        onChange={event => {
                            event && event.complete ? setCardCvvValid(true) : setCardCvvValid(false)
                            event && event.error && setCardCvvError(event.error.message)
                            console.log("CardNumberElement [change]", event);
                        }}
                        onBlur={() => {
                            console.log("CardNumberElement [blur]");
                        }}
                        onFocus={() => {
                            console.log("CardNumberElement [focus]");
                        }}
                    />
                </div>
                {/* {cardNumberError && cardNumberError}
                {cardExpError && cardExpError}
                {cardCvvError && cardCvvError} */}
                {/* <button onClick={handleCardFormSubmitForm} type="submit" disabled={!stripe}>
                    Pay
                </button> */}
                
            </form>
        </>
    );
};

export default CardForm;
