import React from 'react';
import { Helmet, HelmetProvider } from 'react-helmet-async';




const HelmetComponent = ({ yoastHeadJson }) => {

    return (
        <HelmetProvider>
            <Helmet>
                <title>{yoastHeadJson.title}</title>
                <meta name="description" content={yoastHeadJson.description} />
                <link rel="canonical" href={yoastHeadJson.canonical.replace(process.env.ADMIN_URL+'/',process.env.SITE_URL)} />
                <meta property="og:locale" content={yoastHeadJson.ogLocale} />
                <meta property="og:type" content={yoastHeadJson.ogType} />
                <meta property="og:title" content={yoastHeadJson.ogTitle} />
                <meta property="og:description" content={yoastHeadJson.ogDescription} />
                <meta property="og:url" content={yoastHeadJson.ogUrl.replace(process.env.ADMIN_URL+'/',process.env.SITE_URL)} />
                <meta property="og:site_name" content={yoastHeadJson.ogSiteName} />
                <meta property="article:modified_time" content={yoastHeadJson.articleModifiedTime} />
                { yoastHeadJson && yoastHeadJson.ogImage && yoastHeadJson.ogImage.map((ogImageItem, index) => {
                    return <meta key={index} property="og:image" content={ogImageItem.url} />
                }) }
                { yoastHeadJson && yoastHeadJson.ogImage && yoastHeadJson.ogImage.map((ogImageItem, index) => {
                    return <meta key={index} property="og:image:width" content={ogImageItem.width} />
                }) }
                { yoastHeadJson && yoastHeadJson.ogImage && yoastHeadJson.ogImage.map((ogImageItem, index) => {
                    return <meta key={index} property="og:image:height" content={ogImageItem.height} />
                }) }
                { yoastHeadJson && yoastHeadJson.ogImage && yoastHeadJson.ogImage.map((ogImageItem, index) => {
                    return <meta key={index} property="og:image:type" content={ogImageItem.type} />
                }) }
                <meta name="twitter:card" content={yoastHeadJson.twitterCard} />
                { ((yoastHeadJson.twitterMisc) ? <meta name="twitter:label1" content="Estimated reading time" /> : '') }
                { ((yoastHeadJson.twitterMisc) ? <meta name="twitter:data1" content={yoastHeadJson.twitterMisc.estimatedReadingTime} /> : '') }
                { ((yoastHeadJson.twitterMisc && yoastHeadJson.twitterMisc.writtenBy) ? <meta name="twitter:label2" content="Written by" /> : '') }
                { ((yoastHeadJson.twitterMisc && yoastHeadJson.twitterMisc.writtenBy) ? <meta name="twitter:data2" content={yoastHeadJson.twitterMisc.writtenBy} /> : '') }
              
                <script type="application/ld+json" className="yoast-schema-graph"> 
                    {JSON.stringify(yoastHeadJson.schema).replaceAll(process.env.ADMIN_URL+'/',process.env.SITE_URL)}
                </script>
            </Helmet>
        </HelmetProvider>

    );
};

export default HelmetComponent;
