import Head from "next/head";
function PageMetaData({ yoastHeadJson = null, pageTitle = null, media = "" }) {

    return (
        <Head>
            {
                pageTitle != null ?
                    <title>{pageTitle}</title>
                    : yoastHeadJson ?
                        <>
                            <title>{yoastHeadJson.title} </title>
                            <meta name="description" content={yoastHeadJson.description} />
                            <link rel="canonical" href={yoastHeadJson.canonical && yoastHeadJson.canonical.replace(process.env.ADMIN_REPLACE_URL, process.env.SITE_URL)} />
                            {((media != "") ? <link rel="preload" as="image" href={media.url} imagesrcset={srcset} imagesizes="50vw" /> : '')}
                            <meta property="og:locale" content={yoastHeadJson.og_locale && yoastHeadJson.og_locale} />
                            <meta property="og:type" content={yoastHeadJson.og_type && yoastHeadJson.og_type} />
                            <meta property="og:title" content={yoastHeadJson.og_title && yoastHeadJson.og_title} />
                            <meta property="og:description" content={yoastHeadJson.og_description && yoastHeadJson.og_description} />
                            <meta property="og:url" content={yoastHeadJson.og_url && yoastHeadJson.og_url.replace(process.env.ADMIN_REPLACE_URL, process.env.SITE_URL)} />
                            <meta property="og:site_name" content={yoastHeadJson.og_siteName && yoastHeadJson.og_siteName} />
                            <meta property="article:modified_time" content={yoastHeadJson.article_modified_time && yoastHeadJson.article_modified_time} />
                            {yoastHeadJson && yoastHeadJson.og_image && yoastHeadJson.og_image.map((ogImageItem, index) => {
                                return <meta key={index} property="og:image" content={ogImageItem.url} />
                            })}
                            {yoastHeadJson && yoastHeadJson.og_image && yoastHeadJson.og_image.map((ogImageItem, index) => {
                                return <meta key={index} property="og:image:width" content={ogImageItem.width} />
                            })}
                            {yoastHeadJson && yoastHeadJson.og_image && yoastHeadJson.og_image.map((ogImageItem, index) => {
                                return <meta key={index} property="og:image:height" content={ogImageItem.height} />
                            })}
                            {yoastHeadJson && yoastHeadJson.og_image && yoastHeadJson.og_image.map((ogImageItem, index) => {
                                return <meta key={index} property="og:image:type" content={ogImageItem.type} />
                            })}
                            <meta name="twitter:card" content={yoastHeadJson.twitter_card} />
                            {((yoastHeadJson.twitter_misc) ? <meta name="twitter:label1" content="Estimated reading time" /> : '')}
                            {((yoastHeadJson.twitter_misc) ? <meta name="twitter:data1" content={yoastHeadJson.twitter_misc.estimated_reading_time} /> : '')}
                            {((yoastHeadJson.twitter_misc && yoastHeadJson.twitter_misc.written_by) ? <meta name="twitter:label2" content="Written by" /> : '')}
                            {((yoastHeadJson.twitter_misc && yoastHeadJson.twitter_misc.written_by) ? <meta name="twitter:data2" content={yoastHeadJson.twitter_misc.written_by} /> : '')}

                            <script type="application/ld+json" className="yoast-schema-graph">
                                {JSON.stringify(yoastHeadJson.schema).replaceAll(process.env.ADMIN_REPLACE_URL, process.env.SITE_URL)}
                            </script>
                        </>
                        :
                        <title>Antique Silver Dealers | William Walter</title>
            }
        </Head>
    )
}

export default PageMetaData