import NextApp from "next/app";
import { Provider } from "react-redux";
// import { createWrapper,withRedux } from "next-redux-wrapper";
import store from "../lib/store";
import { SiteContext, useSiteContext } from "hooks/use-site";
import NextNProgress from 'nextjs-progressbar';
import { fetchMenuBySlug } from "../services";
import "../styles/globals.scss";
import "../styles/wordpress.scss";
import variables from '../styles/_variables.module.scss';

export default function App({ Component, pageProps = {}, metadata, headerMenuData, topMenuData }) {
  const site = useSiteContext({
    metadata,
    headerMenuData,
    topMenuData
  });
  return (
    <Provider store={store}>
      <SiteContext.Provider value={site}>
        <NextNProgress height={4} color={variables.progressbarColor} />
        <Component {...pageProps} />
      </SiteContext.Provider>
    </Provider>
  );
}

App.getInitialProps = async function (appContext) {
  const appProps = await NextApp.getInitialProps(appContext);
  const headerMenuData = await fetchMenuBySlug('header-menu');
  const topMenuData = await fetchMenuBySlug('top-menu');

  return {
    ...appProps,
    headerMenuData,
    topMenuData
  };
};



