import dynamic from "next/dynamic";
import { fetchPagesById, fetchOptionByParams } from "../services";
import HelmetComponent from "../helmet";
const Breadcrumb = dynamic(() => import("../components/Common/breadcrumb"));
const Filter = dynamic(() => import("../components/news/filter"));
import MainBannerTitle from "../components/news/MainBannerTitle";
import Layout from "components/Layout";
import styles from "../styles/height.module.scss";
import PageMetaData from "lib/pageMetaData";
//const InstagramFeed = dynamic(() => import("../components/Home/InstagramFeed"));

const News = ({ optionData, newsResponse, yoastMetaData }) => {
  return (
    <Layout>
      <>
        <PageMetaData yoastHeadJson={yoastMetaData} />
        <div className={styles.heightAdjust}>
          <MainBannerTitle newsData={newsResponse} optionData={optionData} />
          <Breadcrumb
            breadcrumbMenu={[
              { title: "Home", link: "/" },
              { title: "Our News", link: "" },
            ]}
          />
          <Filter />
          {/* <InstagramFeed /> */}
        </div>
      </>
    </Layout>
  );
};

export default News;

export async function getServerSideProps() {
  const optionData = await fetchOptionByParams("acf.default_banner_image");
  const newsResponse = await fetchPagesById("232");
  const yoastMetaData = newsResponse && newsResponse.yoastHeadJson && newsResponse.yoastHeadJson
  return {
    props: {
      newsResponse,
      optionData,
      yoastMetaData
    },
  };
}
