import dynamic from "next/dynamic";
import React, { useEffect, useState } from 'react';
import Image from "next/image";
import Link from "next/link";
import { useRouter } from 'next/router'
import { fetchWpSearch } from '../services';
import Breadcrumb from '../components/Common/breadcrumb';
//import InstagramFeed from '../components/home/InstagramFeed';
import ProductContact from '../components/Shop/ProductContact';
// import '../style/search.scss'
// import '../style/shop/productlistingmain.scss';
import RecentlyViewed from '../components/Shop/RecentlyViewed';
import styles from "../styles/shop/ProductListingMain.module.scss";
import roundloader from '../assets/round-loader.svg';
import PreviousIcon from "../assets/slider-arrow-left.svg";
import NextIcon from "../assets/slider-arrow.svg";
import UrlReplace from '../components/Common/UrlReplace';
import AddToCart from '../components/Common/AddToCart';
import AddToBasket from '../components/popup/AddToBasket';
import Layout from 'components/Layout';

const Search = () => {
  const router = useRouter()
  const { s, page } = router.query
  //const searchQuery = new URLSearchParams(window.location.search);
  const searchParam = s;
  const pageParam = page ? page : 1;

  const [isLoading, setIsLoading] = useState(false);
  const [isActive, setActive] = useState("false");
  const [total, setTotal] = useState(0);
  const [totalpages, setTotalpages] = useState(0);
  const [perPage, setPerPage] = useState(12);
  const [searchData, setSearchData] = useState([]);
  const [productSimilarObjData, setProductSimilarObjData] = useState({});
  const [modalIsOpen, setIsOpen] = useState(false);

  const ToggleClass = () => {
    setActive(!isActive);
  };
  function openModal(productItemObj) {
    setProductSimilarObjData(productItemObj)
    setIsOpen(true);
  }

  function closeModal() {
    setIsOpen(false);
  }

  const handleSearch = async () => {
    setIsLoading(true);
    try {
      const searchResponse = await fetchWpSearch(searchParam, pageParam);
      if (searchResponse) {
        setIsLoading(false);
        setSearchData(searchResponse.data);
        setTotalpages(searchResponse.maxNumPages);
        setTotal(searchResponse.foundPosts);
      }
    } catch (e) {
      console.log("error", e);
    }
  }
  useEffect(() => {
    handleSearch();
  }, [pageParam])
  const tablePagination = (count) => {
    var indents = [];
    if (pageParam > 1) {
      indents.push(
        <li className='previous-page' key={0}>
          <Link href={"/search?s=" + searchParam + "&page=" + (Number(pageParam) - 1)} className="page-numbers">
            <Image width={6} height={18} src={PreviousIcon.src} className="" alt="previous" loading="lazy" />
            {/* <img src={PreviousIcon} className="" alt="" loading="lazy" /> */}
          </Link>
        </li>)
    }
    var startIndex = ((pageParam == 1) ? pageParam : (pageParam - 1));
    var endIndex = (((Number(pageParam) + 8) > totalpages) ? totalpages : Number(pageParam) + 8);
    if (Math.ceil(count / perPage) > 1) {
      for (let index = startIndex; index <= endIndex; index++) {
        var activeClass = (pageParam == index) ? 'page-numbers current' : 'page-numbers';
        indents.push(
          <li key={index}>
            <Link href={"/search?s=" + searchParam + "&page=" + index}><span aria-current="page" className={activeClass}>{index}</span></Link>
          </li>
        )
      }
    }
    if (Math.ceil(count / perPage) > pageParam) {
      indents.push(
        <li key={count + 1}>
          <Link href={"/search?s=" + searchParam + "&page=" + (Number(pageParam) + 1)} className="page-numbers next-page">
            {/* <img src={NextIcon} className="" alt="" loading="lazy" /> */}
            <Image width={6} height={18} src={NextIcon.src} className="" alt="next" loading="lazy" />
          </Link>
        </li>
      )
    }
    return indents;

  }
  return (
    <Layout>
      <div className={styles.root}>
        <section className="searchform-section">
          <div className={styles.wrapper}>
            <div className="banner-text">
              <h1 className="page-tittle">Search</h1>
            </div>
            <Breadcrumb breadcrumbMenu={[{ title: "Home", link: '/' }, { title: "SEARCH RESULTS FOR “" + searchParam + "”", link: '' }]} />
            <div className='list-products main-listing'>
              {searchData && searchData.length !== 0 &&
                <div className='filter-bars'>
                  <a href="#" data-type="grid" className={((isActive) ? "grid-view-data selected" : "grid-view-data")} onClick={ToggleClass}>
                    <i className="fa fa-th"></i>
                  </a>
                  <a href="#" data-type="list" className={((isActive) ? "list-view-data" : "list-view-data selected")} onClick={ToggleClass}>
                    <i className="fa fa-bars"></i>
                  </a>
                  <nav className="woocommerce-pagination">
                    <ul className="page-numbers"> {tablePagination(total)} </ul>
                  </nav>
                </div>
              }

              <div className='product-block'>
                <Image className="loader-image" src={roundloader} style={{ display: ((isLoading) ? '' : 'none') }} />
                {!isLoading && searchData && searchData.length !== 0 ?
                  <ul className={((isActive) ? "products columns-4" : "products columns-4 list-view")}>
                    {
                      searchData.map((item, index) => {
                        return (
                          <li>
                            <Link href={UrlReplace(item.link)}>
                              <div className="product-img">
                                <Image width={800} height={758} src={item.image} className="attachment-product-image size-product-image wp-post-image" alt="product-banner-img" />
                              </div>
                              <div className='list-view-set'>
                                <h2 className="woocommerce-loop-product__title">{item.name}</h2>
                                {/* <span className="price">
                                              <span className="woocommerce-Price-amount amount">
                                                  <bdi>
                                                      <span className="woocommerce-Price-currencySymbol">£</span>1,200 </bdi>
                                              </span>
                                          </span> */}
                                <div className="product-custom-mata">
                                  <div className="woocommerce-sku">{item.sku}</div>
                                  <div className="product-date-label"> Date: <div className="woocommerce-sku">{item.productDateFrom} </div>
                                  </div>
                                  {
                                    ((item.maker.length > 0) ?
                                      <div className="maker">
                                        <span className="maker-label">Maker: </span><span dangerouslySetInnerHTML={{ __html: (item.maker[0].name) }}></span>
                                      </div>
                                      : '')
                                  }
                                  <div className="price">
                                    {
                                      (((item.inStock == "outofstock")) ? 'Sold' :
                                        <span className="woocommerce-Price-amount amount">
                                          <bdi>
                                            <span className="woocommerce-Price-currencySymbol">£{item.price}</span>
                                          </bdi>
                                        </span>)
                                    }
                                  </div>
                                  <div className="lgv_description lgv_description_simple">
                                    <div className="woocommerce-product-details__short-description">
                                      <p>{item.shortDescription}</p>
                                    </div>
                                  </div>
                                </div>
                              </div>
                            </Link>
                            {((item.buyingOptions && item.buyingOptions.includes('allow_buy_online') && item.inStock == "instock") ?
                              <AddToCart product={item} openModal={openModal} page="list" /> : '')}
                            <Link href={UrlReplace(item.link)} className="button enquire_only_btn">ENQUIRE ABOUT THIS PIECE </Link>
                          </li>
                        )
                      })
                    }

                  </ul>
                  : ""
                }

                {

                  searchData && searchData.length !== 0 &&
                  <div className='filter-bars'>
                    <a href="#" data-type="grid" className={((isActive) ? "grid-view-data selected" : "grid-view-data")} onClick={ToggleClass}>
                      <i className="fa fa-th"></i>
                    </a>
                    <a href="#" data-type="list" className={((isActive) ? "list-view-data" : "list-view-data selected")} onClick={ToggleClass}>
                      <i className="fa fa-bars"></i>
                    </a>
                    <nav className="woocommerce-pagination">
                      <ul className="page-numbers">
                        {tablePagination(total)}
                      </ul>
                    </nav>
                  </div>

                }

              </div>
              {!isLoading && searchData && searchData.length == 0 ?
                <p className="cart-empty woocommerce-info">"No products were found matching your selection."</p>
                : ""
              }
            </div>
            <AddToBasket productData={productSimilarObjData} modalIsOpen={modalIsOpen} closeModal={closeModal} />

          </div>
        </section>
      </div>
      <ProductContact />
      <RecentlyViewed productsData={searchData} />
      {/* <InstagramFeed /> */}
    </Layout>
  )
};

export default Search;
