import dynamic from "next/dynamic";
import React, { useEffect, useState } from "react";
import Link from "next/link";
import { fetchMakers } from "../services";
//const InstagramFeed = dynamic(() => import("../components/Home/InstagramFeed"));
const AboutBreadcrumb = dynamic(() => import("../components/Common/SmithBreadcrumb"));
import MainBannerBrand from "../components/brand/MainBannerBrand";
const RecentlyViewed = dynamic(() => import("../components/Common/RecentlyViewed"));
const ProductContact = dynamic(() => import("../components/Shop/ProductContact"));
import UrlReplace from "../components/Common/UrlReplace";
const FulllPageLoader = dynamic(() => import("../components/Common/FulllPageLoader"));
import Layout from "components/Layout";
import styles from "../styles/cmspage/Alphabeticfilter.module.scss";

const SilverSmithIndex = ({ optionData }) => {
  const [isSilverSmithLoading, setIsSilverSmithLoading] = useState(true);
  const [silverSmithData, setSilverSmithData] = useState("");
  const [selectedMaker, setSelectedMaker] = useState([]);
  const [refreshComponet, setRefreshComponet] = useState("");
  const [isToggle, setIsToggle] = useState(false);

  const handleSilverSmith = async () => {
    setIsSilverSmithLoading(true);
    const silverSmithResponse = await fetchMakers();
    setSilverSmithData(silverSmithResponse);
    setIsSilverSmithLoading(false);
  };

  useEffect(() => {
    if (isSilverSmithLoading) {
      handleSilverSmith();
      window.scrollTo(0, 0);
    }
  }, [refreshComponet]);

  const filterSelectMaker = (event) => {
    let newSelectedMaker = [...selectedMaker];
    if (event.target.checked) {
      newSelectedMaker.push(event.target.value);
    } else {
      var indexa = newSelectedMaker.indexOf(event.target.value);
      if (indexa > -1) {
        newSelectedMaker.splice(indexa, 1);
      }
    }

    setSelectedMaker(newSelectedMaker);
    setRefreshComponet(Math.random());
  };

  const filterCleartMaker = () => {
    setSelectedMaker([]);
    setRefreshComponet(Math.random());
  };

  const openFilter = () => {
    setIsToggle(!isToggle);
  };

  return isSilverSmithLoading ? (
    <FulllPageLoader />
  ) : (
    <Layout>
      <section className={styles.root}>
        <MainBannerBrand silverSmithData={silverSmithData} />
        <AboutBreadcrumb
          breadcrumbMenu={[
            { title: "Home", link: "/" },
            { title: silverSmithData.pageData.postTitle, link: "" },
          ]}
        />
        <div className="maker-filter">
          <div className={styles.wrapper}>
            <div className="fillter-section">
              <div className="fillter-part">
                <div className={isToggle ? "fillter-fixed open" : "fillter-fixed"}>
                  <div className="block-title filter-title" onClick={openFilter}>
                    FILTER
                  </div>
                  <div className="fillter-inner-container">
                    <h3>Filter by Maker</h3>

                    <div className="fillter-left">
                      <a
                        onClick={filterCleartMaker}
                        className={selectedMaker.length > 0 ? "fillter-clear active" : "fillter-clear"}
                      >
                        CLEAR
                      </a>
                      {silverSmithData &&
                        silverSmithData.alphabetic &&
                        silverSmithData.alphabetic.map((alphabeticItem, index) => {
                          return (
                            <div key={index} className="checkbox-part">
                              <a className="scroll" href={"#maker_alpha_" + alphabeticItem}>
                                <label>
                                  <input
                                    onChange={(e) => filterSelectMaker(e)}
                                    checked={
                                      selectedMaker.length != 0 && selectedMaker.includes(alphabeticItem.toString())
                                    }
                                    name="maker_alpha"
                                    type="checkbox"
                                    className={"maker_alpha_chk maker_alpha" + alphabeticItem}
                                    value={alphabeticItem}
                                  />
                                  <span>{alphabeticItem}</span>
                                </label>
                              </a>
                            </div>
                          );
                        })}
                    </div>
                  </div>
                </div>

                <div className="a-z_cat_contect left-side">
                  {silverSmithData &&
                    silverSmithData.alphabetic &&
                    silverSmithData.alphabetic.map((alphabeticItem, index) => {
                      return selectedMaker.indexOf(alphabeticItem) > -1 || selectedMaker.length == 0 ? (
                        <div key={index} className="cat-block maker-div-block" id={"#maker_alpha_" + alphabeticItem}>
                          <h5>{alphabeticItem}</h5>
                          <div className="a-z_sub_cat">
                            {silverSmithData.data[alphabeticItem.toLowerCase()].length > 0 ? (
                              <ul className="william-abdy">
                                {silverSmithData.data[alphabeticItem.toLowerCase()].map(
                                  (silverSmithDataItem, sIndex) => {
                                    return (
                                      <li key={sIndex}>
                                        <Link href={UrlReplace(silverSmithDataItem.termLink)}>
                                          <span
                                            dangerouslySetInnerHTML={{ __html: silverSmithDataItem.getMakerObg }}
                                          ></span>
                                          <span>
                                            {silverSmithDataItem.forSaleCount} for sale, {silverSmithDataItem.soldCount}{" "}
                                            sold
                                          </span>
                                        </Link>
                                      </li>
                                    );
                                  },
                                )}
                              </ul>
                            ) : (
                              <p>No makers found</p>
                            )}
                          </div>
                        </div>
                      ) : (
                        ""
                      );
                    })}
                </div>
              </div>
            </div>
          </div>
        </div>
        <ProductContact />
        <RecentlyViewed />
        {/* <InstagramFeed /> */}
      </section>
    </Layout>
  );
};

export default SilverSmithIndex;

