import { createSlice } from '@reduxjs/toolkit';

const initialState = {
  userIsLogin: false,
  userIsLoading: true,
  userData: [],
  userError: '',
};

const userSlice = createSlice({
  name: 'user',
  initialState,
  reducers: {
    userPending: state => {
      state.userIsLogin = false;
      state.userIsLoading = false,
      state.userError = '';
    },
    userSuccess: (state, { payload }) => {
      state.userIsLogin = true;
      state.userIsLoading = false,
      state.userData = payload;
    },
    userUpdate: (state, { payload }) => {
      state.userData.firstname = payload.account_first_name;
      state.userData.lastname = payload.account_last_name;
      state.userData.email = payload.account_email;
      state.userData.displayname = payload.account_first_name+' '+payload.account_last_name;
    },
    userFail: (state, { payload }) => {
      state.userIsLogin = false;
      state.userIsLoading = true,
      state.userError = payload;
    },
  },
});

const { reducer, actions } = userSlice;

export const { userPending, userSuccess, userFail, userUpdate } = actions;

export default reducer;
