/* eslint-disable no-param-reassign */
import { createSlice } from '@reduxjs/toolkit'
// ------------------------------------
// Constants
// ------------------------------------

const initialState = {
    isCartReady: false,
    isShippingMethodReady: false,
    cart: {
        coupons: [],
        shipping_rates: [],
        ship_to_different_address: true,
        isPaymentReady: false,
        shipping_address: {
            first_name: "",
            last_name: "",
            company: "",
            address_1: "",
            address_2: "",
            city: "",
            state: "",
            postcode: "",
            country: "",
            email: "",
            phone: ""
        },
        billing_address: {
            first_name: "",
            last_name: "",
            company: "",
            address_1: "",
            address_2: "",
            city: "",
            state: "",
            postcode: "",
            country: "",
            email: "",
            phone: ""
        },
        items: [],
        items_count: 0,
        items_weight: 0,
        needs_payment: false,
        needs_shipping: false,
        has_calculated_shipping: false,
        totals: {
            total_items: "0",
            total_items_tax: "",
            total_fees: "0",
            total_fees_tax: "",
            total_discount: "0",
            total_discount_tax: "0",
            total_shipping: "",
            total_shipping_tax: "",
            total_price: "",
            total_tax: "",
            tax_lines: [],
            currency_code: "",
            currency_symbol: "",
            currency_minor_unit: 0,
            currency_decimal_separator: "",
            currency_thousand_separator: "",
            currency_prefix: "",
            currency_suffix: ""
        },
        errors: [],
        extensions: {}
    },
    checkout: {
        payment_method: "stripe",
        customer_note: ""
    },
    saveStripeCardToken:"",
    stripe_payment_data: [],
    order: {},
    product: {}
}

// ------------------------------------
// Slice
// ------------------------------------

const woocommerceSlice = createSlice({
    name: 'woocommerce',
    initialState,
    reducers: {
        pendingCart: state => {
            state.isCartReady = false
        },
        getCart: (state, { payload }) => {
            state.cart = payload;
            state.isCartReady = true
        },
        updateCart: (state, { payload }) => {
            state.cart = payload;
            state.isCartReady = true
        },
        updateBilling: (state, { payload }) => {
            state.cart.billing_address = { ...state.cart.billing_address, ...payload };
        },
        isCartStatusUpdate: (state , { payload }) => {
            state.isCartReady = payload
        },
        updateAddressStatus: (state, { payload }) => {
            state.cart.ship_to_different_address = payload;
            state.isShippingMethodReady = true
        },
        updateShippingMethod: (state, { payload }) => {
            state.cart.shipping_rates = [ ...state.cart.shipping_rates, ...payload ];
            state.isShippingMethodReady = true
        },
        updateShipping: (state, { payload }) => {
            state.cart.shipping_address = { ...state.cart.shipping_address, ...payload };
            state.isShippingMethodReady = true
        },
        updateCheckout: (state, { payload }) => {
            state.checkout = payload;
            state.isCartReady = true
            state.isPaymentReady = true
        },
        updateStripeToken: (state, { payload }) => {
            state.stripe_payment_data = payload;
            state.isPaymentReady = true;
        },
        getStripeToken:(state,{payload})=>{
            state.saveStripeCardToken = payload
        },
    },
})

const { reducer, actions } = woocommerceSlice
export const { getCart, pendingCart, updateCart, updateBilling, updateShipping, isCartStatusUpdate, updateAddressStatus, updateShippingMethod,updateCheckout,updateStripeToken,getStripeToken } = actions;

export default reducer
