import Http from "../utils/Http";
import Transformer from "../utils/Transformer";

export function storeApi({ endpoint, params = {} }) {
  const searchParams = new URLSearchParams(params);
  return new Promise((resolve, reject) => {
    Http.get(`${process.env.STORE_URL}${endpoint}?${searchParams}`)
      .then((res) => {
        const data = Transformer.fetch(res.data);
        return resolve(data);
      })
      .catch((err) => {
        let rejectRes = reject(err.response);
        return rejectRes;
      });
  });
}

export function addItem({ endpoint, params = {} }) {
  const searchParams = new URLSearchParams(params);
  return new Promise((resolve, reject) => {
    Http.post(`${process.env.STORE_URL}${endpoint}?${searchParams}`)
      .then((res) => {
        const data = Transformer.fetch(res.data);
        return resolve(data);
      })
      .catch((err) => {
        let rejectRes = reject(err.response);
        return rejectRes;
      });
  });
}
export function fetchMenuBySlug(slug) {
  return new Promise((resolve, reject) => {
    Http.get("menus/v1/menus/" + slug)
      .then((res) => {
        const data = Transformer.fetch(res.data);
        return resolve(data);
      })
      .catch((err) => {
        let rejectRes = reject(err.response);
        return rejectRes;
      });
  });
}

export function fetchGeneralSettings() {
  return new Promise((resolve, reject) => {
    Http.get("acf/v3/options/options")
      .then((res) => {
        const data = Transformer.fetch(res.data);
        return resolve(data);
      })
      .catch((err) => {
        let rejectRes = reject(err.response);
        return rejectRes;
      });
  });
}

export function fetchOptionByParams(params) {
  return new Promise((resolve, reject) => {
    Http.get("acf/v3/options/options?_fields=" + params)
      .then((res) => {
        const data = Transformer.fetch(res.data);
        return resolve(data);
      })
      .catch((err) => {
        let rejectRes = reject(err.response);
        return rejectRes;
      });
  });
}
export function joinOurNewsletter(postData) {
  return new Promise((resolve, reject) => {
    Http.post("contact-form-7/v1/contact-forms/131/feedback", postData)
      .then((res) => {
        const data = Transformer.fetch(res.data);
        return resolve(data);
      })
      .catch((err) => {
        let rejectRes = reject(err.response);
        return rejectRes;
      });
  });
}

export function fetchPagesById(id) {
  return new Promise((resolve, reject) => {
    Http.get("wp/v2/pages/" + id + "?_embed")
      .then((res) => {
        const data = Transformer.fetch(res.data);
        return resolve(data);
      })
      .catch((err) => {
        let rejectRes = reject(err.response);
        return rejectRes;
      });
  });
}

export function fetchLatestNews() {
  return new Promise((resolve, reject) => {
    Http.get("wp/v2/get_news_posts?post_id=53")
      .then((res) => {
        const data = Transformer.fetch(res.data);
        return resolve(data);
      })
      .catch((err) => {
        let rejectRes = reject(err.response);
        return rejectRes;
      });
  });
}

export function fetchProductsByCondition() {
  return new Promise((resolve, reject) => {
    Http.get("wp/v2/get_products_by_condition?listing_type=latest&limit=8")
      .then((res) => {
        const data = Transformer.fetch(res.data);
        return resolve(data);
      })
      .catch((err) => {
        let rejectRes = reject(err.response);
        return rejectRes;
      });
  });
}

export function fetchCategories() {
  return new Promise((resolve, reject) => {
    Http.get("wp/v2/categories")
      .then((res) => {
        const data = Transformer.fetch(res.data);
        return resolve(data);
      })
      .catch((err) => {
        let rejectRes = reject(err.response);
        return rejectRes;
      });
  });
}

export function fetchPosts(filterParam) {
  return new Promise((resolve, reject) => {
    Http.get("wp/v2/posts" + filterParam)
      .then((res) => {
        const data = Transformer.fetch(res.data);
        return resolve(data);
      })
      .catch((err) => {
        let rejectRes = reject(err.response);
        return rejectRes;
      });
  });
}

export function fetchPostsWithfilter(filterParam) {
  return new Promise((resolve, reject) => {
    Http.get("wp/v2/posts" + filterParam)
      .then((res) => {
        const data = Transformer.fetch(res);
        return resolve(data);
      })
      .catch((err) => {
        let rejectRes = reject(err.response);
        return rejectRes;
      });
  });
}

export function fetchCustomPostType(postType) {
  return new Promise((resolve, reject) => {
    Http.get("wp/v2/" + postType)
      .then((res) => {
        const data = Transformer.fetch(res.data);
        return resolve(data);
      })
      .catch((err) => {
        let rejectRes = reject(err.response);
        return rejectRes;
      });
  });
}

export function fetchCustomPostTypePagination(postType) {
  return new Promise((resolve, reject) => {
    Http.get("wp/v2/" + postType)
      .then((res) => {
        const data = Transformer.fetch(res);
        return resolve(data);
      })
      .catch((err) => {
        let rejectRes = reject(err.response);
        return rejectRes;
      });
  });
}

export function fetchOurExpertProduct(products) {
  return new Promise((resolve, reject) => {
    Http.get("wp/v2/get_our_expert_product?products=" + products)
      .then((res) => {
        const data = Transformer.fetch(res.data);
        return resolve(data);
      })
      .catch((err) => {
        let rejectRes = reject(err.response);
        return rejectRes;
      });
  });
}

export function fetchProducts(filterParam) {
  return new Promise((resolve, reject) => {
    Http.get("wc/v3/products" + filterParam)
      .then((res) => {
        const data = Transformer.fetch(res.data);
        return resolve(data);
      })
      .catch((err) => {
        let rejectRes = reject(err.response);
        return rejectRes;
      });
  });
}

export function fetchProductLists(filterParam) {
  return new Promise((resolve, reject) => {
    Http.get("wc/v3/products" + filterParam)
      .then((res) => {
        const data = Transformer.fetch(res);
        return resolve(data);
      })
      .catch((err) => {
        let rejectRes = reject(err.response);
        return rejectRes;
      });
  });
}

export function fetchProductFilters(slug) {
  return new Promise((resolve, reject) => {
    Http.get("wp/v2/product_filter_data?category_slug=" + slug)
      .then((res) => {
        const data = Transformer.fetch(res.data);
        return resolve(data);
      })
      .catch((err) => {
        let rejectRes = reject(err.response);
        return rejectRes;
      });
  });
}
export function fetchProductCurrentCategory(slug) {
  return new Promise((resolve, reject) => {
    Http.get("wp/v2/get_product_current_category?category_slug=" + slug)
      .then((res) => {
        const data = Transformer.fetch(res.data);
        return resolve(data);
      })
      .catch((err) => {
        let rejectRes = reject(err.response);
        return rejectRes;
      });
  });
}

export function fetchProductFiltersMakers(slug) {
  return new Promise((resolve, reject) => {
    Http.get("wp/v2/product_filter_data_maker?maker_slug=" + slug)
      .then((res) => {
        const data = Transformer.fetch(res.data);
        return resolve(data);
      })
      .catch((err) => {
        let rejectRes = reject(err.response);
        return rejectRes;
      });
  });
}

export function submitContactFormWithId(id, postData) {
  return new Promise((resolve, reject) => {
    Http.post("contact-form-7/v1/contact-forms/" + id + "/feedback", postData)
      .then((res) => {
        const data = Transformer.fetch(res.data);
        return resolve(data);
      })
      .catch((err) => {
        let rejectRes = reject(err.response);
        return rejectRes;
      });
  });
}

export function isUserLoggedIn(apiArgument) {
  return new Promise((resolve, reject) => {
    Http.get(process.env.USER_API_URL + apiArgument, { withCredentials: true })
      .then((res) => {
        const data = Transformer.fetch(res.data);
        return resolve(data);
      })
      .catch((error) => {
        let rejectRes = reject(err.response);
        return rejectRes;
      });
  });
}

export function fetchClientSecretKey(postData) {
  return new Promise((resolve, reject) => {
    Http.post("https://api.stripe.com/v1/payment_intents", postData, {
      headers: {
        "Content-type": "application/x-www-form-urlencoded",
        Authorization:
          "Bearer sk_test_51LrJeWAGpzZeI2RHauIN1TCsYIaZqCCC5osFvbqLSUbMTFMniF5XN1DbuNyQNpihf0obccGajLn2ek6QInJKfOpH00o0DXZbnW",
      },
    })
      .then((res) => {
        const data = Transformer.fetch(res.data);
        return resolve(data);
      })
      .catch((err) => {
        let rejectRes = reject(err.response);
        return rejectRes;
      });
  });
}

export function fetchShippingCountries() {
  return new Promise((resolve, reject) => {
    Http.get("wp/v2/getShippingCountries")
      .then((res) => {
        const data = Transformer.fetch(res.data);
        return resolve(data);
      })
      .catch((err) => {
        let rejectRes = reject(err.response);
        return rejectRes;
      });
  });
}

export function fetchOrderHistory(filterParam) {
  return new Promise((resolve, reject) => {
    Http.get("wc/v3/orders" + filterParam)
      .then((res) => {
        const data = Transformer.fetch(res);
        return resolve(data);
      })
      .catch((err) => {
        let rejectRes = reject(err.response);
        return rejectRes;
      });
  });
}

export function fetchPaymentGateways() {
  return new Promise((resolve, reject) => {
    Http.get("wc/v3/payment_gateways")
      .then((res) => {
        const data = Transformer.fetch(res);
        return resolve(data);
      })
      .catch((err) => {
        let rejectRes = reject(err.response);
        return rejectRes;
      });
  });
}

export function fetchMakers() {
  return new Promise((resolve, reject) => {
    Http.get("wp/v2/get_makers")
      .then((res) => {
        const data = Transformer.fetch(res.data);
        return resolve(data);
      })
      .catch((err) => {
        let rejectRes = reject(err.response);
        return rejectRes;
      });
  });
}

export function fetchMakersDetail(slug) {
  return new Promise((resolve, reject) => {
    Http.get("wp/v2/get_makers_detail?slug=" + slug)
      .then((res) => {
        const data = Transformer.fetch(res.data);
        return resolve(data);
      })
      .catch((err) => {
        let rejectRes = reject(err.response);
        return rejectRes;
      });
  });
}

export function fetchWpSearch(search, page = 1) {
  return new Promise((resolve, reject) => {
    Http.get("wp/v2/my_rest_engine_name?s=" + search + "&page=" + page)
      .then((res) => {
        const data = Transformer.fetch(res.data);
        return resolve(data);
      })
      .catch((err) => {
        let rejectRes = reject(err.response);
        return rejectRes;
      });
  });
}

export function fetchPageAcf(params) {
  return new Promise((resolve, reject) => {
    Http.get('wp/v2/pages/' + params)
      .then((res) => {
        const data = Transformer.fetch(res.data);
        return resolve(data);
      })
      .catch((err) => {
        let rejectRes = reject(err.response);
        return rejectRes;
      });
  });
}